Class: Aws::Mgn::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Mgn::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-mgn/client.rb,
sig/client.rbs
Overview
An API client for Mgn. To construct a client, you need to configure a :region and :credentials.
client = Aws::Mgn::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _ArchiveApplicationResponseSuccess, _ArchiveWaveResponseSuccess, _AssociateApplicationsResponseSuccess, _AssociateSourceServersResponseSuccess, _ChangeServerLifeCycleStateResponseSuccess, _CreateApplicationResponseSuccess, _CreateConnectorResponseSuccess, _CreateLaunchConfigurationTemplateResponseSuccess, _CreateNetworkMigrationDefinitionResponseSuccess, _CreateReplicationConfigurationTemplateResponseSuccess, _CreateWaveResponseSuccess, _DeleteApplicationResponseSuccess, _DeleteJobResponseSuccess, _DeleteLaunchConfigurationTemplateResponseSuccess, _DeleteNetworkMigrationDefinitionResponseSuccess, _DeleteReplicationConfigurationTemplateResponseSuccess, _DeleteSourceServerResponseSuccess, _DeleteWaveResponseSuccess, _DescribeJobLogItemsResponseSuccess, _DescribeJobsResponseSuccess, _DescribeLaunchConfigurationTemplatesResponseSuccess, _DescribeReplicationConfigurationTemplatesResponseSuccess, _DescribeSourceServersResponseSuccess, _DescribeVcenterClientsResponseSuccess, _DisassociateApplicationsResponseSuccess, _DisassociateSourceServersResponseSuccess, _DisconnectFromServiceResponseSuccess, _FinalizeCutoverResponseSuccess, _GetLaunchConfigurationResponseSuccess, _GetNetworkMigrationDefinitionResponseSuccess, _GetNetworkMigrationMapperSegmentConstructResponseSuccess, _GetReplicationConfigurationResponseSuccess, _InitializeServiceResponseSuccess, _ListApplicationsResponseSuccess, _ListConnectorsResponseSuccess, _ListExportErrorsResponseSuccess, _ListExportsResponseSuccess, _ListImportErrorsResponseSuccess, _ListImportFileEnrichmentsResponseSuccess, _ListImportsResponseSuccess, _ListManagedAccountsResponseSuccess, _ListNetworkMigrationAnalysesResponseSuccess, _ListNetworkMigrationAnalysisResultsResponseSuccess, _ListNetworkMigrationCodeGenerationSegmentsResponseSuccess, _ListNetworkMigrationCodeGenerationsResponseSuccess, _ListNetworkMigrationDefinitionsResponseSuccess, _ListNetworkMigrationDeployedStacksResponseSuccess, _ListNetworkMigrationDeploymentsResponseSuccess, _ListNetworkMigrationExecutionsResponseSuccess, _ListNetworkMigrationMapperSegmentConstructsResponseSuccess, _ListNetworkMigrationMapperSegmentsResponseSuccess, _ListNetworkMigrationMappingUpdatesResponseSuccess, _ListNetworkMigrationMappingsResponseSuccess, _ListSourceServerActionsResponseSuccess, _ListTagsForResourceResponseSuccess, _ListTemplateActionsResponseSuccess, _ListWavesResponseSuccess, _MarkAsArchivedResponseSuccess, _PauseReplicationResponseSuccess, _PutSourceServerActionResponseSuccess, _PutTemplateActionResponseSuccess, _RemoveSourceServerActionResponseSuccess, _RemoveTemplateActionResponseSuccess, _ResumeReplicationResponseSuccess, _RetryDataReplicationResponseSuccess, _StartCutoverResponseSuccess, _StartExportResponseSuccess, _StartImportFileEnrichmentResponseSuccess, _StartImportResponseSuccess, _StartNetworkMigrationAnalysisResponseSuccess, _StartNetworkMigrationCodeGenerationResponseSuccess, _StartNetworkMigrationDeploymentResponseSuccess, _StartNetworkMigrationMappingResponseSuccess, _StartNetworkMigrationMappingUpdateResponseSuccess, _StartReplicationResponseSuccess, _StartTestResponseSuccess, _StopReplicationResponseSuccess, _TerminateTargetInstancesResponseSuccess, _UnarchiveApplicationResponseSuccess, _UnarchiveWaveResponseSuccess, _UpdateApplicationResponseSuccess, _UpdateConnectorResponseSuccess, _UpdateLaunchConfigurationResponseSuccess, _UpdateLaunchConfigurationTemplateResponseSuccess, _UpdateNetworkMigrationDefinitionResponseSuccess, _UpdateNetworkMigrationMapperSegmentResponseSuccess, _UpdateReplicationConfigurationResponseSuccess, _UpdateReplicationConfigurationTemplateResponseSuccess, _UpdateSourceServerReplicationTypeResponseSuccess, _UpdateSourceServerResponseSuccess, _UpdateWaveResponseSuccess
Constant Summary collapse
- Params =
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#archive_application(params = {}) ⇒ Types::Application
Archive application.
-
#archive_wave(params = {}) ⇒ Types::Wave
Archive wave.
-
#associate_applications(params = {}) ⇒ Struct
Associate applications to wave.
-
#associate_source_servers(params = {}) ⇒ Struct
Associate source servers to application.
-
#change_server_life_cycle_state(params = {}) ⇒ Types::SourceServer
Allows the user to set the SourceServer.LifeCycle.state property for specific Source Server IDs to one of the following: READY_FOR_TEST or READY_FOR_CUTOVER.
-
#create_application(params = {}) ⇒ Types::Application
Create application.
-
#create_connector(params = {}) ⇒ Types::Connector
Create Connector.
-
#create_launch_configuration_template(params = {}) ⇒ Types::LaunchConfigurationTemplate
Creates a new Launch Configuration Template.
-
#create_network_migration_definition(params = {}) ⇒ Types::NetworkMigrationDefinition
Creates a new network migration definition that specifies the source and target network configuration for a migration.
-
#create_replication_configuration_template(params = {}) ⇒ Types::ReplicationConfigurationTemplate
Creates a new ReplicationConfigurationTemplate.
-
#create_wave(params = {}) ⇒ Types::Wave
Create wave.
-
#delete_application(params = {}) ⇒ Struct
Delete application.
-
#delete_connector(params = {}) ⇒ Struct
Delete Connector.
-
#delete_job(params = {}) ⇒ Struct
Deletes a single Job by ID.
-
#delete_launch_configuration_template(params = {}) ⇒ Struct
Deletes a single Launch Configuration Template by ID.
-
#delete_network_migration_definition(params = {}) ⇒ Struct
Deletes a network migration definition.
-
#delete_replication_configuration_template(params = {}) ⇒ Struct
Deletes a single Replication Configuration Template by ID.
-
#delete_source_server(params = {}) ⇒ Struct
Deletes a single source server by ID.
-
#delete_vcenter_client(params = {}) ⇒ Struct
Deletes a given vCenter client by ID.
-
#delete_wave(params = {}) ⇒ Struct
Delete wave.
-
#describe_job_log_items(params = {}) ⇒ Types::DescribeJobLogItemsResponse
Retrieves detailed job log items with paging.
-
#describe_jobs(params = {}) ⇒ Types::DescribeJobsResponse
Returns a list of Jobs.
-
#describe_launch_configuration_templates(params = {}) ⇒ Types::DescribeLaunchConfigurationTemplatesResponse
Lists all Launch Configuration Templates, filtered by Launch Configuration Template IDs.
-
#describe_replication_configuration_templates(params = {}) ⇒ Types::DescribeReplicationConfigurationTemplatesResponse
Lists all ReplicationConfigurationTemplates, filtered by replication configuration template IDs.
-
#describe_source_servers(params = {}) ⇒ Types::DescribeSourceServersResponse
Retrieves all SourceServers or multiple SourceServers by ID.
-
#describe_vcenter_clients(params = {}) ⇒ Types::DescribeVcenterClientsResponse
Returns a list of the installed vCenter clients.
-
#disassociate_applications(params = {}) ⇒ Struct
Disassociate applications from wave.
-
#disassociate_source_servers(params = {}) ⇒ Struct
Disassociate source servers from application.
-
#disconnect_from_service(params = {}) ⇒ Types::SourceServer
Disconnects specific Source Servers from Application Migration Service.
-
#finalize_cutover(params = {}) ⇒ Types::SourceServer
Finalizes the cutover immediately for specific Source Servers.
-
#get_launch_configuration(params = {}) ⇒ Types::LaunchConfiguration
Lists all LaunchConfigurations available, filtered by Source Server IDs.
-
#get_network_migration_definition(params = {}) ⇒ Types::NetworkMigrationDefinition
Retrieves the details of a network migration definition including source and target configurations.
-
#get_network_migration_mapper_segment_construct(params = {}) ⇒ Types::GetNetworkMigrationMapperSegmentConstructResponse
Retrieves detailed information about a specific construct within a mapper segment, including its properties and configuration data.
-
#get_replication_configuration(params = {}) ⇒ Types::ReplicationConfiguration
Lists all ReplicationConfigurations, filtered by Source Server ID.
-
#initialize_service(params = {}) ⇒ Struct
Initialize Application Migration Service.
-
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Retrieves all applications or multiple applications by ID.
-
#list_connectors(params = {}) ⇒ Types::ListConnectorsResponse
List Connectors.
-
#list_export_errors(params = {}) ⇒ Types::ListExportErrorsResponse
List export errors.
-
#list_exports(params = {}) ⇒ Types::ListExportsResponse
List exports.
-
#list_import_errors(params = {}) ⇒ Types::ListImportErrorsResponse
List import errors.
-
#list_import_file_enrichments(params = {}) ⇒ Types::ListImportFileEnrichmentsResponse
Lists import file enrichment jobs with optional filtering by job IDs.
-
#list_imports(params = {}) ⇒ Types::ListImportsResponse
List imports.
-
#list_managed_accounts(params = {}) ⇒ Types::ListManagedAccountsResponse
List Managed Accounts.
-
#list_network_migration_analyses(params = {}) ⇒ Types::ListNetworkMigrationAnalysesResponse
Lists network migration analysis jobs for a specified execution.
-
#list_network_migration_analysis_results(params = {}) ⇒ Types::ListNetworkMigrationAnalysisResultsResponse
Lists the results of network migration analyses, showing connectivity and compatibility findings for migrated resources.
-
#list_network_migration_code_generation_segments(params = {}) ⇒ Types::ListNetworkMigrationCodeGenerationSegmentsResponse
Lists code generation segments, which represent individual infrastructure components generated as code templates.
-
#list_network_migration_code_generations(params = {}) ⇒ Types::ListNetworkMigrationCodeGenerationsResponse
Lists network migration code generation jobs, which convert network mappings into infrastructure-as-code templates.
-
#list_network_migration_definitions(params = {}) ⇒ Types::ListNetworkMigrationDefinitionsResponse
Lists all network migration definitions in the account, with optional filtering.
-
#list_network_migration_deployed_stacks(params = {}) ⇒ Types::ListNetworkMigrationDeployedStacksResponse
Lists CloudFormation stacks that have been deployed as part of the network migration.
-
#list_network_migration_deployments(params = {}) ⇒ Types::ListNetworkMigrationDeployerJobResponse
Lists network migration deployment jobs and their current status.
-
#list_network_migration_executions(params = {}) ⇒ Types::ListNetworkMigrationExecutionsResponse
Lists network migration execution instances for a given definition, showing the status and progress of each execution.
-
#list_network_migration_mapper_segment_constructs(params = {}) ⇒ Types::ListNetworkMigrationMapperSegmentConstructsResponse
Lists constructs within a mapper segment, representing individual infrastructure components like VPCs, subnets, or security groups.
-
#list_network_migration_mapper_segments(params = {}) ⇒ Types::ListNetworkMigrationMapperSegmentsResponse
Lists mapper segments, which represent logical groupings of network resources to be migrated together.
-
#list_network_migration_mapping_updates(params = {}) ⇒ Types::ListNetworkMigrationMappingUpdatesResponse
Lists mapping update jobs, which apply customer modifications to the generated network mappings.
-
#list_network_migration_mappings(params = {}) ⇒ Types::ListNetworkMigrationMappingsResponse
Lists network migration mapping jobs, which analyze and create relationships between source and target network resources.
-
#list_source_server_actions(params = {}) ⇒ Types::ListSourceServerActionsResponse
List source server post migration custom actions.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List all tags for your Application Migration Service resources.
-
#list_template_actions(params = {}) ⇒ Types::ListTemplateActionsResponse
List template post migration custom actions.
-
#list_waves(params = {}) ⇒ Types::ListWavesResponse
Retrieves all waves or multiple waves by ID.
-
#mark_as_archived(params = {}) ⇒ Types::SourceServer
Archives specific Source Servers by setting the SourceServer.isArchived property to true for specified SourceServers by ID.
-
#pause_replication(params = {}) ⇒ Types::SourceServer
Pause Replication.
-
#put_source_server_action(params = {}) ⇒ Types::SourceServerActionDocument
Put source server post migration custom action.
-
#put_template_action(params = {}) ⇒ Types::TemplateActionDocument
Put template post migration custom action.
-
#remove_source_server_action(params = {}) ⇒ Struct
Remove source server post migration custom action.
-
#remove_template_action(params = {}) ⇒ Struct
Remove template post migration custom action.
-
#resume_replication(params = {}) ⇒ Types::SourceServer
Resume Replication.
-
#retry_data_replication(params = {}) ⇒ Types::SourceServer
Causes the data replication initiation sequence to begin immediately upon next Handshake for specified SourceServer IDs, regardless of when the previous initiation started.
-
#start_cutover(params = {}) ⇒ Types::StartCutoverResponse
Launches a Cutover Instance for specific Source Servers.
-
#start_export(params = {}) ⇒ Types::StartExportResponse
Start export.
-
#start_import(params = {}) ⇒ Types::StartImportResponse
Start import.
-
#start_import_file_enrichment(params = {}) ⇒ Types::StartImportFileEnrichmentResponse
Starts an import file enrichment job to process and enrich network migration import files with additional metadata and IP assignment strategies.
-
#start_network_migration_analysis(params = {}) ⇒ Types::StartNetworkMigrationAnalysisResponse
Starts a network migration analysis job to evaluate connectivity and compatibility of the migration mappings.
-
#start_network_migration_code_generation(params = {}) ⇒ Types::StartNetworkMigrationCodeGenerationResponse
Starts a code generation job to convert network migration mappings into infrastructure-as-code templates.
-
#start_network_migration_deployment(params = {}) ⇒ Types::StartNetworkMigrationDeployerJobResponse
Starts a deployment job to create the target network infrastructure based on the generated code templates.
-
#start_network_migration_mapping(params = {}) ⇒ Types::StartNetworkMigrationMappingResponse
Starts the network migration mapping process for a given network migration execution.
-
#start_network_migration_mapping_update(params = {}) ⇒ Types::StartNetworkMigrationMappingUpdateResponse
Starts a job to apply customer modifications to network migration mappings, such as changing properties.
-
#start_replication(params = {}) ⇒ Types::SourceServer
Start replication for source server irrespective of its replication type.
-
#start_test(params = {}) ⇒ Types::StartTestResponse
Launches a Test Instance for specific Source Servers.
-
#stop_replication(params = {}) ⇒ Types::SourceServer
Stop Replication.
-
#tag_resource(params = {}) ⇒ Struct
Adds or overwrites only the specified tags for the specified Application Migration Service resource or resources.
-
#terminate_target_instances(params = {}) ⇒ Types::TerminateTargetInstancesResponse
Starts a job that terminates specific launched EC2 Test and Cutover instances.
-
#unarchive_application(params = {}) ⇒ Types::Application
Unarchive application.
-
#unarchive_wave(params = {}) ⇒ Types::Wave
Unarchive wave.
-
#untag_resource(params = {}) ⇒ Struct
Deletes the specified set of tags from the specified set of Application Migration Service resources.
-
#update_application(params = {}) ⇒ Types::Application
Update application.
-
#update_connector(params = {}) ⇒ Types::Connector
Update Connector.
-
#update_launch_configuration(params = {}) ⇒ Types::LaunchConfiguration
Updates multiple LaunchConfigurations by Source Server ID.
-
#update_launch_configuration_template(params = {}) ⇒ Types::LaunchConfigurationTemplate
Updates an existing Launch Configuration Template by ID.
-
#update_network_migration_definition(params = {}) ⇒ Types::NetworkMigrationDefinition
Updates an existing network migration definition with new source or target configurations.
-
#update_network_migration_mapper_segment(params = {}) ⇒ Types::NetworkMigrationMapperSegment
Updates a mapper segment's configuration, such as changing its scope tags.
-
#update_replication_configuration(params = {}) ⇒ Types::ReplicationConfiguration
Allows you to update multiple ReplicationConfigurations by Source Server ID.
-
#update_replication_configuration_template(params = {}) ⇒ Types::ReplicationConfigurationTemplate
Updates a ReplicationConfigurationTemplate by ID.
-
#update_source_server(params = {}) ⇒ Types::SourceServer
Update Source Server.
-
#update_source_server_replication_type(params = {}) ⇒ Types::SourceServer
Allows you to change between the AGENT_BASED replication type and the SNAPSHOT_SHIPPING replication type.
-
#update_wave(params = {}) ⇒ Types::Wave
Update wave.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-mgn/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
7884 7885 7886 |
# File 'lib/aws-sdk-mgn/client.rb', line 7884 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
7887 7888 7889 |
# File 'lib/aws-sdk-mgn/client.rb', line 7887 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14 def self.new: ( |
Instance Method Details
#archive_application(params = {}) ⇒ Types::Application
Archive application.
95 |
# File 'sig/client.rbs', line 95 def archive_application: ( |
#archive_wave(params = {}) ⇒ Types::Wave
Archive wave.
114 |
# File 'sig/client.rbs', line 114 def archive_wave: ( |
#associate_applications(params = {}) ⇒ Struct
Associate applications to wave.
124 |
# File 'sig/client.rbs', line 124 def associate_applications: ( |
#associate_source_servers(params = {}) ⇒ Struct
Associate source servers to application.
135 |
# File 'sig/client.rbs', line 135 def associate_source_servers: ( |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
7857 7858 7859 7860 7861 7862 7863 7864 7865 7866 7867 7868 7869 7870 7871 7872 7873 |
# File 'lib/aws-sdk-mgn/client.rb', line 7857 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Mgn') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-mgn' context[:gem_version] = '1.77.0' Seahorse::Client::Request.new(handlers, context) end |
#change_server_life_cycle_state(params = {}) ⇒ Types::SourceServer
Allows the user to set the SourceServer.LifeCycle.state property for specific Source Server IDs to one of the following: READY_FOR_TEST or READY_FOR_CUTOVER. This command only works if the Source Server is already launchable (dataReplicationInfo.lagDuration is not null.)
160 |
# File 'sig/client.rbs', line 160 def change_server_life_cycle_state: ( |
#create_application(params = {}) ⇒ Types::Application
Create application.
183 |
# File 'sig/client.rbs', line 183 def create_application: ( |
#create_connector(params = {}) ⇒ Types::Connector
Create Connector.
201 |
# File 'sig/client.rbs', line 201 def create_connector: ( |
#create_launch_configuration_template(params = {}) ⇒ Types::LaunchConfigurationTemplate
Creates a new Launch Configuration Template.
237 |
# File 'sig/client.rbs', line 237 def create_launch_configuration_template: ( |
#create_network_migration_definition(params = {}) ⇒ Types::NetworkMigrationDefinition
Creates a new network migration definition that specifies the source and target network configuration for a migration.
289 |
# File 'sig/client.rbs', line 289 def create_network_migration_definition: ( |
#create_replication_configuration_template(params = {}) ⇒ Types::ReplicationConfigurationTemplate
Creates a new ReplicationConfigurationTemplate.
341 |
# File 'sig/client.rbs', line 341 def create_replication_configuration_template: ( |
#create_wave(params = {}) ⇒ Types::Wave
Create wave.
381 |
# File 'sig/client.rbs', line 381 def create_wave: ( |
#delete_application(params = {}) ⇒ Struct
Delete application.
393 |
# File 'sig/client.rbs', line 393 def delete_application: ( |
#delete_connector(params = {}) ⇒ Struct
Delete Connector.
400 |
# File 'sig/client.rbs', line 400 def delete_connector: ( |
#delete_job(params = {}) ⇒ Struct
Deletes a single Job by ID.
409 |
# File 'sig/client.rbs', line 409 def delete_job: ( |
#delete_launch_configuration_template(params = {}) ⇒ Struct
Deletes a single Launch Configuration Template by ID.
419 |
# File 'sig/client.rbs', line 419 def delete_launch_configuration_template: ( |
#delete_network_migration_definition(params = {}) ⇒ Struct
Deletes a network migration definition. This operation removes the migration definition and all associated metadata.
428 |
# File 'sig/client.rbs', line 428 def delete_network_migration_definition: ( |
#delete_replication_configuration_template(params = {}) ⇒ Struct
Deletes a single Replication Configuration Template by ID
437 |
# File 'sig/client.rbs', line 437 def delete_replication_configuration_template: ( |
#delete_source_server(params = {}) ⇒ Struct
Deletes a single source server by ID.
446 |
# File 'sig/client.rbs', line 446 def delete_source_server: ( |
#delete_vcenter_client(params = {}) ⇒ Struct
Deletes a given vCenter client by ID.
453 |
# File 'sig/client.rbs', line 453 def delete_vcenter_client: ( |
#delete_wave(params = {}) ⇒ Struct
Delete wave.
462 |
# File 'sig/client.rbs', line 462 def delete_wave: ( |
#describe_job_log_items(params = {}) ⇒ Types::DescribeJobLogItemsResponse
Retrieves detailed job log items with paging.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
474 |
# File 'sig/client.rbs', line 474 def describe_job_log_items: ( |
#describe_jobs(params = {}) ⇒ Types::DescribeJobsResponse
Returns a list of Jobs. Use the jobIDs and fromDate and toDate filters to limit which jobs are returned. The response is sorted by creationDateTime - latest date first. Jobs are normally created by the StartTest, StartCutover, and TerminateTargetInstances APIs. Jobs are also created by DiagnosticLaunch and TerminateDiagnosticInstances, which are APIs available only to Support and only used in response to relevant support tickets.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
488 |
# File 'sig/client.rbs', line 488 def describe_jobs: ( |
#describe_launch_configuration_templates(params = {}) ⇒ Types::DescribeLaunchConfigurationTemplatesResponse
Lists all Launch Configuration Templates, filtered by Launch Configuration Template IDs
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
506 |
# File 'sig/client.rbs', line 506 def describe_launch_configuration_templates: ( |
#describe_replication_configuration_templates(params = {}) ⇒ Types::DescribeReplicationConfigurationTemplatesResponse
Lists all ReplicationConfigurationTemplates, filtered by replication configuration template IDs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
519 |
# File 'sig/client.rbs', line 519 def describe_replication_configuration_templates: ( |
#describe_source_servers(params = {}) ⇒ Types::DescribeSourceServersResponse
Retrieves all SourceServers or multiple SourceServers by ID.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
532 |
# File 'sig/client.rbs', line 532 def describe_source_servers: ( |
#describe_vcenter_clients(params = {}) ⇒ Types::DescribeVcenterClientsResponse
Returns a list of the installed vCenter clients.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
552 |
# File 'sig/client.rbs', line 552 def describe_vcenter_clients: ( |
#disassociate_applications(params = {}) ⇒ Struct
Disassociate applications from wave.
562 |
# File 'sig/client.rbs', line 562 def disassociate_applications: ( |
#disassociate_source_servers(params = {}) ⇒ Struct
Disassociate source servers from application.
573 |
# File 'sig/client.rbs', line 573 def disassociate_source_servers: ( |
#disconnect_from_service(params = {}) ⇒ Types::SourceServer
Disconnects specific Source Servers from Application Migration Service. Data replication is stopped immediately. All AWS resources created by Application Migration Service for enabling the replication of these source servers will be terminated / deleted within 90 minutes. Launched Test or Cutover instances will NOT be terminated. If the agent on the source server has not been prevented from communicating with Application Migration Service, then it will receive a command to uninstall itself (within approximately 10 minutes). The following properties of the SourceServer will be changed immediately: dataReplicationInfo.dataReplicationState will be set to DISCONNECTED; The totalStorageBytes property for each of dataReplicationInfo.replicatedDisks will be set to zero; dataReplicationInfo.lagDuration and dataReplicationInfo.lagDuration will be nullified.
598 |
# File 'sig/client.rbs', line 598 def disconnect_from_service: ( |
#finalize_cutover(params = {}) ⇒ Types::SourceServer
Finalizes the cutover immediately for specific Source Servers. All AWS resources created by Application Migration Service for enabling the replication of these source servers will be terminated / deleted within 90 minutes. Launched Test or Cutover instances will NOT be terminated. The AWS Replication Agent will receive a command to uninstall itself (within 10 minutes). The following properties of the SourceServer will be changed immediately: dataReplicationInfo.dataReplicationState will be changed to DISCONNECTED; The SourceServer.lifeCycle.state will be changed to CUTOVER; The totalStorageBytes property for each of dataReplicationInfo.replicatedDisks will be set to zero; dataReplicationInfo.lagDuration and dataReplicationInfo.lagDuration will be nullified.
622 |
# File 'sig/client.rbs', line 622 def finalize_cutover: ( |
#get_launch_configuration(params = {}) ⇒ Types::LaunchConfiguration
Lists all LaunchConfigurations available, filtered by Source Server IDs.
644 |
# File 'sig/client.rbs', line 644 def get_launch_configuration: ( |
#get_network_migration_definition(params = {}) ⇒ Types::NetworkMigrationDefinition
Retrieves the details of a network migration definition including source and target configurations.
668 |
# File 'sig/client.rbs', line 668 def get_network_migration_definition: ( |
#get_network_migration_mapper_segment_construct(params = {}) ⇒ Types::GetNetworkMigrationMapperSegmentConstructResponse
Retrieves detailed information about a specific construct within a mapper segment, including its properties and configuration data.
678 |
# File 'sig/client.rbs', line 678 def get_network_migration_mapper_segment_construct: ( |
#get_replication_configuration(params = {}) ⇒ Types::ReplicationConfiguration
Lists all ReplicationConfigurations, filtered by Source Server ID.
709 |
# File 'sig/client.rbs', line 709 def get_replication_configuration: ( |
#initialize_service(params = {}) ⇒ Struct
Initialize Application Migration Service.
719 |
# File 'sig/client.rbs', line 719 def initialize_service: ( |
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Retrieves all applications or multiple applications by ID.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
729 |
# File 'sig/client.rbs', line 729 def list_applications: ( |
#list_connectors(params = {}) ⇒ Types::ListConnectorsResponse
List Connectors.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
747 |
# File 'sig/client.rbs', line 747 def list_connectors: ( |
#list_export_errors(params = {}) ⇒ Types::ListExportErrorsResponse
List export errors.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
762 |
# File 'sig/client.rbs', line 762 def list_export_errors: ( |
#list_exports(params = {}) ⇒ Types::ListExportsResponse
List exports.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
775 |
# File 'sig/client.rbs', line 775 def list_exports: ( |
#list_import_errors(params = {}) ⇒ Types::ListImportErrorsResponse
List import errors.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
790 |
# File 'sig/client.rbs', line 790 def list_import_errors: ( |
#list_import_file_enrichments(params = {}) ⇒ Types::ListImportFileEnrichmentsResponse
Lists import file enrichment jobs with optional filtering by job IDs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
803 |
# File 'sig/client.rbs', line 803 def list_import_file_enrichments: ( |
#list_imports(params = {}) ⇒ Types::ListImportsResponse
List imports.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
818 |
# File 'sig/client.rbs', line 818 def list_imports: ( |
#list_managed_accounts(params = {}) ⇒ Types::ListManagedAccountsResponse
List Managed Accounts.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
833 |
# File 'sig/client.rbs', line 833 def list_managed_accounts: ( |
#list_network_migration_analyses(params = {}) ⇒ Types::ListNetworkMigrationAnalysesResponse
Lists network migration analysis jobs for a specified execution. Returns information about analysis job status and results.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
845 |
# File 'sig/client.rbs', line 845 def list_network_migration_analyses: ( |
#list_network_migration_analysis_results(params = {}) ⇒ Types::ListNetworkMigrationAnalysisResultsResponse
Lists the results of network migration analyses, showing connectivity and compatibility findings for migrated resources.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
862 |
# File 'sig/client.rbs', line 862 def list_network_migration_analysis_results: ( |
#list_network_migration_code_generation_segments(params = {}) ⇒ Types::ListNetworkMigrationCodeGenerationSegmentsResponse
Lists code generation segments, which represent individual infrastructure components generated as code templates.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
879 |
# File 'sig/client.rbs', line 879 def list_network_migration_code_generation_segments: ( |
#list_network_migration_code_generations(params = {}) ⇒ Types::ListNetworkMigrationCodeGenerationsResponse
Lists network migration code generation jobs, which convert network mappings into infrastructure-as-code templates.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
896 |
# File 'sig/client.rbs', line 896 def list_network_migration_code_generations: ( |
#list_network_migration_definitions(params = {}) ⇒ Types::ListNetworkMigrationDefinitionsResponse
Lists all network migration definitions in the account, with optional filtering.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
913 |
# File 'sig/client.rbs', line 913 def list_network_migration_definitions: ( |
#list_network_migration_deployed_stacks(params = {}) ⇒ Types::ListNetworkMigrationDeployedStacksResponse
Lists CloudFormation stacks that have been deployed as part of the network migration.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
928 |
# File 'sig/client.rbs', line 928 def list_network_migration_deployed_stacks: ( |
#list_network_migration_deployments(params = {}) ⇒ Types::ListNetworkMigrationDeployerJobResponse
Lists network migration deployment jobs and their current status.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
942 |
# File 'sig/client.rbs', line 942 def list_network_migration_deployments: ( |
#list_network_migration_executions(params = {}) ⇒ Types::ListNetworkMigrationExecutionsResponse
Lists network migration execution instances for a given definition, showing the status and progress of each execution.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
959 |
# File 'sig/client.rbs', line 959 def list_network_migration_executions: ( |
#list_network_migration_mapper_segment_constructs(params = {}) ⇒ Types::ListNetworkMigrationMapperSegmentConstructsResponse
Lists constructs within a mapper segment, representing individual infrastructure components like VPCs, subnets, or security groups.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
976 |
# File 'sig/client.rbs', line 976 def list_network_migration_mapper_segment_constructs: ( |
#list_network_migration_mapper_segments(params = {}) ⇒ Types::ListNetworkMigrationMapperSegmentsResponse
Lists mapper segments, which represent logical groupings of network resources to be migrated together.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
995 |
# File 'sig/client.rbs', line 995 def list_network_migration_mapper_segments: ( |
#list_network_migration_mapping_updates(params = {}) ⇒ Types::ListNetworkMigrationMappingUpdatesResponse
Lists mapping update jobs, which apply customer modifications to the generated network mappings.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1012 |
# File 'sig/client.rbs', line 1012 def list_network_migration_mapping_updates: ( |
#list_network_migration_mappings(params = {}) ⇒ Types::ListNetworkMigrationMappingsResponse
Lists network migration mapping jobs, which analyze and create relationships between source and target network resources.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1029 |
# File 'sig/client.rbs', line 1029 def list_network_migration_mappings: ( |
#list_source_server_actions(params = {}) ⇒ Types::ListSourceServerActionsResponse
List source server post migration custom actions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1046 |
# File 'sig/client.rbs', line 1046 def list_source_server_actions: ( |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List all tags for your Application Migration Service resources.
1062 |
# File 'sig/client.rbs', line 1062 def list_tags_for_resource: ( |
#list_template_actions(params = {}) ⇒ Types::ListTemplateActionsResponse
List template post migration custom actions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1073 |
# File 'sig/client.rbs', line 1073 def list_template_actions: ( |
#list_waves(params = {}) ⇒ Types::ListWavesResponse
Retrieves all waves or multiple waves by ID.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1089 |
# File 'sig/client.rbs', line 1089 def list_waves: ( |
#mark_as_archived(params = {}) ⇒ Types::SourceServer
Archives specific Source Servers by setting the SourceServer.isArchived property to true for specified SourceServers by ID. This command only works for SourceServers with a lifecycle state that equals DISCONNECTED or CUTOVER.
1118 |
# File 'sig/client.rbs', line 1118 def mark_as_archived: ( |
#pause_replication(params = {}) ⇒ Types::SourceServer
Pause Replication.
1142 |
# File 'sig/client.rbs', line 1142 def pause_replication: ( |
#put_source_server_action(params = {}) ⇒ Types::SourceServerActionDocument
Put source server post migration custom action.
1164 |
# File 'sig/client.rbs', line 1164 def put_source_server_action: ( |
#put_template_action(params = {}) ⇒ Types::TemplateActionDocument
Put template post migration custom action.
1206 |
# File 'sig/client.rbs', line 1206 def put_template_action: ( |
#remove_source_server_action(params = {}) ⇒ Struct
Remove source server post migration custom action.
1235 |
# File 'sig/client.rbs', line 1235 def remove_source_server_action: ( |
#remove_template_action(params = {}) ⇒ Struct
Remove template post migration custom action.
1246 |
# File 'sig/client.rbs', line 1246 def remove_template_action: ( |
#resume_replication(params = {}) ⇒ Types::SourceServer
Resume Replication.
1270 |
# File 'sig/client.rbs', line 1270 def resume_replication: ( |
#retry_data_replication(params = {}) ⇒ Types::SourceServer
Causes the data replication initiation sequence to begin immediately upon next Handshake for specified SourceServer IDs, regardless of when the previous initiation started. This command will not work if the SourceServer is not stalled or is in a DISCONNECTED or STOPPED state.
1294 |
# File 'sig/client.rbs', line 1294 def retry_data_replication: ( |
#start_cutover(params = {}) ⇒ Types::StartCutoverResponse
Launches a Cutover Instance for specific Source Servers. This command starts a LAUNCH job whose initiatedBy property is StartCutover and changes the SourceServer.lifeCycle.state property to CUTTING_OVER.
1305 |
# File 'sig/client.rbs', line 1305 def start_cutover: ( |
#start_export(params = {}) ⇒ Types::StartExportResponse
Start export.
1317 |
# File 'sig/client.rbs', line 1317 def start_export: ( |
#start_import(params = {}) ⇒ Types::StartImportResponse
Start import.
1330 |
# File 'sig/client.rbs', line 1330 def start_import: ( |
#start_import_file_enrichment(params = {}) ⇒ Types::StartImportFileEnrichmentResponse
Starts an import file enrichment job to process and enrich network migration import files with additional metadata and IP assignment strategies.
1346 |
# File 'sig/client.rbs', line 1346 def start_import_file_enrichment: ( |
#start_network_migration_analysis(params = {}) ⇒ Types::StartNetworkMigrationAnalysisResponse
Starts a network migration analysis job to evaluate connectivity and compatibility of the migration mappings.
1367 |
# File 'sig/client.rbs', line 1367 def start_network_migration_analysis: ( |
#start_network_migration_code_generation(params = {}) ⇒ Types::StartNetworkMigrationCodeGenerationResponse
Starts a code generation job to convert network migration mappings into infrastructure-as-code templates.
1378 |
# File 'sig/client.rbs', line 1378 def start_network_migration_code_generation: ( |
#start_network_migration_deployment(params = {}) ⇒ Types::StartNetworkMigrationDeployerJobResponse
Starts a deployment job to create the target network infrastructure based on the generated code templates.
1390 |
# File 'sig/client.rbs', line 1390 def start_network_migration_deployment: ( |
#start_network_migration_mapping(params = {}) ⇒ Types::StartNetworkMigrationMappingResponse
Starts the network migration mapping process for a given network migration execution.
1401 |
# File 'sig/client.rbs', line 1401 def start_network_migration_mapping: ( |
#start_network_migration_mapping_update(params = {}) ⇒ Types::StartNetworkMigrationMappingUpdateResponse
Starts a job to apply customer modifications to network migration mappings, such as changing properties.
1413 |
# File 'sig/client.rbs', line 1413 def start_network_migration_mapping_update: ( |
#start_replication(params = {}) ⇒ Types::SourceServer
Start replication for source server irrespective of its replication type.
1475 |
# File 'sig/client.rbs', line 1475 def start_replication: ( |
#start_test(params = {}) ⇒ Types::StartTestResponse
Launches a Test Instance for specific Source Servers. This command starts a LAUNCH job whose initiatedBy property is StartTest and changes the SourceServer.lifeCycle.state property to TESTING.
1486 |
# File 'sig/client.rbs', line 1486 def start_test: ( |
#stop_replication(params = {}) ⇒ Types::SourceServer
Stop Replication.
1511 |
# File 'sig/client.rbs', line 1511 def stop_replication: ( |
#tag_resource(params = {}) ⇒ Struct
Adds or overwrites only the specified tags for the specified Application Migration Service resource or resources. When you specify an existing tag key, the value is overwritten with the new value. Each resource can have a maximum of 50 tags. Each tag consists of a key and optional value.
1518 |
# File 'sig/client.rbs', line 1518 def tag_resource: ( |
#terminate_target_instances(params = {}) ⇒ Types::TerminateTargetInstancesResponse
Starts a job that terminates specific launched EC2 Test and Cutover instances. This command will not work for any Source Server with a lifecycle.state of TESTING, CUTTING_OVER, or CUTOVER.
1529 |
# File 'sig/client.rbs', line 1529 def terminate_target_instances: ( |
#unarchive_application(params = {}) ⇒ Types::Application
Unarchive application.
1550 |
# File 'sig/client.rbs', line 1550 def unarchive_application: ( |
#unarchive_wave(params = {}) ⇒ Types::Wave
Unarchive wave.
1569 |
# File 'sig/client.rbs', line 1569 def unarchive_wave: ( |
#untag_resource(params = {}) ⇒ Struct
Deletes the specified set of tags from the specified set of Application Migration Service resources.
1576 |
# File 'sig/client.rbs', line 1576 def untag_resource: ( |
#update_application(params = {}) ⇒ Types::Application
Update application.
1596 |
# File 'sig/client.rbs', line 1596 def update_application: ( |
#update_connector(params = {}) ⇒ Types::Connector
Update Connector.
1614 |
# File 'sig/client.rbs', line 1614 def update_connector: ( |
#update_launch_configuration(params = {}) ⇒ Types::LaunchConfiguration
Updates multiple LaunchConfigurations by Source Server ID.
LEGACY_BIOS | UEFI | USE_SOURCE
1642 |
# File 'sig/client.rbs', line 1642 def update_launch_configuration: ( |
#update_launch_configuration_template(params = {}) ⇒ Types::LaunchConfigurationTemplate
Updates an existing Launch Configuration Template by ID.
1683 |
# File 'sig/client.rbs', line 1683 def update_launch_configuration_template: ( |
#update_network_migration_definition(params = {}) ⇒ Types::NetworkMigrationDefinition
Updates an existing network migration definition with new source or target configurations.
1735 |
# File 'sig/client.rbs', line 1735 def update_network_migration_definition: ( |
#update_network_migration_mapper_segment(params = {}) ⇒ Types::NetworkMigrationMapperSegment
Updates a mapper segment's configuration, such as changing its scope tags.
1783 |
# File 'sig/client.rbs', line 1783 def update_network_migration_mapper_segment: ( |
#update_replication_configuration(params = {}) ⇒ Types::ReplicationConfiguration
Allows you to update multiple ReplicationConfigurations by Source Server ID.
1814 |
# File 'sig/client.rbs', line 1814 def update_replication_configuration: ( |
#update_replication_configuration_template(params = {}) ⇒ Types::ReplicationConfigurationTemplate
Updates a ReplicationConfigurationTemplate by ID.
1875 |
# File 'sig/client.rbs', line 1875 def update_replication_configuration_template: ( |
#update_source_server(params = {}) ⇒ Types::SourceServer
Update Source Server.
1921 |
# File 'sig/client.rbs', line 1921 def update_source_server: ( |
#update_source_server_replication_type(params = {}) ⇒ Types::SourceServer
Allows you to change between the AGENT_BASED replication type and the SNAPSHOT_SHIPPING replication type.
SNAPSHOT_SHIPPING should be used for agentless replication.
1952 |
# File 'sig/client.rbs', line 1952 def update_source_server_replication_type: ( |
#update_wave(params = {}) ⇒ Types::Wave
Update wave.
1972 |
# File 'sig/client.rbs', line 1972 def update_wave: ( |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
7877 7878 7879 |
# File 'lib/aws-sdk-mgn/client.rb', line 7877 def waiter_names [] end |