Method: Aws::Mgn::Client#start_replication
- Defined in:
- lib/aws-sdk-mgn/client.rb
#start_replication(params = {}) ⇒ Types::SourceServer
Start replication for source server irrespective of its replication type.
Examples:
Request syntax with placeholder values
Request syntax with placeholder values
resp = client.start_replication({
source_server_id: "SourceServerID", # required
account_id: "AccountID",
})
Response structure
Response structure
resp.source_server_id #=> String
resp.arn #=> String
resp.is_archived #=> Boolean
resp.tags #=> Hash
resp.tags["TagKey"] #=> String
resp.launched_instance.ec2_instance_id #=> String
resp.launched_instance.job_id #=> String
resp.launched_instance.first_boot #=> String, one of "WAITING", "SUCCEEDED", "UNKNOWN", "STOPPED"
resp.data_replication_info.lag_duration #=> String
resp.data_replication_info.eta_date_time #=> String
resp.data_replication_info.replicated_disks #=> Array
resp.data_replication_info.replicated_disks[0].device_name #=> String
resp.data_replication_info.replicated_disks[0].total_storage_bytes #=> Integer
resp.data_replication_info.replicated_disks[0].replicated_storage_bytes #=> Integer
resp.data_replication_info.replicated_disks[0].rescanned_storage_bytes #=> Integer
resp.data_replication_info.replicated_disks[0].backlogged_storage_bytes #=> Integer
resp.data_replication_info.data_replication_state #=> String, one of "STOPPED", "INITIATING", "INITIAL_SYNC", "BACKLOG", "CREATING_SNAPSHOT", "CONTINUOUS", "PAUSED", "RESCAN", "STALLED", "DISCONNECTED", "PENDING_SNAPSHOT_SHIPPING", "SHIPPING_SNAPSHOT"
resp.data_replication_info.data_replication_initiation.start_date_time #=> String
resp.data_replication_info.data_replication_initiation.next_attempt_date_time #=> String
resp.data_replication_info.data_replication_initiation.steps #=> Array
resp.data_replication_info.data_replication_initiation.steps[0].name #=> String, one of "WAIT", "CREATE_SECURITY_GROUP", "LAUNCH_REPLICATION_SERVER", "BOOT_REPLICATION_SERVER", "AUTHENTICATE_WITH_SERVICE", "DOWNLOAD_REPLICATION_SOFTWARE", "CREATE_STAGING_DISKS", "ATTACH_STAGING_DISKS", "PAIR_REPLICATION_SERVER_WITH_AGENT", "CONNECT_AGENT_TO_REPLICATION_SERVER", "START_DATA_TRANSFER"
resp.data_replication_info.data_replication_initiation.steps[0].status #=> String, one of "NOT_STARTED", "IN_PROGRESS", "SUCCEEDED", "FAILED", "SKIPPED"
resp.data_replication_info.data_replication_error.error #=> String, one of "AGENT_NOT_SEEN", "SNAPSHOTS_FAILURE", "NOT_CONVERGING", "UNSTABLE_NETWORK", "FAILED_TO_CREATE_SECURITY_GROUP", "FAILED_TO_LAUNCH_REPLICATION_SERVER", "FAILED_TO_BOOT_REPLICATION_SERVER", "FAILED_TO_AUTHENTICATE_WITH_SERVICE", "FAILED_TO_DOWNLOAD_REPLICATION_SOFTWARE", "FAILED_TO_CREATE_STAGING_DISKS", "FAILED_TO_ATTACH_STAGING_DISKS", "FAILED_TO_PAIR_REPLICATION_SERVER_WITH_AGENT", "FAILED_TO_CONNECT_AGENT_TO_REPLICATION_SERVER", "FAILED_TO_START_DATA_TRANSFER", "UNSUPPORTED_VM_CONFIGURATION", "LAST_SNAPSHOT_JOB_FAILED"
resp.data_replication_info.data_replication_error.raw_error #=> String
resp.data_replication_info.last_snapshot_date_time #=> String
resp.data_replication_info.replicator_id #=> String
resp.life_cycle.added_to_service_date_time #=> String
resp.life_cycle.first_byte_date_time #=> String
resp.life_cycle.elapsed_replication_duration #=> String
resp.life_cycle.last_seen_by_service_date_time #=> String
resp.life_cycle.last_test.initiated.api_call_date_time #=> String
resp.life_cycle.last_test.initiated.job_id #=> String
resp.life_cycle.last_test.reverted.api_call_date_time #=> String
resp.life_cycle.last_test.finalized.api_call_date_time #=> String
resp.life_cycle.last_cutover.initiated.api_call_date_time #=> String
resp.life_cycle.last_cutover.initiated.job_id #=> String
resp.life_cycle.last_cutover.reverted.api_call_date_time #=> String
resp.life_cycle.last_cutover.finalized.api_call_date_time #=> String
resp.life_cycle.state #=> String, one of "STOPPED", "NOT_READY", "READY_FOR_TEST", "TESTING", "READY_FOR_CUTOVER", "CUTTING_OVER", "CUTOVER", "DISCONNECTED", "DISCOVERED", "PENDING_INSTALLATION"
resp.source_properties.last_updated_date_time #=> String
resp.source_properties.recommended_instance_type #=> String
resp.source_properties.identification_hints.fqdn #=> String
resp.source_properties.identification_hints.hostname #=> String
resp.source_properties.identification_hints.vm_ware_uuid #=> String
resp.source_properties.identification_hints.aws_instance_id #=> String
resp.source_properties.identification_hints.vm_path #=> String
resp.source_properties.network_interfaces #=> Array
resp.source_properties.network_interfaces[0].mac_address #=> String
resp.source_properties.network_interfaces[0].ips #=> Array
resp.source_properties.network_interfaces[0].ips[0] #=> String
resp.source_properties.network_interfaces[0].is_primary #=> Boolean
resp.source_properties.disks #=> Array
resp.source_properties.disks[0].device_name #=> String
resp.source_properties.disks[0].bytes #=> Integer
resp.source_properties.cpus #=> Array
resp.source_properties.cpus[0].cores #=> Integer
resp.source_properties.cpus[0].model_name #=> String
resp.source_properties.ram_bytes #=> Integer
resp.source_properties.os.full_string #=> String
resp.replication_type #=> String, one of "AGENT_BASED", "SNAPSHOT_SHIPPING"
resp.vcenter_client_id #=> String
resp.application_id #=> String
resp.user_provided_id #=> String
resp.fqdn_for_action_framework #=> String
resp.connector_action.credentials_secret_arn #=> String
resp.connector_action.connector_arn #=> String
Parameters:
-
params
(Hash)
(defaults to: {})
—
({})
Options Hash (params):
-
:source_server_id
(required, String)
—
ID of source server on which to start replication.
-
:account_id
(String)
—
Account ID on which to start replication.
Returns:
-
(Types::SourceServer)
—
Returns a response object which responds to the following methods:
-
#source_server_id => String
-
#arn => String
-
#is_archived => Boolean
-
#tags => Hash<String,String>
-
#launched_instance => Types::LaunchedInstance
-
#data_replication_info => Types::DataReplicationInfo
-
#life_cycle => Types::LifeCycle
-
#source_properties => Types::SourceProperties
-
#replication_type => String
-
#vcenter_client_id => String
-
#application_id => String
-
#user_provided_id => String
-
#fqdn_for_action_framework => String
-
#connector_action => Types::SourceServerConnectorAction
-
See Also:
3976 3977 3978 3979 |
# File 'lib/aws-sdk-mgn/client.rb', line 3976 def start_replication(params = {}, options = {}) req = build_request(:start_replication, params) req.send_request(options) end |