Class: Aws::Mgn::Types::CreateNetworkMigrationDefinitionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mgn/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:tags, :scope_tags]

Instance Attribute Summary collapse

Instance Attribute Details

#cidr_mappings ⇒ Array<Types::CidrMapping>

A list of CIDR mappings that map original source CIDR ranges to updated target CIDR ranges. CIDR mappings can be provided only when vpcProvisioningStrategy is set to USE_EXISTING.

Returns:



605
606
607
608
609
610
611
612
613
614
615
616
617
618
# File 'lib/aws-sdk-mgn/types.rb', line 605

class CreateNetworkMigrationDefinitionRequest < Struct.new(
  :name,
  :description,
  :source_configurations,
  :target_s3_configuration,
  :target_network,
  :target_deployment,
  :vpc_provisioning_strategy,
  :cidr_mappings,
  :tags,
  :scope_tags)
  SENSITIVE = [:tags, :scope_tags]
  include Aws::Structure
end

#description ⇒ String

A description of the network migration definition.

Returns:

  • (String)


605
606
607
608
609
610
611
612
613
614
615
616
617
618
# File 'lib/aws-sdk-mgn/types.rb', line 605

class CreateNetworkMigrationDefinitionRequest < Struct.new(
  :name,
  :description,
  :source_configurations,
  :target_s3_configuration,
  :target_network,
  :target_deployment,
  :vpc_provisioning_strategy,
  :cidr_mappings,
  :tags,
  :scope_tags)
  SENSITIVE = [:tags, :scope_tags]
  include Aws::Structure
end

#name ⇒ String

The name of the network migration definition.

Returns:

  • (String)


605
606
607
608
609
610
611
612
613
614
615
616
617
618
# File 'lib/aws-sdk-mgn/types.rb', line 605

class CreateNetworkMigrationDefinitionRequest < Struct.new(
  :name,
  :description,
  :source_configurations,
  :target_s3_configuration,
  :target_network,
  :target_deployment,
  :vpc_provisioning_strategy,
  :cidr_mappings,
  :tags,
  :scope_tags)
  SENSITIVE = [:tags, :scope_tags]
  include Aws::Structure
end

#scope_tags ⇒ Hash<String,String>

Scope tags for the network migration definition to control access and organization.

Returns:

  • (Hash<String,String>)


605
606
607
608
609
610
611
612
613
614
615
616
617
618
# File 'lib/aws-sdk-mgn/types.rb', line 605

class CreateNetworkMigrationDefinitionRequest < Struct.new(
  :name,
  :description,
  :source_configurations,
  :target_s3_configuration,
  :target_network,
  :target_deployment,
  :vpc_provisioning_strategy,
  :cidr_mappings,
  :tags,
  :scope_tags)
  SENSITIVE = [:tags, :scope_tags]
  include Aws::Structure
end

#source_configurations ⇒ Array<Types::SourceConfiguration>

A list of source configurations for the network migration.

Returns:



605
606
607
608
609
610
611
612
613
614
615
616
617
618
# File 'lib/aws-sdk-mgn/types.rb', line 605

class CreateNetworkMigrationDefinitionRequest < Struct.new(
  :name,
  :description,
  :source_configurations,
  :target_s3_configuration,
  :target_network,
  :target_deployment,
  :vpc_provisioning_strategy,
  :cidr_mappings,
  :tags,
  :scope_tags)
  SENSITIVE = [:tags, :scope_tags]
  include Aws::Structure
end

#tags ⇒ Hash<String,String>

Tags to assign to the network migration definition.

Returns:

  • (Hash<String,String>)


605
606
607
608
609
610
611
612
613
614
615
616
617
618
# File 'lib/aws-sdk-mgn/types.rb', line 605

class CreateNetworkMigrationDefinitionRequest < Struct.new(
  :name,
  :description,
  :source_configurations,
  :target_s3_configuration,
  :target_network,
  :target_deployment,
  :vpc_provisioning_strategy,
  :cidr_mappings,
  :tags,
  :scope_tags)
  SENSITIVE = [:tags, :scope_tags]
  include Aws::Structure
end

#target_deployment ⇒ String

The target deployment configuration for the migrated network.

Returns:

  • (String)


605
606
607
608
609
610
611
612
613
614
615
616
617
618
# File 'lib/aws-sdk-mgn/types.rb', line 605

class CreateNetworkMigrationDefinitionRequest < Struct.new(
  :name,
  :description,
  :source_configurations,
  :target_s3_configuration,
  :target_network,
  :target_deployment,
  :vpc_provisioning_strategy,
  :cidr_mappings,
  :tags,
  :scope_tags)
  SENSITIVE = [:tags, :scope_tags]
  include Aws::Structure
end

#target_network ⇒ Types::TargetNetwork

The target network configuration including topology and CIDR ranges.



605
606
607
608
609
610
611
612
613
614
615
616
617
618
# File 'lib/aws-sdk-mgn/types.rb', line 605

class CreateNetworkMigrationDefinitionRequest < Struct.new(
  :name,
  :description,
  :source_configurations,
  :target_s3_configuration,
  :target_network,
  :target_deployment,
  :vpc_provisioning_strategy,
  :cidr_mappings,
  :tags,
  :scope_tags)
  SENSITIVE = [:tags, :scope_tags]
  include Aws::Structure
end

#target_s3_configuration ⇒ Types::TargetS3Configuration

The S3 configuration for storing the target network artifacts.



605
606
607
608
609
610
611
612
613
614
615
616
617
618
# File 'lib/aws-sdk-mgn/types.rb', line 605

class CreateNetworkMigrationDefinitionRequest < Struct.new(
  :name,
  :description,
  :source_configurations,
  :target_s3_configuration,
  :target_network,
  :target_deployment,
  :vpc_provisioning_strategy,
  :cidr_mappings,
  :tags,
  :scope_tags)
  SENSITIVE = [:tags, :scope_tags]
  include Aws::Structure
end

#vpc_provisioning_strategy ⇒ String

Specifies whether to create new target VPCs or use existing ones. Set to CREATE_NEW to provision new target VPCs as part of the migration, or USE_EXISTING to migrate into existing VPCs in the target account.

Returns:

  • (String)


605
606
607
608
609
610
611
612
613
614
615
616
617
618
# File 'lib/aws-sdk-mgn/types.rb', line 605

class CreateNetworkMigrationDefinitionRequest < Struct.new(
  :name,
  :description,
  :source_configurations,
  :target_s3_configuration,
  :target_network,
  :target_deployment,
  :vpc_provisioning_strategy,
  :cidr_mappings,
  :tags,
  :scope_tags)
  SENSITIVE = [:tags, :scope_tags]
  include Aws::Structure
end