Class: Aws::Mgn::Types::DeleteNetworkMigrationDefinitionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Mgn::Types::DeleteNetworkMigrationDefinitionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mgn/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#network_migration_definition_id ⇒ String
The unique identifier of the network migration definition to delete.
Instance Attribute Details
#network_migration_definition_id ⇒ String
The unique identifier of the network migration definition to delete.
935 936 937 938 939 |
# File 'lib/aws-sdk-mgn/types.rb', line 935 class DeleteNetworkMigrationDefinitionRequest < Struct.new( :network_migration_definition_id) SENSITIVE = [] include Aws::Structure end |