Class: Aws::Mgn::Types::DescribeReplicationConfigurationTemplatesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Mgn::Types::DescribeReplicationConfigurationTemplatesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mgn/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#items ⇒ Array<Types::ReplicationConfigurationTemplate>
Request to describe Replication Configuration template by items.
-
#next_token ⇒ String
Request to describe Replication Configuration template by next token.
Instance Attribute Details
#items ⇒ Array<Types::ReplicationConfigurationTemplate>
Request to describe Replication Configuration template by items.
1207 1208 1209 1210 1211 1212 |
# File 'lib/aws-sdk-mgn/types.rb', line 1207 class DescribeReplicationConfigurationTemplatesResponse < Struct.new( :items, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Request to describe Replication Configuration template by next token.
1207 1208 1209 1210 1211 1212 |
# File 'lib/aws-sdk-mgn/types.rb', line 1207 class DescribeReplicationConfigurationTemplatesResponse < Struct.new( :items, :next_token) SENSITIVE = [] include Aws::Structure end |