Class: Aws::Mgn::Types::Disk
- Inherits:
-
Struct
- Object
- Struct
- Aws::Mgn::Types::Disk
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mgn/types.rb
Overview
The disk identifier.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bytes ⇒ Integer
The amount of storage on the disk in bytes.
-
#device_name ⇒ String
The disk or device name.
Instance Attribute Details
#bytes ⇒ Integer
The amount of storage on the disk in bytes.
1299 1300 1301 1302 1303 1304 |
# File 'lib/aws-sdk-mgn/types.rb', line 1299 class Disk < Struct.new( :device_name, :bytes) SENSITIVE = [] include Aws::Structure end |
#device_name ⇒ String
The disk or device name.
1299 1300 1301 1302 1303 1304 |
# File 'lib/aws-sdk-mgn/types.rb', line 1299 class Disk < Struct.new( :device_name, :bytes) SENSITIVE = [] include Aws::Structure end |