Class: Aws::Mgn::Types::GetNetworkMigrationDefinitionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Mgn::Types::GetNetworkMigrationDefinitionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mgn/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#network_migration_definition_id ⇒ String
The unique identifier of the network migration definition to retrieve.
Instance Attribute Details
#network_migration_definition_id ⇒ String
The unique identifier of the network migration definition to retrieve.
1722 1723 1724 1725 1726 |
# File 'lib/aws-sdk-mgn/types.rb', line 1722 class GetNetworkMigrationDefinitionRequest < Struct.new( :network_migration_definition_id) SENSITIVE = [] include Aws::Structure end |