Class: Aws::Mgn::Types::GetNetworkMigrationMapperSegmentConstructRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Mgn::Types::GetNetworkMigrationMapperSegmentConstructRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mgn/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#construct_id ⇒ String
The unique identifier of the construct within the segment.
-
#network_migration_definition_id ⇒ String
The unique identifier of the network migration definition.
-
#network_migration_execution_id ⇒ String
The unique identifier of the network migration execution.
-
#segment_id ⇒ String
The unique identifier of the mapper segment.
Instance Attribute Details
#construct_id ⇒ String
The unique identifier of the construct within the segment.
1678 1679 1680 1681 1682 1683 1684 1685 |
# File 'lib/aws-sdk-mgn/types.rb', line 1678 class GetNetworkMigrationMapperSegmentConstructRequest < Struct.new( :network_migration_definition_id, :network_migration_execution_id, :segment_id, :construct_id) SENSITIVE = [] include Aws::Structure end |
#network_migration_definition_id ⇒ String
The unique identifier of the network migration definition.
1678 1679 1680 1681 1682 1683 1684 1685 |
# File 'lib/aws-sdk-mgn/types.rb', line 1678 class GetNetworkMigrationMapperSegmentConstructRequest < Struct.new( :network_migration_definition_id, :network_migration_execution_id, :segment_id, :construct_id) SENSITIVE = [] include Aws::Structure end |
#network_migration_execution_id ⇒ String
The unique identifier of the network migration execution.
1678 1679 1680 1681 1682 1683 1684 1685 |
# File 'lib/aws-sdk-mgn/types.rb', line 1678 class GetNetworkMigrationMapperSegmentConstructRequest < Struct.new( :network_migration_definition_id, :network_migration_execution_id, :segment_id, :construct_id) SENSITIVE = [] include Aws::Structure end |
#segment_id ⇒ String
The unique identifier of the mapper segment.
1678 1679 1680 1681 1682 1683 1684 1685 |
# File 'lib/aws-sdk-mgn/types.rb', line 1678 class GetNetworkMigrationMapperSegmentConstructRequest < Struct.new( :network_migration_definition_id, :network_migration_execution_id, :segment_id, :construct_id) SENSITIVE = [] include Aws::Structure end |