Class: Aws::Mgn::Types::ImportFileEnrichment

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mgn/types.rb

Overview

Details about an import file enrichment job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#checksum ⇒ Types::Checksum

The checksum of the enriched file for integrity verification.

Returns:



1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
# File 'lib/aws-sdk-mgn/types.rb', line 1894

class ImportFileEnrichment < Struct.new(
  :job_id,
  :created_at,
  :ended_at,
  :status,
  :status_details,
  :checksum,
  :s3_bucket_target)
  SENSITIVE = []
  include Aws::Structure
end

#created_at ⇒ Time

The timestamp when the enrichment job was created.

Returns:

  • (Time)


1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
# File 'lib/aws-sdk-mgn/types.rb', line 1894

class ImportFileEnrichment < Struct.new(
  :job_id,
  :created_at,
  :ended_at,
  :status,
  :status_details,
  :checksum,
  :s3_bucket_target)
  SENSITIVE = []
  include Aws::Structure
end

#ended_at ⇒ Time

The timestamp when the enrichment job completed or failed.

Returns:

  • (Time)


1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
# File 'lib/aws-sdk-mgn/types.rb', line 1894

class ImportFileEnrichment < Struct.new(
  :job_id,
  :created_at,
  :ended_at,
  :status,
  :status_details,
  :checksum,
  :s3_bucket_target)
  SENSITIVE = []
  include Aws::Structure
end

#job_id ⇒ String

The unique identifier of the import file enrichment job.

Returns:

  • (String)


1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
# File 'lib/aws-sdk-mgn/types.rb', line 1894

class ImportFileEnrichment < Struct.new(
  :job_id,
  :created_at,
  :ended_at,
  :status,
  :status_details,
  :checksum,
  :s3_bucket_target)
  SENSITIVE = []
  include Aws::Structure
end

#s3_bucket_target ⇒ Types::EnrichmentTargetS3Configuration

The target S3 configuration for the enriched import file.



1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
# File 'lib/aws-sdk-mgn/types.rb', line 1894

class ImportFileEnrichment < Struct.new(
  :job_id,
  :created_at,
  :ended_at,
  :status,
  :status_details,
  :checksum,
  :s3_bucket_target)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The current status of the import file enrichment job.

Returns:

  • (String)


1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
# File 'lib/aws-sdk-mgn/types.rb', line 1894

class ImportFileEnrichment < Struct.new(
  :job_id,
  :created_at,
  :ended_at,
  :status,
  :status_details,
  :checksum,
  :s3_bucket_target)
  SENSITIVE = []
  include Aws::Structure
end

#status_details ⇒ String

Detailed status information about the enrichment job.

Returns:

  • (String)


1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
# File 'lib/aws-sdk-mgn/types.rb', line 1894

class ImportFileEnrichment < Struct.new(
  :job_id,
  :created_at,
  :ended_at,
  :status,
  :status_details,
  :checksum,
  :s3_bucket_target)
  SENSITIVE = []
  include Aws::Structure
end