Class: Aws::Mgn::Types::JobLogEventData
- Inherits:
-
Struct
- Object
- Struct
- Aws::Mgn::Types::JobLogEventData
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mgn/types.rb
Overview
Job log data
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attempt_count ⇒ Integer
Retries for this operation.
-
#conversion_server_id ⇒ String
Job Event conversion Server ID.
-
#max_attempts_count ⇒ Integer
The maximum number of retries that will be attempted if this operation failed.
-
#raw_error ⇒ String
Job error.
-
#source_server_id ⇒ String
Job Event Source Server ID.
-
#target_instance_id ⇒ String
Job Event Target instance ID.
Instance Attribute Details
#attempt_count ⇒ Integer
Retries for this operation.
2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 |
# File 'lib/aws-sdk-mgn/types.rb', line 2135 class JobLogEventData < Struct.new( :source_server_id, :conversion_server_id, :target_instance_id, :raw_error, :attempt_count, :max_attempts_count) SENSITIVE = [] include Aws::Structure end |
#conversion_server_id ⇒ String
Job Event conversion Server ID.
2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 |
# File 'lib/aws-sdk-mgn/types.rb', line 2135 class JobLogEventData < Struct.new( :source_server_id, :conversion_server_id, :target_instance_id, :raw_error, :attempt_count, :max_attempts_count) SENSITIVE = [] include Aws::Structure end |
#max_attempts_count ⇒ Integer
The maximum number of retries that will be attempted if this operation failed.
2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 |
# File 'lib/aws-sdk-mgn/types.rb', line 2135 class JobLogEventData < Struct.new( :source_server_id, :conversion_server_id, :target_instance_id, :raw_error, :attempt_count, :max_attempts_count) SENSITIVE = [] include Aws::Structure end |
#raw_error ⇒ String
Job error.
2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 |
# File 'lib/aws-sdk-mgn/types.rb', line 2135 class JobLogEventData < Struct.new( :source_server_id, :conversion_server_id, :target_instance_id, :raw_error, :attempt_count, :max_attempts_count) SENSITIVE = [] include Aws::Structure end |
#source_server_id ⇒ String
Job Event Source Server ID.
2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 |
# File 'lib/aws-sdk-mgn/types.rb', line 2135 class JobLogEventData < Struct.new( :source_server_id, :conversion_server_id, :target_instance_id, :raw_error, :attempt_count, :max_attempts_count) SENSITIVE = [] include Aws::Structure end |
#target_instance_id ⇒ String
Job Event Target instance ID.
2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 |
# File 'lib/aws-sdk-mgn/types.rb', line 2135 class JobLogEventData < Struct.new( :source_server_id, :conversion_server_id, :target_instance_id, :raw_error, :attempt_count, :max_attempts_count) SENSITIVE = [] include Aws::Structure end |