Class: Aws::Mgn::Types::JobPostLaunchActionsLaunchStatus

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mgn/types.rb

Overview

Launch Status of the Job Post Launch Actions.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#execution_idString

AWS Systems Manager Document’s execution ID of the of the Job Post Launch Actions.



2172
2173
2174
2175
2176
2177
2178
2179
2180
# File 'lib/aws-sdk-mgn/types.rb', line 2172

class JobPostLaunchActionsLaunchStatus < Struct.new(
  :ssm_document,
  :ssm_document_type,
  :execution_id,
  :execution_status,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#execution_statusString

AWS Systems Manager Document’s execution status.



2172
2173
2174
2175
2176
2177
2178
2179
2180
# File 'lib/aws-sdk-mgn/types.rb', line 2172

class JobPostLaunchActionsLaunchStatus < Struct.new(
  :ssm_document,
  :ssm_document_type,
  :execution_id,
  :execution_status,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reasonString

AWS Systems Manager Document’s failure reason.



2172
2173
2174
2175
2176
2177
2178
2179
2180
# File 'lib/aws-sdk-mgn/types.rb', line 2172

class JobPostLaunchActionsLaunchStatus < Struct.new(
  :ssm_document,
  :ssm_document_type,
  :execution_id,
  :execution_status,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#ssm_documentTypes::SsmDocument

AWS Systems Manager’s Document of the of the Job Post Launch Actions.



2172
2173
2174
2175
2176
2177
2178
2179
2180
# File 'lib/aws-sdk-mgn/types.rb', line 2172

class JobPostLaunchActionsLaunchStatus < Struct.new(
  :ssm_document,
  :ssm_document_type,
  :execution_id,
  :execution_status,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#ssm_document_typeString

AWS Systems Manager Document type.



2172
2173
2174
2175
2176
2177
2178
2179
2180
# File 'lib/aws-sdk-mgn/types.rb', line 2172

class JobPostLaunchActionsLaunchStatus < Struct.new(
  :ssm_document,
  :ssm_document_type,
  :execution_id,
  :execution_status,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end