Class: Aws::Mgn::Types::LaunchConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Mgn::Types::LaunchConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mgn/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#boot_mode ⇒ String
Launch configuration boot mode.
-
#copy_private_ip ⇒ Boolean
Copy Private IP during Launch Configuration.
-
#copy_tags ⇒ Boolean
Copy Tags during Launch Configuration.
-
#ec2_launch_template_id ⇒ String
Launch configuration EC2 Launch template ID.
-
#enable_map_auto_tagging ⇒ Boolean
Enable map auto tagging.
-
#launch_disposition ⇒ String
Launch disposition for launch configuration.
-
#licensing ⇒ Types::Licensing
Launch configuration OS licensing.
-
#map_auto_tagging_mpe_id ⇒ String
Map auto tagging MPE ID.
-
#name ⇒ String
Launch configuration name.
-
#post_launch_actions ⇒ Types::PostLaunchActions
Post Launch Actions to executed on the Test or Cutover instance.
-
#source_server_id ⇒ String
Launch configuration Source Server ID.
-
#target_instance_type_right_sizing_method ⇒ String
Launch configuration Target instance type right sizing method.
Instance Attribute Details
#boot_mode ⇒ String
Launch configuration boot mode.
2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 |
# File 'lib/aws-sdk-mgn/types.rb', line 2232 class LaunchConfiguration < Struct.new( :source_server_id, :name, :ec2_launch_template_id, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :boot_mode, :post_launch_actions, :enable_map_auto_tagging, :map_auto_tagging_mpe_id) SENSITIVE = [] include Aws::Structure end |
#copy_private_ip ⇒ Boolean
Copy Private IP during Launch Configuration.
2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 |
# File 'lib/aws-sdk-mgn/types.rb', line 2232 class LaunchConfiguration < Struct.new( :source_server_id, :name, :ec2_launch_template_id, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :boot_mode, :post_launch_actions, :enable_map_auto_tagging, :map_auto_tagging_mpe_id) SENSITIVE = [] include Aws::Structure end |
#copy_tags ⇒ Boolean
Copy Tags during Launch Configuration.
2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 |
# File 'lib/aws-sdk-mgn/types.rb', line 2232 class LaunchConfiguration < Struct.new( :source_server_id, :name, :ec2_launch_template_id, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :boot_mode, :post_launch_actions, :enable_map_auto_tagging, :map_auto_tagging_mpe_id) SENSITIVE = [] include Aws::Structure end |
#ec2_launch_template_id ⇒ String
Launch configuration EC2 Launch template ID.
2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 |
# File 'lib/aws-sdk-mgn/types.rb', line 2232 class LaunchConfiguration < Struct.new( :source_server_id, :name, :ec2_launch_template_id, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :boot_mode, :post_launch_actions, :enable_map_auto_tagging, :map_auto_tagging_mpe_id) SENSITIVE = [] include Aws::Structure end |
#enable_map_auto_tagging ⇒ Boolean
Enable map auto tagging.
2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 |
# File 'lib/aws-sdk-mgn/types.rb', line 2232 class LaunchConfiguration < Struct.new( :source_server_id, :name, :ec2_launch_template_id, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :boot_mode, :post_launch_actions, :enable_map_auto_tagging, :map_auto_tagging_mpe_id) SENSITIVE = [] include Aws::Structure end |
#launch_disposition ⇒ String
Launch disposition for launch configuration.
2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 |
# File 'lib/aws-sdk-mgn/types.rb', line 2232 class LaunchConfiguration < Struct.new( :source_server_id, :name, :ec2_launch_template_id, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :boot_mode, :post_launch_actions, :enable_map_auto_tagging, :map_auto_tagging_mpe_id) SENSITIVE = [] include Aws::Structure end |
#licensing ⇒ Types::Licensing
Launch configuration OS licensing.
2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 |
# File 'lib/aws-sdk-mgn/types.rb', line 2232 class LaunchConfiguration < Struct.new( :source_server_id, :name, :ec2_launch_template_id, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :boot_mode, :post_launch_actions, :enable_map_auto_tagging, :map_auto_tagging_mpe_id) SENSITIVE = [] include Aws::Structure end |
#map_auto_tagging_mpe_id ⇒ String
Map auto tagging MPE ID.
2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 |
# File 'lib/aws-sdk-mgn/types.rb', line 2232 class LaunchConfiguration < Struct.new( :source_server_id, :name, :ec2_launch_template_id, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :boot_mode, :post_launch_actions, :enable_map_auto_tagging, :map_auto_tagging_mpe_id) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Launch configuration name.
2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 |
# File 'lib/aws-sdk-mgn/types.rb', line 2232 class LaunchConfiguration < Struct.new( :source_server_id, :name, :ec2_launch_template_id, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :boot_mode, :post_launch_actions, :enable_map_auto_tagging, :map_auto_tagging_mpe_id) SENSITIVE = [] include Aws::Structure end |
#post_launch_actions ⇒ Types::PostLaunchActions
Post Launch Actions to executed on the Test or Cutover instance.
2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 |
# File 'lib/aws-sdk-mgn/types.rb', line 2232 class LaunchConfiguration < Struct.new( :source_server_id, :name, :ec2_launch_template_id, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :boot_mode, :post_launch_actions, :enable_map_auto_tagging, :map_auto_tagging_mpe_id) SENSITIVE = [] include Aws::Structure end |
#source_server_id ⇒ String
Launch configuration Source Server ID.
2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 |
# File 'lib/aws-sdk-mgn/types.rb', line 2232 class LaunchConfiguration < Struct.new( :source_server_id, :name, :ec2_launch_template_id, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :boot_mode, :post_launch_actions, :enable_map_auto_tagging, :map_auto_tagging_mpe_id) SENSITIVE = [] include Aws::Structure end |
#target_instance_type_right_sizing_method ⇒ String
Launch configuration Target instance type right sizing method.
2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 |
# File 'lib/aws-sdk-mgn/types.rb', line 2232 class LaunchConfiguration < Struct.new( :source_server_id, :name, :ec2_launch_template_id, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :boot_mode, :post_launch_actions, :enable_map_auto_tagging, :map_auto_tagging_mpe_id) SENSITIVE = [] include Aws::Structure end |