Class: Aws::Mgn::Types::ListSourceServerActionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mgn/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_id ⇒ String

Account ID to return when listing source server post migration custom actions.

Returns:

  • (String)


3911
3912
3913
3914
3915
3916
3917
3918
3919
# File 'lib/aws-sdk-mgn/types.rb', line 3911

class ListSourceServerActionsRequest < Struct.new(
  :source_server_id,
  :filters,
  :max_results,
  :next_token,
  :account_id)
  SENSITIVE = []
  include Aws::Structure
end

#filters ⇒ Types::SourceServerActionsRequestFilters

Filters to apply when listing source server post migration custom actions.



3911
3912
3913
3914
3915
3916
3917
3918
3919
# File 'lib/aws-sdk-mgn/types.rb', line 3911

class ListSourceServerActionsRequest < Struct.new(
  :source_server_id,
  :filters,
  :max_results,
  :next_token,
  :account_id)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

Maximum amount of items to return when listing source server post migration custom actions.

Returns:

  • (Integer)


3911
3912
3913
3914
3915
3916
3917
3918
3919
# File 'lib/aws-sdk-mgn/types.rb', line 3911

class ListSourceServerActionsRequest < Struct.new(
  :source_server_id,
  :filters,
  :max_results,
  :next_token,
  :account_id)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

Next token to use when listing source server post migration custom actions.

Returns:

  • (String)


3911
3912
3913
3914
3915
3916
3917
3918
3919
# File 'lib/aws-sdk-mgn/types.rb', line 3911

class ListSourceServerActionsRequest < Struct.new(
  :source_server_id,
  :filters,
  :max_results,
  :next_token,
  :account_id)
  SENSITIVE = []
  include Aws::Structure
end

#source_server_id ⇒ String

Source server ID.

Returns:

  • (String)


3911
3912
3913
3914
3915
3916
3917
3918
3919
# File 'lib/aws-sdk-mgn/types.rb', line 3911

class ListSourceServerActionsRequest < Struct.new(
  :source_server_id,
  :filters,
  :max_results,
  :next_token,
  :account_id)
  SENSITIVE = []
  include Aws::Structure
end