Class: Aws::Mgn::Types::ListTemplateActionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mgn/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filters ⇒ Types::TemplateActionsRequestFilters

Filters to apply when listing template post migration custom actions.



3984
3985
3986
3987
3988
3989
3990
3991
# File 'lib/aws-sdk-mgn/types.rb', line 3984

class ListTemplateActionsRequest < Struct.new(
  :launch_configuration_template_id,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#launch_configuration_template_id ⇒ String

Launch configuration template ID.

Returns:

  • (String)


3984
3985
3986
3987
3988
3989
3990
3991
# File 'lib/aws-sdk-mgn/types.rb', line 3984

class ListTemplateActionsRequest < Struct.new(
  :launch_configuration_template_id,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

Maximum amount of items to return when listing template post migration custom actions.

Returns:

  • (Integer)


3984
3985
3986
3987
3988
3989
3990
3991
# File 'lib/aws-sdk-mgn/types.rb', line 3984

class ListTemplateActionsRequest < Struct.new(
  :launch_configuration_template_id,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

Next token to use when listing template post migration custom actions.

Returns:

  • (String)


3984
3985
3986
3987
3988
3989
3990
3991
# File 'lib/aws-sdk-mgn/types.rb', line 3984

class ListTemplateActionsRequest < Struct.new(
  :launch_configuration_template_id,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end