Class: Aws::Mgn::Types::MergeOperation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mgn/types.rb

Overview

An operation that merges constructs from different segments into the target construct.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#merge_constructsArray<Types::MergeConstruct>

The list of constructs to merge into the target.

Returns:



4090
4091
4092
4093
4094
# File 'lib/aws-sdk-mgn/types.rb', line 4090

class MergeOperation < Struct.new(
  :merge_constructs)
  SENSITIVE = []
  include Aws::Structure
end