Class: Aws::Mgn::Types::NetworkMigrationAnalysisResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Mgn::Types::NetworkMigrationAnalysisResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mgn/types.rb
Overview
The result of a network migration analysis operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#analysis_result ⇒ String
The detailed analysis findings and recommendations.
-
#analyzer_type ⇒ String
The type of analyzer that generated this result.
-
#job_id ⇒ String
The unique identifier of the analysis job that generated this result.
-
#network_migration_definition_id ⇒ String
The unique identifier of the network migration definition.
-
#network_migration_execution_id ⇒ String
The unique identifier of the network migration execution.
-
#source ⇒ Types::NetworkMigrationAnalysisResultSource
The source resource that was analyzed.
-
#status ⇒ String
The status of the analysis result.
-
#target ⇒ Types::NetworkMigrationAnalysisResultTarget
The target resource in the analysis.
Instance Attribute Details
#analysis_result ⇒ String
The detailed analysis findings and recommendations.
4089 4090 4091 4092 4093 4094 4095 4096 4097 4098 4099 4100 |
# File 'lib/aws-sdk-mgn/types.rb', line 4089 class NetworkMigrationAnalysisResult < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :analyzer_type, :source, :target, :status, :analysis_result) SENSITIVE = [] include Aws::Structure end |
#analyzer_type ⇒ String
The type of analyzer that generated this result.
4089 4090 4091 4092 4093 4094 4095 4096 4097 4098 4099 4100 |
# File 'lib/aws-sdk-mgn/types.rb', line 4089 class NetworkMigrationAnalysisResult < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :analyzer_type, :source, :target, :status, :analysis_result) SENSITIVE = [] include Aws::Structure end |
#job_id ⇒ String
The unique identifier of the analysis job that generated this result.
4089 4090 4091 4092 4093 4094 4095 4096 4097 4098 4099 4100 |
# File 'lib/aws-sdk-mgn/types.rb', line 4089 class NetworkMigrationAnalysisResult < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :analyzer_type, :source, :target, :status, :analysis_result) SENSITIVE = [] include Aws::Structure end |
#network_migration_definition_id ⇒ String
The unique identifier of the network migration definition.
4089 4090 4091 4092 4093 4094 4095 4096 4097 4098 4099 4100 |
# File 'lib/aws-sdk-mgn/types.rb', line 4089 class NetworkMigrationAnalysisResult < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :analyzer_type, :source, :target, :status, :analysis_result) SENSITIVE = [] include Aws::Structure end |
#network_migration_execution_id ⇒ String
The unique identifier of the network migration execution.
4089 4090 4091 4092 4093 4094 4095 4096 4097 4098 4099 4100 |
# File 'lib/aws-sdk-mgn/types.rb', line 4089 class NetworkMigrationAnalysisResult < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :analyzer_type, :source, :target, :status, :analysis_result) SENSITIVE = [] include Aws::Structure end |
#source ⇒ Types::NetworkMigrationAnalysisResultSource
The source resource that was analyzed.
4089 4090 4091 4092 4093 4094 4095 4096 4097 4098 4099 4100 |
# File 'lib/aws-sdk-mgn/types.rb', line 4089 class NetworkMigrationAnalysisResult < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :analyzer_type, :source, :target, :status, :analysis_result) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the analysis result.
4089 4090 4091 4092 4093 4094 4095 4096 4097 4098 4099 4100 |
# File 'lib/aws-sdk-mgn/types.rb', line 4089 class NetworkMigrationAnalysisResult < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :analyzer_type, :source, :target, :status, :analysis_result) SENSITIVE = [] include Aws::Structure end |
#target ⇒ Types::NetworkMigrationAnalysisResultTarget
The target resource in the analysis.
4089 4090 4091 4092 4093 4094 4095 4096 4097 4098 4099 4100 |
# File 'lib/aws-sdk-mgn/types.rb', line 4089 class NetworkMigrationAnalysisResult < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :analyzer_type, :source, :target, :status, :analysis_result) SENSITIVE = [] include Aws::Structure end |