Class: Aws::Mgn::Types::NetworkMigrationCodeGenerationSegment

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mgn/types.rb

Overview

A segment of generated code representing a logical grouping of infrastructure resources.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#artifacts ⇒ Array<Types::NetworkMigrationCodeGenerationArtifact>

A list of artifacts generated for this segment.



4436
4437
4438
4439
4440
4441
4442
4443
4444
4445
4446
4447
4448
4449
# File 'lib/aws-sdk-mgn/types.rb', line 4436

class NetworkMigrationCodeGenerationSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :logical_id,
  :mapper_segment_id,
  :artifacts,
  :referenced_segments,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_at ⇒ Time

The timestamp when the segment was created.

Returns:

  • (Time)


4436
4437
4438
4439
4440
4441
4442
4443
4444
4445
4446
4447
4448
4449
# File 'lib/aws-sdk-mgn/types.rb', line 4436

class NetworkMigrationCodeGenerationSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :logical_id,
  :mapper_segment_id,
  :artifacts,
  :referenced_segments,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#job_id ⇒ String

The unique identifier of the code generation job.

Returns:

  • (String)


4436
4437
4438
4439
4440
4441
4442
4443
4444
4445
4446
4447
4448
4449
# File 'lib/aws-sdk-mgn/types.rb', line 4436

class NetworkMigrationCodeGenerationSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :logical_id,
  :mapper_segment_id,
  :artifacts,
  :referenced_segments,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#logical_id ⇒ String

The logical identifier for the segment.

Returns:

  • (String)


4436
4437
4438
4439
4440
4441
4442
4443
4444
4445
4446
4447
4448
4449
# File 'lib/aws-sdk-mgn/types.rb', line 4436

class NetworkMigrationCodeGenerationSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :logical_id,
  :mapper_segment_id,
  :artifacts,
  :referenced_segments,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#mapper_segment_id ⇒ String

The ID of the mapper segment that this code generation segment was created from.

Returns:

  • (String)


4436
4437
4438
4439
4440
4441
4442
4443
4444
4445
4446
4447
4448
4449
# File 'lib/aws-sdk-mgn/types.rb', line 4436

class NetworkMigrationCodeGenerationSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :logical_id,
  :mapper_segment_id,
  :artifacts,
  :referenced_segments,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#network_migration_definition_id ⇒ String

The unique identifier of the network migration definition.

Returns:

  • (String)


4436
4437
4438
4439
4440
4441
4442
4443
4444
4445
4446
4447
4448
4449
# File 'lib/aws-sdk-mgn/types.rb', line 4436

class NetworkMigrationCodeGenerationSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :logical_id,
  :mapper_segment_id,
  :artifacts,
  :referenced_segments,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#network_migration_execution_id ⇒ String

The unique identifier of the network migration execution.

Returns:

  • (String)


4436
4437
4438
4439
4440
4441
4442
4443
4444
4445
4446
4447
4448
4449
# File 'lib/aws-sdk-mgn/types.rb', line 4436

class NetworkMigrationCodeGenerationSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :logical_id,
  :mapper_segment_id,
  :artifacts,
  :referenced_segments,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#referenced_segments ⇒ Array<String>

A list of other segments that this segment depends on or references.

Returns:

  • (Array<String>)


4436
4437
4438
4439
4440
4441
4442
4443
4444
4445
4446
4447
4448
4449
# File 'lib/aws-sdk-mgn/types.rb', line 4436

class NetworkMigrationCodeGenerationSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :logical_id,
  :mapper_segment_id,
  :artifacts,
  :referenced_segments,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#segment_id ⇒ String

The unique identifier of the segment.

Returns:

  • (String)


4436
4437
4438
4439
4440
4441
4442
4443
4444
4445
4446
4447
4448
4449
# File 'lib/aws-sdk-mgn/types.rb', line 4436

class NetworkMigrationCodeGenerationSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :logical_id,
  :mapper_segment_id,
  :artifacts,
  :referenced_segments,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#segment_type ⇒ String

The type of the segment.

Returns:

  • (String)


4436
4437
4438
4439
4440
4441
4442
4443
4444
4445
4446
4447
4448
4449
# File 'lib/aws-sdk-mgn/types.rb', line 4436

class NetworkMigrationCodeGenerationSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :logical_id,
  :mapper_segment_id,
  :artifacts,
  :referenced_segments,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end