Class: Aws::Mgn::Types::NetworkMigrationDeployedStackDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mgn/types.rb

Overview

Details about a CloudFormation stack that has been deployed as part of the network migration.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#failed_resources ⇒ Array<Types::NetworkMigrationFailedResourceDetails>

A list of resources that failed to deploy.



4601
4602
4603
4604
4605
4606
4607
4608
4609
4610
# File 'lib/aws-sdk-mgn/types.rb', line 4601

class NetworkMigrationDeployedStackDetails < Struct.new(
  :status,
  :stack_physical_id,
  :stack_logical_id,
  :segment_id,
  :target_account,
  :failed_resources)
  SENSITIVE = []
  include Aws::Structure
end

#segment_id ⇒ String

The ID of the segment that this stack was deployed for.

Returns:

  • (String)


4601
4602
4603
4604
4605
4606
4607
4608
4609
4610
# File 'lib/aws-sdk-mgn/types.rb', line 4601

class NetworkMigrationDeployedStackDetails < Struct.new(
  :status,
  :stack_physical_id,
  :stack_logical_id,
  :segment_id,
  :target_account,
  :failed_resources)
  SENSITIVE = []
  include Aws::Structure
end

#stack_logical_id ⇒ String

The logical ID of the stack.

Returns:

  • (String)


4601
4602
4603
4604
4605
4606
4607
4608
4609
4610
# File 'lib/aws-sdk-mgn/types.rb', line 4601

class NetworkMigrationDeployedStackDetails < Struct.new(
  :status,
  :stack_physical_id,
  :stack_logical_id,
  :segment_id,
  :target_account,
  :failed_resources)
  SENSITIVE = []
  include Aws::Structure
end

#stack_physical_id ⇒ String

The physical ID of the CloudFormation stack.

Returns:

  • (String)


4601
4602
4603
4604
4605
4606
4607
4608
4609
4610
# File 'lib/aws-sdk-mgn/types.rb', line 4601

class NetworkMigrationDeployedStackDetails < Struct.new(
  :status,
  :stack_physical_id,
  :stack_logical_id,
  :segment_id,
  :target_account,
  :failed_resources)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The current status of the deployed stack.

Returns:

  • (String)


4601
4602
4603
4604
4605
4606
4607
4608
4609
4610
# File 'lib/aws-sdk-mgn/types.rb', line 4601

class NetworkMigrationDeployedStackDetails < Struct.new(
  :status,
  :stack_physical_id,
  :stack_logical_id,
  :segment_id,
  :target_account,
  :failed_resources)
  SENSITIVE = []
  include Aws::Structure
end

#target_account ⇒ String

The target AWS account where the stack was deployed.

Returns:

  • (String)


4601
4602
4603
4604
4605
4606
4607
4608
4609
4610
# File 'lib/aws-sdk-mgn/types.rb', line 4601

class NetworkMigrationDeployedStackDetails < Struct.new(
  :status,
  :stack_physical_id,
  :stack_logical_id,
  :segment_id,
  :target_account,
  :failed_resources)
  SENSITIVE = []
  include Aws::Structure
end