Class: Aws::Mgn::Types::NetworkMigrationExecution

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mgn/types.rb

Overview

Details about a network migration execution instance.

Constant Summary collapse

SENSITIVE =
[:tags]

Instance Attribute Summary collapse

Instance Attribute Details

#activity ⇒ String

The current activity being performed in the execution.

Returns:

  • (String)


4693
4694
4695
4696
4697
4698
4699
4700
4701
4702
4703
4704
# File 'lib/aws-sdk-mgn/types.rb', line 4693

class NetworkMigrationExecution < Struct.new(
  :network_migration_definition_id,
  :network_migration_execution_id,
  :status,
  :stage,
  :activity,
  :created_at,
  :updated_at,
  :tags)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#created_at ⇒ Time

The timestamp when the execution was created.

Returns:

  • (Time)


4693
4694
4695
4696
4697
4698
4699
4700
4701
4702
4703
4704
# File 'lib/aws-sdk-mgn/types.rb', line 4693

class NetworkMigrationExecution < Struct.new(
  :network_migration_definition_id,
  :network_migration_execution_id,
  :status,
  :stage,
  :activity,
  :created_at,
  :updated_at,
  :tags)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#network_migration_definition_id ⇒ String

The unique identifier of the network migration definition used by this execution.

Returns:

  • (String)


4693
4694
4695
4696
4697
4698
4699
4700
4701
4702
4703
4704
# File 'lib/aws-sdk-mgn/types.rb', line 4693

class NetworkMigrationExecution < Struct.new(
  :network_migration_definition_id,
  :network_migration_execution_id,
  :status,
  :stage,
  :activity,
  :created_at,
  :updated_at,
  :tags)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#network_migration_execution_id ⇒ String

The unique identifier of the execution.

Returns:

  • (String)


4693
4694
4695
4696
4697
4698
4699
4700
4701
4702
4703
4704
# File 'lib/aws-sdk-mgn/types.rb', line 4693

class NetworkMigrationExecution < Struct.new(
  :network_migration_definition_id,
  :network_migration_execution_id,
  :status,
  :stage,
  :activity,
  :created_at,
  :updated_at,
  :tags)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#stage ⇒ String

The current stage of the execution in the migration workflow.

Returns:

  • (String)


4693
4694
4695
4696
4697
4698
4699
4700
4701
4702
4703
4704
# File 'lib/aws-sdk-mgn/types.rb', line 4693

class NetworkMigrationExecution < Struct.new(
  :network_migration_definition_id,
  :network_migration_execution_id,
  :status,
  :stage,
  :activity,
  :created_at,
  :updated_at,
  :tags)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#status ⇒ String

The current status of the execution.

Returns:

  • (String)


4693
4694
4695
4696
4697
4698
4699
4700
4701
4702
4703
4704
# File 'lib/aws-sdk-mgn/types.rb', line 4693

class NetworkMigrationExecution < Struct.new(
  :network_migration_definition_id,
  :network_migration_execution_id,
  :status,
  :stage,
  :activity,
  :created_at,
  :updated_at,
  :tags)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#tags ⇒ Hash<String,String>

Tags assigned to the execution.

Returns:

  • (Hash<String,String>)


4693
4694
4695
4696
4697
4698
4699
4700
4701
4702
4703
4704
# File 'lib/aws-sdk-mgn/types.rb', line 4693

class NetworkMigrationExecution < Struct.new(
  :network_migration_definition_id,
  :network_migration_execution_id,
  :status,
  :stage,
  :activity,
  :created_at,
  :updated_at,
  :tags)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#updated_at ⇒ Time

The timestamp when the execution was last updated.

Returns:

  • (Time)


4693
4694
4695
4696
4697
4698
4699
4700
4701
4702
4703
4704
# File 'lib/aws-sdk-mgn/types.rb', line 4693

class NetworkMigrationExecution < Struct.new(
  :network_migration_definition_id,
  :network_migration_execution_id,
  :status,
  :stage,
  :activity,
  :created_at,
  :updated_at,
  :tags)
  SENSITIVE = [:tags]
  include Aws::Structure
end