Class: Aws::Mgn::Types::NetworkMigrationMapperSegment

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mgn/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:scope_tags]

Instance Attribute Summary collapse

Instance Attribute Details

#checksum ⇒ Types::Checksum

The checksum of the segment data for integrity verification.

Returns:



4794
4795
4796
4797
4798
4799
4800
4801
4802
4803
4804
4805
4806
4807
4808
4809
4810
4811
4812
# File 'lib/aws-sdk-mgn/types.rb', line 4794

class NetworkMigrationMapperSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :name,
  :description,
  :logical_id,
  :checksum,
  :output_s3_configuration,
  :created_at,
  :updated_at,
  :scope_tags,
  :target_account,
  :referenced_segments)
  SENSITIVE = [:scope_tags]
  include Aws::Structure
end

#created_at ⇒ Time

The timestamp when the segment was created.

Returns:

  • (Time)


4794
4795
4796
4797
4798
4799
4800
4801
4802
4803
4804
4805
4806
4807
4808
4809
4810
4811
4812
# File 'lib/aws-sdk-mgn/types.rb', line 4794

class NetworkMigrationMapperSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :name,
  :description,
  :logical_id,
  :checksum,
  :output_s3_configuration,
  :created_at,
  :updated_at,
  :scope_tags,
  :target_account,
  :referenced_segments)
  SENSITIVE = [:scope_tags]
  include Aws::Structure
end

#description ⇒ String

A description of the segment.

Returns:

  • (String)


4794
4795
4796
4797
4798
4799
4800
4801
4802
4803
4804
4805
4806
4807
4808
4809
4810
4811
4812
# File 'lib/aws-sdk-mgn/types.rb', line 4794

class NetworkMigrationMapperSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :name,
  :description,
  :logical_id,
  :checksum,
  :output_s3_configuration,
  :created_at,
  :updated_at,
  :scope_tags,
  :target_account,
  :referenced_segments)
  SENSITIVE = [:scope_tags]
  include Aws::Structure
end

#job_id ⇒ String

The unique identifier of the job that created this segment.

Returns:

  • (String)


4794
4795
4796
4797
4798
4799
4800
4801
4802
4803
4804
4805
4806
4807
4808
4809
4810
4811
4812
# File 'lib/aws-sdk-mgn/types.rb', line 4794

class NetworkMigrationMapperSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :name,
  :description,
  :logical_id,
  :checksum,
  :output_s3_configuration,
  :created_at,
  :updated_at,
  :scope_tags,
  :target_account,
  :referenced_segments)
  SENSITIVE = [:scope_tags]
  include Aws::Structure
end

#logical_id ⇒ String

The logical identifier for the segment in the infrastructure code.

Returns:

  • (String)


4794
4795
4796
4797
4798
4799
4800
4801
4802
4803
4804
4805
4806
4807
4808
4809
4810
4811
4812
# File 'lib/aws-sdk-mgn/types.rb', line 4794

class NetworkMigrationMapperSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :name,
  :description,
  :logical_id,
  :checksum,
  :output_s3_configuration,
  :created_at,
  :updated_at,
  :scope_tags,
  :target_account,
  :referenced_segments)
  SENSITIVE = [:scope_tags]
  include Aws::Structure
end

#name ⇒ String

The name of the segment.

Returns:

  • (String)


4794
4795
4796
4797
4798
4799
4800
4801
4802
4803
4804
4805
4806
4807
4808
4809
4810
4811
4812
# File 'lib/aws-sdk-mgn/types.rb', line 4794

class NetworkMigrationMapperSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :name,
  :description,
  :logical_id,
  :checksum,
  :output_s3_configuration,
  :created_at,
  :updated_at,
  :scope_tags,
  :target_account,
  :referenced_segments)
  SENSITIVE = [:scope_tags]
  include Aws::Structure
end

#network_migration_definition_id ⇒ String

The unique identifier of the network migration definition.

Returns:

  • (String)


4794
4795
4796
4797
4798
4799
4800
4801
4802
4803
4804
4805
4806
4807
4808
4809
4810
4811
4812
# File 'lib/aws-sdk-mgn/types.rb', line 4794

class NetworkMigrationMapperSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :name,
  :description,
  :logical_id,
  :checksum,
  :output_s3_configuration,
  :created_at,
  :updated_at,
  :scope_tags,
  :target_account,
  :referenced_segments)
  SENSITIVE = [:scope_tags]
  include Aws::Structure
end

#network_migration_execution_id ⇒ String

The unique identifier of the network migration execution.

Returns:

  • (String)


4794
4795
4796
4797
4798
4799
4800
4801
4802
4803
4804
4805
4806
4807
4808
4809
4810
4811
4812
# File 'lib/aws-sdk-mgn/types.rb', line 4794

class NetworkMigrationMapperSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :name,
  :description,
  :logical_id,
  :checksum,
  :output_s3_configuration,
  :created_at,
  :updated_at,
  :scope_tags,
  :target_account,
  :referenced_segments)
  SENSITIVE = [:scope_tags]
  include Aws::Structure
end

#output_s3_configuration ⇒ Types::S3Configuration

The S3 location where segment artifacts are stored.



4794
4795
4796
4797
4798
4799
4800
4801
4802
4803
4804
4805
4806
4807
4808
4809
4810
4811
4812
# File 'lib/aws-sdk-mgn/types.rb', line 4794

class NetworkMigrationMapperSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :name,
  :description,
  :logical_id,
  :checksum,
  :output_s3_configuration,
  :created_at,
  :updated_at,
  :scope_tags,
  :target_account,
  :referenced_segments)
  SENSITIVE = [:scope_tags]
  include Aws::Structure
end

#referenced_segments ⇒ Array<String>

A list of other segments that this segment depends on or references.

Returns:

  • (Array<String>)


4794
4795
4796
4797
4798
4799
4800
4801
4802
4803
4804
4805
4806
4807
4808
4809
4810
4811
4812
# File 'lib/aws-sdk-mgn/types.rb', line 4794

class NetworkMigrationMapperSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :name,
  :description,
  :logical_id,
  :checksum,
  :output_s3_configuration,
  :created_at,
  :updated_at,
  :scope_tags,
  :target_account,
  :referenced_segments)
  SENSITIVE = [:scope_tags]
  include Aws::Structure
end

#scope_tags ⇒ Hash<String,String>

Scope tags for the segment.

Returns:

  • (Hash<String,String>)


4794
4795
4796
4797
4798
4799
4800
4801
4802
4803
4804
4805
4806
4807
4808
4809
4810
4811
4812
# File 'lib/aws-sdk-mgn/types.rb', line 4794

class NetworkMigrationMapperSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :name,
  :description,
  :logical_id,
  :checksum,
  :output_s3_configuration,
  :created_at,
  :updated_at,
  :scope_tags,
  :target_account,
  :referenced_segments)
  SENSITIVE = [:scope_tags]
  include Aws::Structure
end

#segment_id ⇒ String

The unique identifier of the segment.

Returns:

  • (String)


4794
4795
4796
4797
4798
4799
4800
4801
4802
4803
4804
4805
4806
4807
4808
4809
4810
4811
4812
# File 'lib/aws-sdk-mgn/types.rb', line 4794

class NetworkMigrationMapperSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :name,
  :description,
  :logical_id,
  :checksum,
  :output_s3_configuration,
  :created_at,
  :updated_at,
  :scope_tags,
  :target_account,
  :referenced_segments)
  SENSITIVE = [:scope_tags]
  include Aws::Structure
end

#segment_type ⇒ String

The category of the network migration segment. A segment groups the network constructs (such as VPCs, subnets, and security groups) that are migrated together. Valid values: WORKLOAD, APPLIANCE.

Returns:

  • (String)


4794
4795
4796
4797
4798
4799
4800
4801
4802
4803
4804
4805
4806
4807
4808
4809
4810
4811
4812
# File 'lib/aws-sdk-mgn/types.rb', line 4794

class NetworkMigrationMapperSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :name,
  :description,
  :logical_id,
  :checksum,
  :output_s3_configuration,
  :created_at,
  :updated_at,
  :scope_tags,
  :target_account,
  :referenced_segments)
  SENSITIVE = [:scope_tags]
  include Aws::Structure
end

#target_account ⇒ String

The target AWS account where this segment will be deployed.

Returns:

  • (String)


4794
4795
4796
4797
4798
4799
4800
4801
4802
4803
4804
4805
4806
4807
4808
4809
4810
4811
4812
# File 'lib/aws-sdk-mgn/types.rb', line 4794

class NetworkMigrationMapperSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :name,
  :description,
  :logical_id,
  :checksum,
  :output_s3_configuration,
  :created_at,
  :updated_at,
  :scope_tags,
  :target_account,
  :referenced_segments)
  SENSITIVE = [:scope_tags]
  include Aws::Structure
end

#updated_at ⇒ Time

The timestamp when the segment was last updated.

Returns:

  • (Time)


4794
4795
4796
4797
4798
4799
4800
4801
4802
4803
4804
4805
4806
4807
4808
4809
4810
4811
4812
# File 'lib/aws-sdk-mgn/types.rb', line 4794

class NetworkMigrationMapperSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :name,
  :description,
  :logical_id,
  :checksum,
  :output_s3_configuration,
  :created_at,
  :updated_at,
  :scope_tags,
  :target_account,
  :referenced_segments)
  SENSITIVE = [:scope_tags]
  include Aws::Structure
end