Class: Aws::Mgn::Types::NetworkMigrationMapperSegmentConstruct

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mgn/types.rb

Overview

Represents a construct within a mapper segment. A construct is an individual infrastructure component such as a VPC, subnet, security group, route table, or other network resource that is part of the network migration.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#construct_idString

The unique identifier of the construct.

Returns:



4678
4679
4680
4681
4682
4683
4684
4685
4686
4687
4688
4689
# File 'lib/aws-sdk-mgn/types.rb', line 4678

class NetworkMigrationMapperSegmentConstruct < Struct.new(
  :construct_id,
  :construct_type,
  :name,
  :description,
  :logical_id,
  :created_at,
  :updated_at,
  :properties)
  SENSITIVE = []
  include Aws::Structure
end

#construct_typeString

The type of the construct, such as VPC, subnet, security group, or route table.

Returns:



4678
4679
4680
4681
4682
4683
4684
4685
4686
4687
4688
4689
# File 'lib/aws-sdk-mgn/types.rb', line 4678

class NetworkMigrationMapperSegmentConstruct < Struct.new(
  :construct_id,
  :construct_type,
  :name,
  :description,
  :logical_id,
  :created_at,
  :updated_at,
  :properties)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The timestamp when the construct was created.

Returns:



4678
4679
4680
4681
4682
4683
4684
4685
4686
4687
4688
4689
# File 'lib/aws-sdk-mgn/types.rb', line 4678

class NetworkMigrationMapperSegmentConstruct < Struct.new(
  :construct_id,
  :construct_type,
  :name,
  :description,
  :logical_id,
  :created_at,
  :updated_at,
  :properties)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the construct.

Returns:



4678
4679
4680
4681
4682
4683
4684
4685
4686
4687
4688
4689
# File 'lib/aws-sdk-mgn/types.rb', line 4678

class NetworkMigrationMapperSegmentConstruct < Struct.new(
  :construct_id,
  :construct_type,
  :name,
  :description,
  :logical_id,
  :created_at,
  :updated_at,
  :properties)
  SENSITIVE = []
  include Aws::Structure
end

#logical_idString

The logical identifier for the construct in the infrastructure code.

Returns:



4678
4679
4680
4681
4682
4683
4684
4685
4686
4687
4688
4689
# File 'lib/aws-sdk-mgn/types.rb', line 4678

class NetworkMigrationMapperSegmentConstruct < Struct.new(
  :construct_id,
  :construct_type,
  :name,
  :description,
  :logical_id,
  :created_at,
  :updated_at,
  :properties)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the construct.

Returns:



4678
4679
4680
4681
4682
4683
4684
4685
4686
4687
4688
4689
# File 'lib/aws-sdk-mgn/types.rb', line 4678

class NetworkMigrationMapperSegmentConstruct < Struct.new(
  :construct_id,
  :construct_type,
  :name,
  :description,
  :logical_id,
  :created_at,
  :updated_at,
  :properties)
  SENSITIVE = []
  include Aws::Structure
end

#propertiesHash<String,String>

The properties and configuration of the construct.

Returns:



4678
4679
4680
4681
4682
4683
4684
4685
4686
4687
4688
4689
# File 'lib/aws-sdk-mgn/types.rb', line 4678

class NetworkMigrationMapperSegmentConstruct < Struct.new(
  :construct_id,
  :construct_type,
  :name,
  :description,
  :logical_id,
  :created_at,
  :updated_at,
  :properties)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The timestamp when the construct was last updated.

Returns:



4678
4679
4680
4681
4682
4683
4684
4685
4686
4687
4688
4689
# File 'lib/aws-sdk-mgn/types.rb', line 4678

class NetworkMigrationMapperSegmentConstruct < Struct.new(
  :construct_id,
  :construct_type,
  :name,
  :description,
  :logical_id,
  :created_at,
  :updated_at,
  :properties)
  SENSITIVE = []
  include Aws::Structure
end