Class: Aws::Mgn::Types::PostLaunchActionsStatus

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mgn/types.rb

Overview

Status of the Post Launch Actions running on the Test or Cutover instance.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#post_launch_actions_launch_status_listArray<Types::JobPostLaunchActionsLaunchStatus>

List of Post Launch Action status.



5051
5052
5053
5054
5055
5056
# File 'lib/aws-sdk-mgn/types.rb', line 5051

class PostLaunchActionsStatus < Struct.new(
  :ssm_agent_discovery_datetime,
  :post_launch_actions_launch_status_list)
  SENSITIVE = []
  include Aws::Structure
end

#ssm_agent_discovery_datetimeString

Time where the AWS Systems Manager was detected as running on the Test or Cutover instance.

Returns:

  • (String)


5051
5052
5053
5054
5055
5056
# File 'lib/aws-sdk-mgn/types.rb', line 5051

class PostLaunchActionsStatus < Struct.new(
  :ssm_agent_discovery_datetime,
  :post_launch_actions_launch_status_list)
  SENSITIVE = []
  include Aws::Structure
end