Class: Aws::Mgn::Types::PutTemplateActionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Mgn::Types::PutTemplateActionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mgn/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action_id ⇒ String
Template post migration custom action ID.
-
#action_name ⇒ String
Template post migration custom action name.
-
#active ⇒ Boolean
Template post migration custom action active status.
-
#category ⇒ String
Template post migration custom action category.
-
#description ⇒ String
Template post migration custom action description.
-
#document_identifier ⇒ String
Template post migration custom action document identifier.
-
#document_version ⇒ String
Template post migration custom action document version.
-
#external_parameters ⇒ Hash<String,Types::SsmExternalParameter>
Template post migration custom action external parameters.
-
#launch_configuration_template_id ⇒ String
Launch configuration template ID.
-
#must_succeed_for_cutover ⇒ Boolean
Template post migration custom action must succeed for cutover.
-
#operating_system ⇒ String
Operating system eligible for this template post migration custom action.
-
#order ⇒ Integer
Template post migration custom action order.
-
#parameters ⇒ Hash<String,Array<Types::SsmParameterStoreParameter>>
Template post migration custom action parameters.
-
#timeout_seconds ⇒ Integer
Template post migration custom action timeout in seconds.
Instance Attribute Details
#action_id ⇒ String
Template post migration custom action ID.
5053 5054 5055 5056 5057 5058 5059 5060 5061 5062 5063 5064 5065 5066 5067 5068 5069 5070 |
# File 'lib/aws-sdk-mgn/types.rb', line 5053 class PutTemplateActionRequest < Struct.new( :launch_configuration_template_id, :action_name, :document_identifier, :order, :action_id, :document_version, :active, :timeout_seconds, :must_succeed_for_cutover, :parameters, :operating_system, :external_parameters, :description, :category) SENSITIVE = [] include Aws::Structure end |
#action_name ⇒ String
Template post migration custom action name.
5053 5054 5055 5056 5057 5058 5059 5060 5061 5062 5063 5064 5065 5066 5067 5068 5069 5070 |
# File 'lib/aws-sdk-mgn/types.rb', line 5053 class PutTemplateActionRequest < Struct.new( :launch_configuration_template_id, :action_name, :document_identifier, :order, :action_id, :document_version, :active, :timeout_seconds, :must_succeed_for_cutover, :parameters, :operating_system, :external_parameters, :description, :category) SENSITIVE = [] include Aws::Structure end |
#active ⇒ Boolean
Template post migration custom action active status.
5053 5054 5055 5056 5057 5058 5059 5060 5061 5062 5063 5064 5065 5066 5067 5068 5069 5070 |
# File 'lib/aws-sdk-mgn/types.rb', line 5053 class PutTemplateActionRequest < Struct.new( :launch_configuration_template_id, :action_name, :document_identifier, :order, :action_id, :document_version, :active, :timeout_seconds, :must_succeed_for_cutover, :parameters, :operating_system, :external_parameters, :description, :category) SENSITIVE = [] include Aws::Structure end |
#category ⇒ String
Template post migration custom action category.
5053 5054 5055 5056 5057 5058 5059 5060 5061 5062 5063 5064 5065 5066 5067 5068 5069 5070 |
# File 'lib/aws-sdk-mgn/types.rb', line 5053 class PutTemplateActionRequest < Struct.new( :launch_configuration_template_id, :action_name, :document_identifier, :order, :action_id, :document_version, :active, :timeout_seconds, :must_succeed_for_cutover, :parameters, :operating_system, :external_parameters, :description, :category) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
Template post migration custom action description.
5053 5054 5055 5056 5057 5058 5059 5060 5061 5062 5063 5064 5065 5066 5067 5068 5069 5070 |
# File 'lib/aws-sdk-mgn/types.rb', line 5053 class PutTemplateActionRequest < Struct.new( :launch_configuration_template_id, :action_name, :document_identifier, :order, :action_id, :document_version, :active, :timeout_seconds, :must_succeed_for_cutover, :parameters, :operating_system, :external_parameters, :description, :category) SENSITIVE = [] include Aws::Structure end |
#document_identifier ⇒ String
Template post migration custom action document identifier.
5053 5054 5055 5056 5057 5058 5059 5060 5061 5062 5063 5064 5065 5066 5067 5068 5069 5070 |
# File 'lib/aws-sdk-mgn/types.rb', line 5053 class PutTemplateActionRequest < Struct.new( :launch_configuration_template_id, :action_name, :document_identifier, :order, :action_id, :document_version, :active, :timeout_seconds, :must_succeed_for_cutover, :parameters, :operating_system, :external_parameters, :description, :category) SENSITIVE = [] include Aws::Structure end |
#document_version ⇒ String
Template post migration custom action document version.
5053 5054 5055 5056 5057 5058 5059 5060 5061 5062 5063 5064 5065 5066 5067 5068 5069 5070 |
# File 'lib/aws-sdk-mgn/types.rb', line 5053 class PutTemplateActionRequest < Struct.new( :launch_configuration_template_id, :action_name, :document_identifier, :order, :action_id, :document_version, :active, :timeout_seconds, :must_succeed_for_cutover, :parameters, :operating_system, :external_parameters, :description, :category) SENSITIVE = [] include Aws::Structure end |
#external_parameters ⇒ Hash<String,Types::SsmExternalParameter>
Template post migration custom action external parameters.
5053 5054 5055 5056 5057 5058 5059 5060 5061 5062 5063 5064 5065 5066 5067 5068 5069 5070 |
# File 'lib/aws-sdk-mgn/types.rb', line 5053 class PutTemplateActionRequest < Struct.new( :launch_configuration_template_id, :action_name, :document_identifier, :order, :action_id, :document_version, :active, :timeout_seconds, :must_succeed_for_cutover, :parameters, :operating_system, :external_parameters, :description, :category) SENSITIVE = [] include Aws::Structure end |
#launch_configuration_template_id ⇒ String
Launch configuration template ID.
5053 5054 5055 5056 5057 5058 5059 5060 5061 5062 5063 5064 5065 5066 5067 5068 5069 5070 |
# File 'lib/aws-sdk-mgn/types.rb', line 5053 class PutTemplateActionRequest < Struct.new( :launch_configuration_template_id, :action_name, :document_identifier, :order, :action_id, :document_version, :active, :timeout_seconds, :must_succeed_for_cutover, :parameters, :operating_system, :external_parameters, :description, :category) SENSITIVE = [] include Aws::Structure end |
#must_succeed_for_cutover ⇒ Boolean
Template post migration custom action must succeed for cutover.
5053 5054 5055 5056 5057 5058 5059 5060 5061 5062 5063 5064 5065 5066 5067 5068 5069 5070 |
# File 'lib/aws-sdk-mgn/types.rb', line 5053 class PutTemplateActionRequest < Struct.new( :launch_configuration_template_id, :action_name, :document_identifier, :order, :action_id, :document_version, :active, :timeout_seconds, :must_succeed_for_cutover, :parameters, :operating_system, :external_parameters, :description, :category) SENSITIVE = [] include Aws::Structure end |
#operating_system ⇒ String
Operating system eligible for this template post migration custom action.
5053 5054 5055 5056 5057 5058 5059 5060 5061 5062 5063 5064 5065 5066 5067 5068 5069 5070 |
# File 'lib/aws-sdk-mgn/types.rb', line 5053 class PutTemplateActionRequest < Struct.new( :launch_configuration_template_id, :action_name, :document_identifier, :order, :action_id, :document_version, :active, :timeout_seconds, :must_succeed_for_cutover, :parameters, :operating_system, :external_parameters, :description, :category) SENSITIVE = [] include Aws::Structure end |
#order ⇒ Integer
Template post migration custom action order.
5053 5054 5055 5056 5057 5058 5059 5060 5061 5062 5063 5064 5065 5066 5067 5068 5069 5070 |
# File 'lib/aws-sdk-mgn/types.rb', line 5053 class PutTemplateActionRequest < Struct.new( :launch_configuration_template_id, :action_name, :document_identifier, :order, :action_id, :document_version, :active, :timeout_seconds, :must_succeed_for_cutover, :parameters, :operating_system, :external_parameters, :description, :category) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ Hash<String,Array<Types::SsmParameterStoreParameter>>
Template post migration custom action parameters.
5053 5054 5055 5056 5057 5058 5059 5060 5061 5062 5063 5064 5065 5066 5067 5068 5069 5070 |
# File 'lib/aws-sdk-mgn/types.rb', line 5053 class PutTemplateActionRequest < Struct.new( :launch_configuration_template_id, :action_name, :document_identifier, :order, :action_id, :document_version, :active, :timeout_seconds, :must_succeed_for_cutover, :parameters, :operating_system, :external_parameters, :description, :category) SENSITIVE = [] include Aws::Structure end |
#timeout_seconds ⇒ Integer
Template post migration custom action timeout in seconds.
5053 5054 5055 5056 5057 5058 5059 5060 5061 5062 5063 5064 5065 5066 5067 5068 5069 5070 |
# File 'lib/aws-sdk-mgn/types.rb', line 5053 class PutTemplateActionRequest < Struct.new( :launch_configuration_template_id, :action_name, :document_identifier, :order, :action_id, :document_version, :active, :timeout_seconds, :must_succeed_for_cutover, :parameters, :operating_system, :external_parameters, :description, :category) SENSITIVE = [] include Aws::Structure end |