Class: Aws::Mgn::Types::RemoveTemplateActionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Mgn::Types::RemoveTemplateActionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mgn/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action_id ⇒ String
Template post migration custom action ID to remove.
-
#launch_configuration_template_id ⇒ String
Launch configuration template ID of the post migration custom action to remove.
Instance Attribute Details
#action_id ⇒ String
Template post migration custom action ID to remove.
5109 5110 5111 5112 5113 5114 |
# File 'lib/aws-sdk-mgn/types.rb', line 5109 class RemoveTemplateActionRequest < Struct.new( :launch_configuration_template_id, :action_id) SENSITIVE = [] include Aws::Structure end |
#launch_configuration_template_id ⇒ String
Launch configuration template ID of the post migration custom action to remove.
5109 5110 5111 5112 5113 5114 |
# File 'lib/aws-sdk-mgn/types.rb', line 5109 class RemoveTemplateActionRequest < Struct.new( :launch_configuration_template_id, :action_id) SENSITIVE = [] include Aws::Structure end |