Class: Aws::Mgn::Types::StartImportFileEnrichmentRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mgn/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


5955
5956
5957
5958
5959
5960
5961
5962
# File 'lib/aws-sdk-mgn/types.rb', line 5955

class StartImportFileEnrichmentRequest < Struct.new(
  :client_token,
  :s3_bucket_source,
  :s3_bucket_target,
  :ip_assignment_strategy)
  SENSITIVE = []
  include Aws::Structure
end

#ip_assignment_strategyString

The IP assignment strategy to use when enriching the import file. Can be STATIC or DYNAMIC.

Returns:

  • (String)


5955
5956
5957
5958
5959
5960
5961
5962
# File 'lib/aws-sdk-mgn/types.rb', line 5955

class StartImportFileEnrichmentRequest < Struct.new(
  :client_token,
  :s3_bucket_source,
  :s3_bucket_target,
  :ip_assignment_strategy)
  SENSITIVE = []
  include Aws::Structure
end

#s3_bucket_sourceTypes::EnrichmentSourceS3Configuration

The S3 configuration specifying the source location of the import file to be enriched.



5955
5956
5957
5958
5959
5960
5961
5962
# File 'lib/aws-sdk-mgn/types.rb', line 5955

class StartImportFileEnrichmentRequest < Struct.new(
  :client_token,
  :s3_bucket_source,
  :s3_bucket_target,
  :ip_assignment_strategy)
  SENSITIVE = []
  include Aws::Structure
end

#s3_bucket_targetTypes::EnrichmentTargetS3Configuration

The S3 configuration specifying the target location where the enriched import file will be stored.



5955
5956
5957
5958
5959
5960
5961
5962
# File 'lib/aws-sdk-mgn/types.rb', line 5955

class StartImportFileEnrichmentRequest < Struct.new(
  :client_token,
  :s3_bucket_source,
  :s3_bucket_target,
  :ip_assignment_strategy)
  SENSITIVE = []
  include Aws::Structure
end