Class: Aws::Mgn::Types::StartImportFileEnrichmentResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Mgn::Types::StartImportFileEnrichmentResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mgn/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#job_id ⇒ String
The unique identifier of the import file enrichment job that was started.
Instance Attribute Details
#job_id ⇒ String
The unique identifier of the import file enrichment job that was started.
5971 5972 5973 5974 5975 |
# File 'lib/aws-sdk-mgn/types.rb', line 5971 class StartImportFileEnrichmentResponse < Struct.new( :job_id) SENSITIVE = [] include Aws::Structure end |