Class: Aws::Mgn::Types::StartNetworkMigrationCodeGenerationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Mgn::Types::StartNetworkMigrationCodeGenerationResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mgn/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#job_id ⇒ String
The unique identifier of the code generation job that was started.
Instance Attribute Details
#job_id ⇒ String
The unique identifier of the code generation job that was started.
6076 6077 6078 6079 6080 |
# File 'lib/aws-sdk-mgn/types.rb', line 6076 class StartNetworkMigrationCodeGenerationResponse < Struct.new( :job_id) SENSITIVE = [] include Aws::Structure end |