Class: Aws::Mgn::Types::StartNetworkMigrationDeployerJobResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Mgn::Types::StartNetworkMigrationDeployerJobResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mgn/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#job_id ⇒ String
The unique identifier of the deployer job that was started.
Instance Attribute Details
#job_id ⇒ String
The unique identifier of the deployer job that was started.
6088 6089 6090 6091 6092 |
# File 'lib/aws-sdk-mgn/types.rb', line 6088 class StartNetworkMigrationDeployerJobResponse < Struct.new( :job_id) SENSITIVE = [] include Aws::Structure end |