Class: Aws::Mgn::Types::StartNetworkMigrationMappingUpdateResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Mgn::Types::StartNetworkMigrationMappingUpdateResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mgn/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#job_id ⇒ String
The unique identifier of the mapping update job that was started.
Instance Attribute Details
#job_id ⇒ String
The unique identifier of the mapping update job that was started.
6207 6208 6209 6210 6211 |
# File 'lib/aws-sdk-mgn/types.rb', line 6207 class StartNetworkMigrationMappingUpdateResponse < Struct.new( :job_id) SENSITIVE = [] include Aws::Structure end |