Class: Aws::Mgn::Types::TargetNetwork
- Inherits:
-
Struct
- Object
- Struct
- Aws::Mgn::Types::TargetNetwork
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mgn/types.rb
Overview
Configuration for the target network topology and addressing.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#inbound_cidr ⇒ String
The CIDR block for inbound traffic in the target network.
-
#inspection_cidr ⇒ String
The CIDR block for inspection traffic in the target network.
-
#outbound_cidr ⇒ String
The CIDR block for outbound traffic in the target network.
-
#topology ⇒ String
The network topology type for the target environment.
Instance Attribute Details
#inbound_cidr ⇒ String
The CIDR block for inbound traffic in the target network.
6600 6601 6602 6603 6604 6605 6606 6607 |
# File 'lib/aws-sdk-mgn/types.rb', line 6600 class TargetNetwork < Struct.new( :topology, :inbound_cidr, :outbound_cidr, :inspection_cidr) SENSITIVE = [] include Aws::Structure end |
#inspection_cidr ⇒ String
The CIDR block for inspection traffic in the target network.
6600 6601 6602 6603 6604 6605 6606 6607 |
# File 'lib/aws-sdk-mgn/types.rb', line 6600 class TargetNetwork < Struct.new( :topology, :inbound_cidr, :outbound_cidr, :inspection_cidr) SENSITIVE = [] include Aws::Structure end |
#outbound_cidr ⇒ String
The CIDR block for outbound traffic in the target network.
6600 6601 6602 6603 6604 6605 6606 6607 |
# File 'lib/aws-sdk-mgn/types.rb', line 6600 class TargetNetwork < Struct.new( :topology, :inbound_cidr, :outbound_cidr, :inspection_cidr) SENSITIVE = [] include Aws::Structure end |
#topology ⇒ String
The network topology type for the target environment.
6600 6601 6602 6603 6604 6605 6606 6607 |
# File 'lib/aws-sdk-mgn/types.rb', line 6600 class TargetNetwork < Struct.new( :topology, :inbound_cidr, :outbound_cidr, :inspection_cidr) SENSITIVE = [] include Aws::Structure end |