Class: Aws::Mgn::Types::ThrottlingException
- Inherits:
-
Struct
- Object
- Struct
- Aws::Mgn::Types::ThrottlingException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mgn/types.rb
Overview
Reached throttling quota exception.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
- #message ⇒ String
-
#quota_code ⇒ String
Reached throttling quota exception.
-
#retry_after_seconds ⇒ String
Reached throttling quota exception will retry after x seconds.
-
#service_code ⇒ String
Reached throttling quota exception service code.
Instance Attribute Details
#message ⇒ String
6654 6655 6656 6657 6658 6659 6660 6661 |
# File 'lib/aws-sdk-mgn/types.rb', line 6654 class ThrottlingException < Struct.new( :message, :service_code, :quota_code, :retry_after_seconds) SENSITIVE = [] include Aws::Structure end |
#quota_code ⇒ String
Reached throttling quota exception.
6654 6655 6656 6657 6658 6659 6660 6661 |
# File 'lib/aws-sdk-mgn/types.rb', line 6654 class ThrottlingException < Struct.new( :message, :service_code, :quota_code, :retry_after_seconds) SENSITIVE = [] include Aws::Structure end |
#retry_after_seconds ⇒ String
Reached throttling quota exception will retry after x seconds.
6654 6655 6656 6657 6658 6659 6660 6661 |
# File 'lib/aws-sdk-mgn/types.rb', line 6654 class ThrottlingException < Struct.new( :message, :service_code, :quota_code, :retry_after_seconds) SENSITIVE = [] include Aws::Structure end |
#service_code ⇒ String
Reached throttling quota exception service code.
6654 6655 6656 6657 6658 6659 6660 6661 |
# File 'lib/aws-sdk-mgn/types.rb', line 6654 class ThrottlingException < Struct.new( :message, :service_code, :quota_code, :retry_after_seconds) SENSITIVE = [] include Aws::Structure end |