Class: Aws::Mgn::Types::UpdateLaunchConfigurationTemplateRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Mgn::Types::UpdateLaunchConfigurationTemplateRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mgn/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#associate_public_ip_address ⇒ Boolean
Associate public Ip address.
-
#boot_mode ⇒ String
Launch configuration template boot mode.
-
#copy_private_ip ⇒ Boolean
Copy private Ip.
-
#copy_tags ⇒ Boolean
Copy tags.
-
#enable_map_auto_tagging ⇒ Boolean
Enable map auto tagging.
-
#enable_parameters_encryption ⇒ Boolean
Enable parameters encryption.
-
#large_volume_conf ⇒ Types::LaunchTemplateDiskConf
Large volume config.
-
#launch_configuration_template_id ⇒ String
Launch Configuration Template ID.
-
#launch_disposition ⇒ String
Launch disposition.
-
#licensing ⇒ Types::Licensing
Configure Licensing.
-
#map_auto_tagging_mpe_id ⇒ String
Launch configuration template map auto tagging MPE ID.
-
#parameters_encryption_key ⇒ String
Parameters encryption key.
-
#post_launch_actions ⇒ Types::PostLaunchActions
Post Launch Action to execute on the Test or Cutover instance.
-
#small_volume_conf ⇒ Types::LaunchTemplateDiskConf
Small volume config.
-
#small_volume_max_size ⇒ Integer
Small volume maximum size.
-
#target_instance_type_right_sizing_method ⇒ String
Target instance type right-sizing method.
Instance Attribute Details
#associate_public_ip_address ⇒ Boolean
Associate public Ip address.
6817 6818 6819 6820 6821 6822 6823 6824 6825 6826 6827 6828 6829 6830 6831 6832 6833 6834 6835 6836 |
# File 'lib/aws-sdk-mgn/types.rb', line 6817 class UpdateLaunchConfigurationTemplateRequest < Struct.new( :launch_configuration_template_id, :post_launch_actions, :enable_map_auto_tagging, :map_auto_tagging_mpe_id, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :associate_public_ip_address, :copy_tags, :licensing, :boot_mode, :small_volume_max_size, :small_volume_conf, :large_volume_conf, :enable_parameters_encryption, :parameters_encryption_key) SENSITIVE = [] include Aws::Structure end |
#boot_mode ⇒ String
Launch configuration template boot mode.
6817 6818 6819 6820 6821 6822 6823 6824 6825 6826 6827 6828 6829 6830 6831 6832 6833 6834 6835 6836 |
# File 'lib/aws-sdk-mgn/types.rb', line 6817 class UpdateLaunchConfigurationTemplateRequest < Struct.new( :launch_configuration_template_id, :post_launch_actions, :enable_map_auto_tagging, :map_auto_tagging_mpe_id, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :associate_public_ip_address, :copy_tags, :licensing, :boot_mode, :small_volume_max_size, :small_volume_conf, :large_volume_conf, :enable_parameters_encryption, :parameters_encryption_key) SENSITIVE = [] include Aws::Structure end |
#copy_private_ip ⇒ Boolean
Copy private Ip.
6817 6818 6819 6820 6821 6822 6823 6824 6825 6826 6827 6828 6829 6830 6831 6832 6833 6834 6835 6836 |
# File 'lib/aws-sdk-mgn/types.rb', line 6817 class UpdateLaunchConfigurationTemplateRequest < Struct.new( :launch_configuration_template_id, :post_launch_actions, :enable_map_auto_tagging, :map_auto_tagging_mpe_id, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :associate_public_ip_address, :copy_tags, :licensing, :boot_mode, :small_volume_max_size, :small_volume_conf, :large_volume_conf, :enable_parameters_encryption, :parameters_encryption_key) SENSITIVE = [] include Aws::Structure end |
#copy_tags ⇒ Boolean
Copy tags.
6817 6818 6819 6820 6821 6822 6823 6824 6825 6826 6827 6828 6829 6830 6831 6832 6833 6834 6835 6836 |
# File 'lib/aws-sdk-mgn/types.rb', line 6817 class UpdateLaunchConfigurationTemplateRequest < Struct.new( :launch_configuration_template_id, :post_launch_actions, :enable_map_auto_tagging, :map_auto_tagging_mpe_id, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :associate_public_ip_address, :copy_tags, :licensing, :boot_mode, :small_volume_max_size, :small_volume_conf, :large_volume_conf, :enable_parameters_encryption, :parameters_encryption_key) SENSITIVE = [] include Aws::Structure end |
#enable_map_auto_tagging ⇒ Boolean
Enable map auto tagging.
6817 6818 6819 6820 6821 6822 6823 6824 6825 6826 6827 6828 6829 6830 6831 6832 6833 6834 6835 6836 |
# File 'lib/aws-sdk-mgn/types.rb', line 6817 class UpdateLaunchConfigurationTemplateRequest < Struct.new( :launch_configuration_template_id, :post_launch_actions, :enable_map_auto_tagging, :map_auto_tagging_mpe_id, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :associate_public_ip_address, :copy_tags, :licensing, :boot_mode, :small_volume_max_size, :small_volume_conf, :large_volume_conf, :enable_parameters_encryption, :parameters_encryption_key) SENSITIVE = [] include Aws::Structure end |
#enable_parameters_encryption ⇒ Boolean
Enable parameters encryption.
6817 6818 6819 6820 6821 6822 6823 6824 6825 6826 6827 6828 6829 6830 6831 6832 6833 6834 6835 6836 |
# File 'lib/aws-sdk-mgn/types.rb', line 6817 class UpdateLaunchConfigurationTemplateRequest < Struct.new( :launch_configuration_template_id, :post_launch_actions, :enable_map_auto_tagging, :map_auto_tagging_mpe_id, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :associate_public_ip_address, :copy_tags, :licensing, :boot_mode, :small_volume_max_size, :small_volume_conf, :large_volume_conf, :enable_parameters_encryption, :parameters_encryption_key) SENSITIVE = [] include Aws::Structure end |
#large_volume_conf ⇒ Types::LaunchTemplateDiskConf
Large volume config.
6817 6818 6819 6820 6821 6822 6823 6824 6825 6826 6827 6828 6829 6830 6831 6832 6833 6834 6835 6836 |
# File 'lib/aws-sdk-mgn/types.rb', line 6817 class UpdateLaunchConfigurationTemplateRequest < Struct.new( :launch_configuration_template_id, :post_launch_actions, :enable_map_auto_tagging, :map_auto_tagging_mpe_id, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :associate_public_ip_address, :copy_tags, :licensing, :boot_mode, :small_volume_max_size, :small_volume_conf, :large_volume_conf, :enable_parameters_encryption, :parameters_encryption_key) SENSITIVE = [] include Aws::Structure end |
#launch_configuration_template_id ⇒ String
Launch Configuration Template ID.
6817 6818 6819 6820 6821 6822 6823 6824 6825 6826 6827 6828 6829 6830 6831 6832 6833 6834 6835 6836 |
# File 'lib/aws-sdk-mgn/types.rb', line 6817 class UpdateLaunchConfigurationTemplateRequest < Struct.new( :launch_configuration_template_id, :post_launch_actions, :enable_map_auto_tagging, :map_auto_tagging_mpe_id, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :associate_public_ip_address, :copy_tags, :licensing, :boot_mode, :small_volume_max_size, :small_volume_conf, :large_volume_conf, :enable_parameters_encryption, :parameters_encryption_key) SENSITIVE = [] include Aws::Structure end |
#launch_disposition ⇒ String
Launch disposition.
6817 6818 6819 6820 6821 6822 6823 6824 6825 6826 6827 6828 6829 6830 6831 6832 6833 6834 6835 6836 |
# File 'lib/aws-sdk-mgn/types.rb', line 6817 class UpdateLaunchConfigurationTemplateRequest < Struct.new( :launch_configuration_template_id, :post_launch_actions, :enable_map_auto_tagging, :map_auto_tagging_mpe_id, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :associate_public_ip_address, :copy_tags, :licensing, :boot_mode, :small_volume_max_size, :small_volume_conf, :large_volume_conf, :enable_parameters_encryption, :parameters_encryption_key) SENSITIVE = [] include Aws::Structure end |
#licensing ⇒ Types::Licensing
Configure Licensing.
6817 6818 6819 6820 6821 6822 6823 6824 6825 6826 6827 6828 6829 6830 6831 6832 6833 6834 6835 6836 |
# File 'lib/aws-sdk-mgn/types.rb', line 6817 class UpdateLaunchConfigurationTemplateRequest < Struct.new( :launch_configuration_template_id, :post_launch_actions, :enable_map_auto_tagging, :map_auto_tagging_mpe_id, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :associate_public_ip_address, :copy_tags, :licensing, :boot_mode, :small_volume_max_size, :small_volume_conf, :large_volume_conf, :enable_parameters_encryption, :parameters_encryption_key) SENSITIVE = [] include Aws::Structure end |
#map_auto_tagging_mpe_id ⇒ String
Launch configuration template map auto tagging MPE ID.
6817 6818 6819 6820 6821 6822 6823 6824 6825 6826 6827 6828 6829 6830 6831 6832 6833 6834 6835 6836 |
# File 'lib/aws-sdk-mgn/types.rb', line 6817 class UpdateLaunchConfigurationTemplateRequest < Struct.new( :launch_configuration_template_id, :post_launch_actions, :enable_map_auto_tagging, :map_auto_tagging_mpe_id, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :associate_public_ip_address, :copy_tags, :licensing, :boot_mode, :small_volume_max_size, :small_volume_conf, :large_volume_conf, :enable_parameters_encryption, :parameters_encryption_key) SENSITIVE = [] include Aws::Structure end |
#parameters_encryption_key ⇒ String
Parameters encryption key.
6817 6818 6819 6820 6821 6822 6823 6824 6825 6826 6827 6828 6829 6830 6831 6832 6833 6834 6835 6836 |
# File 'lib/aws-sdk-mgn/types.rb', line 6817 class UpdateLaunchConfigurationTemplateRequest < Struct.new( :launch_configuration_template_id, :post_launch_actions, :enable_map_auto_tagging, :map_auto_tagging_mpe_id, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :associate_public_ip_address, :copy_tags, :licensing, :boot_mode, :small_volume_max_size, :small_volume_conf, :large_volume_conf, :enable_parameters_encryption, :parameters_encryption_key) SENSITIVE = [] include Aws::Structure end |
#post_launch_actions ⇒ Types::PostLaunchActions
Post Launch Action to execute on the Test or Cutover instance.
6817 6818 6819 6820 6821 6822 6823 6824 6825 6826 6827 6828 6829 6830 6831 6832 6833 6834 6835 6836 |
# File 'lib/aws-sdk-mgn/types.rb', line 6817 class UpdateLaunchConfigurationTemplateRequest < Struct.new( :launch_configuration_template_id, :post_launch_actions, :enable_map_auto_tagging, :map_auto_tagging_mpe_id, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :associate_public_ip_address, :copy_tags, :licensing, :boot_mode, :small_volume_max_size, :small_volume_conf, :large_volume_conf, :enable_parameters_encryption, :parameters_encryption_key) SENSITIVE = [] include Aws::Structure end |
#small_volume_conf ⇒ Types::LaunchTemplateDiskConf
Small volume config.
6817 6818 6819 6820 6821 6822 6823 6824 6825 6826 6827 6828 6829 6830 6831 6832 6833 6834 6835 6836 |
# File 'lib/aws-sdk-mgn/types.rb', line 6817 class UpdateLaunchConfigurationTemplateRequest < Struct.new( :launch_configuration_template_id, :post_launch_actions, :enable_map_auto_tagging, :map_auto_tagging_mpe_id, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :associate_public_ip_address, :copy_tags, :licensing, :boot_mode, :small_volume_max_size, :small_volume_conf, :large_volume_conf, :enable_parameters_encryption, :parameters_encryption_key) SENSITIVE = [] include Aws::Structure end |
#small_volume_max_size ⇒ Integer
Small volume maximum size.
6817 6818 6819 6820 6821 6822 6823 6824 6825 6826 6827 6828 6829 6830 6831 6832 6833 6834 6835 6836 |
# File 'lib/aws-sdk-mgn/types.rb', line 6817 class UpdateLaunchConfigurationTemplateRequest < Struct.new( :launch_configuration_template_id, :post_launch_actions, :enable_map_auto_tagging, :map_auto_tagging_mpe_id, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :associate_public_ip_address, :copy_tags, :licensing, :boot_mode, :small_volume_max_size, :small_volume_conf, :large_volume_conf, :enable_parameters_encryption, :parameters_encryption_key) SENSITIVE = [] include Aws::Structure end |
#target_instance_type_right_sizing_method ⇒ String
Target instance type right-sizing method.
6817 6818 6819 6820 6821 6822 6823 6824 6825 6826 6827 6828 6829 6830 6831 6832 6833 6834 6835 6836 |
# File 'lib/aws-sdk-mgn/types.rb', line 6817 class UpdateLaunchConfigurationTemplateRequest < Struct.new( :launch_configuration_template_id, :post_launch_actions, :enable_map_auto_tagging, :map_auto_tagging_mpe_id, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :associate_public_ip_address, :copy_tags, :licensing, :boot_mode, :small_volume_max_size, :small_volume_conf, :large_volume_conf, :enable_parameters_encryption, :parameters_encryption_key) SENSITIVE = [] include Aws::Structure end |