Class: Aws::Mgn::Types::UpdateNetworkMigrationDefinitionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mgn/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:scope_tags]

Instance Attribute Summary collapse

Instance Attribute Details

#cidr_mappings ⇒ Array<Types::CidrMapping>

The updated list of CIDR mappings that map original source CIDR ranges to updated target CIDR ranges. CIDR mappings can be provided only when vpcProvisioningStrategy is set to USE_EXISTING.

Returns:



7144
7145
7146
7147
7148
7149
7150
7151
7152
7153
7154
7155
7156
7157
# File 'lib/aws-sdk-mgn/types.rb', line 7144

class UpdateNetworkMigrationDefinitionRequest < Struct.new(
  :network_migration_definition_id,
  :name,
  :description,
  :source_configurations,
  :target_s3_configuration,
  :target_network,
  :target_deployment,
  :vpc_provisioning_strategy,
  :cidr_mappings,
  :scope_tags)
  SENSITIVE = [:scope_tags]
  include Aws::Structure
end

#description ⇒ String

The updated description of the network migration definition.

Returns:

  • (String)


7144
7145
7146
7147
7148
7149
7150
7151
7152
7153
7154
7155
7156
7157
# File 'lib/aws-sdk-mgn/types.rb', line 7144

class UpdateNetworkMigrationDefinitionRequest < Struct.new(
  :network_migration_definition_id,
  :name,
  :description,
  :source_configurations,
  :target_s3_configuration,
  :target_network,
  :target_deployment,
  :vpc_provisioning_strategy,
  :cidr_mappings,
  :scope_tags)
  SENSITIVE = [:scope_tags]
  include Aws::Structure
end

#name ⇒ String

The updated name of the network migration definition.

Returns:

  • (String)


7144
7145
7146
7147
7148
7149
7150
7151
7152
7153
7154
7155
7156
7157
# File 'lib/aws-sdk-mgn/types.rb', line 7144

class UpdateNetworkMigrationDefinitionRequest < Struct.new(
  :network_migration_definition_id,
  :name,
  :description,
  :source_configurations,
  :target_s3_configuration,
  :target_network,
  :target_deployment,
  :vpc_provisioning_strategy,
  :cidr_mappings,
  :scope_tags)
  SENSITIVE = [:scope_tags]
  include Aws::Structure
end

#network_migration_definition_id ⇒ String

The unique identifier of the network migration definition to update.

Returns:

  • (String)


7144
7145
7146
7147
7148
7149
7150
7151
7152
7153
7154
7155
7156
7157
# File 'lib/aws-sdk-mgn/types.rb', line 7144

class UpdateNetworkMigrationDefinitionRequest < Struct.new(
  :network_migration_definition_id,
  :name,
  :description,
  :source_configurations,
  :target_s3_configuration,
  :target_network,
  :target_deployment,
  :vpc_provisioning_strategy,
  :cidr_mappings,
  :scope_tags)
  SENSITIVE = [:scope_tags]
  include Aws::Structure
end

#scope_tags ⇒ Hash<String,String>

The updated scope tags for the network migration definition.

Returns:

  • (Hash<String,String>)


7144
7145
7146
7147
7148
7149
7150
7151
7152
7153
7154
7155
7156
7157
# File 'lib/aws-sdk-mgn/types.rb', line 7144

class UpdateNetworkMigrationDefinitionRequest < Struct.new(
  :network_migration_definition_id,
  :name,
  :description,
  :source_configurations,
  :target_s3_configuration,
  :target_network,
  :target_deployment,
  :vpc_provisioning_strategy,
  :cidr_mappings,
  :scope_tags)
  SENSITIVE = [:scope_tags]
  include Aws::Structure
end

#source_configurations ⇒ Array<Types::SourceConfiguration>

The updated list of source configurations.

Returns:



7144
7145
7146
7147
7148
7149
7150
7151
7152
7153
7154
7155
7156
7157
# File 'lib/aws-sdk-mgn/types.rb', line 7144

class UpdateNetworkMigrationDefinitionRequest < Struct.new(
  :network_migration_definition_id,
  :name,
  :description,
  :source_configurations,
  :target_s3_configuration,
  :target_network,
  :target_deployment,
  :vpc_provisioning_strategy,
  :cidr_mappings,
  :scope_tags)
  SENSITIVE = [:scope_tags]
  include Aws::Structure
end

#target_deployment ⇒ String

The updated target deployment configuration.

Returns:

  • (String)


7144
7145
7146
7147
7148
7149
7150
7151
7152
7153
7154
7155
7156
7157
# File 'lib/aws-sdk-mgn/types.rb', line 7144

class UpdateNetworkMigrationDefinitionRequest < Struct.new(
  :network_migration_definition_id,
  :name,
  :description,
  :source_configurations,
  :target_s3_configuration,
  :target_network,
  :target_deployment,
  :vpc_provisioning_strategy,
  :cidr_mappings,
  :scope_tags)
  SENSITIVE = [:scope_tags]
  include Aws::Structure
end

#target_network ⇒ Types::TargetNetworkUpdate

The updated target network configuration.



7144
7145
7146
7147
7148
7149
7150
7151
7152
7153
7154
7155
7156
7157
# File 'lib/aws-sdk-mgn/types.rb', line 7144

class UpdateNetworkMigrationDefinitionRequest < Struct.new(
  :network_migration_definition_id,
  :name,
  :description,
  :source_configurations,
  :target_s3_configuration,
  :target_network,
  :target_deployment,
  :vpc_provisioning_strategy,
  :cidr_mappings,
  :scope_tags)
  SENSITIVE = [:scope_tags]
  include Aws::Structure
end

#target_s3_configuration ⇒ Types::TargetS3ConfigurationUpdate

The updated S3 configuration for storing the target network artifacts.



7144
7145
7146
7147
7148
7149
7150
7151
7152
7153
7154
7155
7156
7157
# File 'lib/aws-sdk-mgn/types.rb', line 7144

class UpdateNetworkMigrationDefinitionRequest < Struct.new(
  :network_migration_definition_id,
  :name,
  :description,
  :source_configurations,
  :target_s3_configuration,
  :target_network,
  :target_deployment,
  :vpc_provisioning_strategy,
  :cidr_mappings,
  :scope_tags)
  SENSITIVE = [:scope_tags]
  include Aws::Structure
end

#vpc_provisioning_strategy ⇒ String

Updates whether the migration creates new target VPCs or uses existing ones. Set to USE_EXISTING to migrate into existing VPCs in the target account, or to CREATE_NEW to provision new target VPCs.

Returns:

  • (String)


7144
7145
7146
7147
7148
7149
7150
7151
7152
7153
7154
7155
7156
7157
# File 'lib/aws-sdk-mgn/types.rb', line 7144

class UpdateNetworkMigrationDefinitionRequest < Struct.new(
  :network_migration_definition_id,
  :name,
  :description,
  :source_configurations,
  :target_s3_configuration,
  :target_network,
  :target_deployment,
  :vpc_provisioning_strategy,
  :cidr_mappings,
  :scope_tags)
  SENSITIVE = [:scope_tags]
  include Aws::Structure
end