Class: Aws::Mgn::Types::CreateNetworkMigrationDefinitionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mgn/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:tags, :scope_tags]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

A description of the network migration definition.

Returns:



572
573
574
575
576
577
578
579
580
581
582
583
# File 'lib/aws-sdk-mgn/types.rb', line 572

class CreateNetworkMigrationDefinitionRequest < Struct.new(
  :name,
  :description,
  :source_configurations,
  :target_s3_configuration,
  :target_network,
  :target_deployment,
  :tags,
  :scope_tags)
  SENSITIVE = [:tags, :scope_tags]
  include Aws::Structure
end

#nameString

The name of the network migration definition.

Returns:



572
573
574
575
576
577
578
579
580
581
582
583
# File 'lib/aws-sdk-mgn/types.rb', line 572

class CreateNetworkMigrationDefinitionRequest < Struct.new(
  :name,
  :description,
  :source_configurations,
  :target_s3_configuration,
  :target_network,
  :target_deployment,
  :tags,
  :scope_tags)
  SENSITIVE = [:tags, :scope_tags]
  include Aws::Structure
end

#scope_tagsHash<String,String>

Scope tags for the network migration definition to control access and organization.

Returns:



572
573
574
575
576
577
578
579
580
581
582
583
# File 'lib/aws-sdk-mgn/types.rb', line 572

class CreateNetworkMigrationDefinitionRequest < Struct.new(
  :name,
  :description,
  :source_configurations,
  :target_s3_configuration,
  :target_network,
  :target_deployment,
  :tags,
  :scope_tags)
  SENSITIVE = [:tags, :scope_tags]
  include Aws::Structure
end

#source_configurationsArray<Types::SourceConfiguration>

A list of source configurations for the network migration.

Returns:



572
573
574
575
576
577
578
579
580
581
582
583
# File 'lib/aws-sdk-mgn/types.rb', line 572

class CreateNetworkMigrationDefinitionRequest < Struct.new(
  :name,
  :description,
  :source_configurations,
  :target_s3_configuration,
  :target_network,
  :target_deployment,
  :tags,
  :scope_tags)
  SENSITIVE = [:tags, :scope_tags]
  include Aws::Structure
end

#tagsHash<String,String>

Tags to assign to the network migration definition.

Returns:



572
573
574
575
576
577
578
579
580
581
582
583
# File 'lib/aws-sdk-mgn/types.rb', line 572

class CreateNetworkMigrationDefinitionRequest < Struct.new(
  :name,
  :description,
  :source_configurations,
  :target_s3_configuration,
  :target_network,
  :target_deployment,
  :tags,
  :scope_tags)
  SENSITIVE = [:tags, :scope_tags]
  include Aws::Structure
end

#target_deploymentString

The target deployment configuration for the migrated network.

Returns:



572
573
574
575
576
577
578
579
580
581
582
583
# File 'lib/aws-sdk-mgn/types.rb', line 572

class CreateNetworkMigrationDefinitionRequest < Struct.new(
  :name,
  :description,
  :source_configurations,
  :target_s3_configuration,
  :target_network,
  :target_deployment,
  :tags,
  :scope_tags)
  SENSITIVE = [:tags, :scope_tags]
  include Aws::Structure
end

#target_networkTypes::TargetNetwork

The target network configuration including topology and CIDR ranges.

Returns:



572
573
574
575
576
577
578
579
580
581
582
583
# File 'lib/aws-sdk-mgn/types.rb', line 572

class CreateNetworkMigrationDefinitionRequest < Struct.new(
  :name,
  :description,
  :source_configurations,
  :target_s3_configuration,
  :target_network,
  :target_deployment,
  :tags,
  :scope_tags)
  SENSITIVE = [:tags, :scope_tags]
  include Aws::Structure
end

#target_s3_configurationTypes::TargetS3Configuration

The S3 configuration for storing the target network artifacts.

Returns:



572
573
574
575
576
577
578
579
580
581
582
583
# File 'lib/aws-sdk-mgn/types.rb', line 572

class CreateNetworkMigrationDefinitionRequest < Struct.new(
  :name,
  :description,
  :source_configurations,
  :target_s3_configuration,
  :target_network,
  :target_deployment,
  :tags,
  :scope_tags)
  SENSITIVE = [:tags, :scope_tags]
  include Aws::Structure
end