Class: Aws::Mgn::Types::CreateNetworkMigrationDefinitionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Mgn::Types::CreateNetworkMigrationDefinitionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mgn/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:tags, :scope_tags]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the network migration definition.
-
#name ⇒ String
The name of the network migration definition.
-
#scope_tags ⇒ Hash<String,String>
Scope tags for the network migration definition to control access and organization.
-
#source_configurations ⇒ Array<Types::SourceConfiguration>
A list of source configurations for the network migration.
-
#tags ⇒ Hash<String,String>
Tags to assign to the network migration definition.
-
#target_deployment ⇒ String
The target deployment configuration for the migrated network.
-
#target_network ⇒ Types::TargetNetwork
The target network configuration including topology and CIDR ranges.
-
#target_s3_configuration ⇒ Types::TargetS3Configuration
The S3 configuration for storing the target network artifacts.
Instance Attribute Details
#description ⇒ String
A description of the network migration definition.
572 573 574 575 576 577 578 579 580 581 582 583 |
# File 'lib/aws-sdk-mgn/types.rb', line 572 class CreateNetworkMigrationDefinitionRequest < Struct.new( :name, :description, :source_configurations, :target_s3_configuration, :target_network, :target_deployment, :tags, :scope_tags) SENSITIVE = [:tags, :scope_tags] include Aws::Structure end |
#name ⇒ String
The name of the network migration definition.
572 573 574 575 576 577 578 579 580 581 582 583 |
# File 'lib/aws-sdk-mgn/types.rb', line 572 class CreateNetworkMigrationDefinitionRequest < Struct.new( :name, :description, :source_configurations, :target_s3_configuration, :target_network, :target_deployment, :tags, :scope_tags) SENSITIVE = [:tags, :scope_tags] include Aws::Structure end |
#scope_tags ⇒ Hash<String,String>
Scope tags for the network migration definition to control access and organization.
572 573 574 575 576 577 578 579 580 581 582 583 |
# File 'lib/aws-sdk-mgn/types.rb', line 572 class CreateNetworkMigrationDefinitionRequest < Struct.new( :name, :description, :source_configurations, :target_s3_configuration, :target_network, :target_deployment, :tags, :scope_tags) SENSITIVE = [:tags, :scope_tags] include Aws::Structure end |
#source_configurations ⇒ Array<Types::SourceConfiguration>
A list of source configurations for the network migration.
572 573 574 575 576 577 578 579 580 581 582 583 |
# File 'lib/aws-sdk-mgn/types.rb', line 572 class CreateNetworkMigrationDefinitionRequest < Struct.new( :name, :description, :source_configurations, :target_s3_configuration, :target_network, :target_deployment, :tags, :scope_tags) SENSITIVE = [:tags, :scope_tags] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Tags to assign to the network migration definition.
572 573 574 575 576 577 578 579 580 581 582 583 |
# File 'lib/aws-sdk-mgn/types.rb', line 572 class CreateNetworkMigrationDefinitionRequest < Struct.new( :name, :description, :source_configurations, :target_s3_configuration, :target_network, :target_deployment, :tags, :scope_tags) SENSITIVE = [:tags, :scope_tags] include Aws::Structure end |
#target_deployment ⇒ String
The target deployment configuration for the migrated network.
572 573 574 575 576 577 578 579 580 581 582 583 |
# File 'lib/aws-sdk-mgn/types.rb', line 572 class CreateNetworkMigrationDefinitionRequest < Struct.new( :name, :description, :source_configurations, :target_s3_configuration, :target_network, :target_deployment, :tags, :scope_tags) SENSITIVE = [:tags, :scope_tags] include Aws::Structure end |
#target_network ⇒ Types::TargetNetwork
The target network configuration including topology and CIDR ranges.
572 573 574 575 576 577 578 579 580 581 582 583 |
# File 'lib/aws-sdk-mgn/types.rb', line 572 class CreateNetworkMigrationDefinitionRequest < Struct.new( :name, :description, :source_configurations, :target_s3_configuration, :target_network, :target_deployment, :tags, :scope_tags) SENSITIVE = [:tags, :scope_tags] include Aws::Structure end |
#target_s3_configuration ⇒ Types::TargetS3Configuration
The S3 configuration for storing the target network artifacts.
572 573 574 575 576 577 578 579 580 581 582 583 |
# File 'lib/aws-sdk-mgn/types.rb', line 572 class CreateNetworkMigrationDefinitionRequest < Struct.new( :name, :description, :source_configurations, :target_s3_configuration, :target_network, :target_deployment, :tags, :scope_tags) SENSITIVE = [:tags, :scope_tags] include Aws::Structure end |