Class: Aws::Mgn::Types::GetNetworkMigrationMapperSegmentConstructRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Mgn::Types::GetNetworkMigrationMapperSegmentConstructRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mgn/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#construct_id ⇒ String
The unique identifier of the construct within the segment.
-
#network_migration_definition_id ⇒ String
The unique identifier of the network migration definition.
-
#network_migration_execution_id ⇒ String
The unique identifier of the network migration execution.
-
#segment_id ⇒ String
The unique identifier of the mapper segment.
Instance Attribute Details
#construct_id ⇒ String
The unique identifier of the construct within the segment.
1711 1712 1713 1714 1715 1716 1717 1718 |
# File 'lib/aws-sdk-mgn/types.rb', line 1711 class GetNetworkMigrationMapperSegmentConstructRequest < Struct.new( :network_migration_definition_id, :network_migration_execution_id, :segment_id, :construct_id) SENSITIVE = [] include Aws::Structure end |
#network_migration_definition_id ⇒ String
The unique identifier of the network migration definition.
1711 1712 1713 1714 1715 1716 1717 1718 |
# File 'lib/aws-sdk-mgn/types.rb', line 1711 class GetNetworkMigrationMapperSegmentConstructRequest < Struct.new( :network_migration_definition_id, :network_migration_execution_id, :segment_id, :construct_id) SENSITIVE = [] include Aws::Structure end |
#network_migration_execution_id ⇒ String
The unique identifier of the network migration execution.
1711 1712 1713 1714 1715 1716 1717 1718 |
# File 'lib/aws-sdk-mgn/types.rb', line 1711 class GetNetworkMigrationMapperSegmentConstructRequest < Struct.new( :network_migration_definition_id, :network_migration_execution_id, :segment_id, :construct_id) SENSITIVE = [] include Aws::Structure end |
#segment_id ⇒ String
The unique identifier of the mapper segment.
1711 1712 1713 1714 1715 1716 1717 1718 |
# File 'lib/aws-sdk-mgn/types.rb', line 1711 class GetNetworkMigrationMapperSegmentConstructRequest < Struct.new( :network_migration_definition_id, :network_migration_execution_id, :segment_id, :construct_id) SENSITIVE = [] include Aws::Structure end |