Class: Aws::Mgn::Types::ImportFileEnrichment

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mgn/types.rb

Overview

Details about an import file enrichment job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#checksumTypes::Checksum

The checksum of the enriched file for integrity verification.

Returns:



1826
1827
1828
1829
1830
1831
1832
1833
1834
1835
1836
# File 'lib/aws-sdk-mgn/types.rb', line 1826

class ImportFileEnrichment < Struct.new(
  :job_id,
  :created_at,
  :ended_at,
  :status,
  :status_details,
  :checksum,
  :s3_bucket_target)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The timestamp when the enrichment job was created.

Returns:

  • (Time)


1826
1827
1828
1829
1830
1831
1832
1833
1834
1835
1836
# File 'lib/aws-sdk-mgn/types.rb', line 1826

class ImportFileEnrichment < Struct.new(
  :job_id,
  :created_at,
  :ended_at,
  :status,
  :status_details,
  :checksum,
  :s3_bucket_target)
  SENSITIVE = []
  include Aws::Structure
end

#ended_atTime

The timestamp when the enrichment job completed or failed.

Returns:

  • (Time)


1826
1827
1828
1829
1830
1831
1832
1833
1834
1835
1836
# File 'lib/aws-sdk-mgn/types.rb', line 1826

class ImportFileEnrichment < Struct.new(
  :job_id,
  :created_at,
  :ended_at,
  :status,
  :status_details,
  :checksum,
  :s3_bucket_target)
  SENSITIVE = []
  include Aws::Structure
end

#job_idString

The unique identifier of the import file enrichment job.

Returns:

  • (String)


1826
1827
1828
1829
1830
1831
1832
1833
1834
1835
1836
# File 'lib/aws-sdk-mgn/types.rb', line 1826

class ImportFileEnrichment < Struct.new(
  :job_id,
  :created_at,
  :ended_at,
  :status,
  :status_details,
  :checksum,
  :s3_bucket_target)
  SENSITIVE = []
  include Aws::Structure
end

#s3_bucket_targetTypes::EnrichmentTargetS3Configuration

The target S3 configuration for the enriched import file.



1826
1827
1828
1829
1830
1831
1832
1833
1834
1835
1836
# File 'lib/aws-sdk-mgn/types.rb', line 1826

class ImportFileEnrichment < Struct.new(
  :job_id,
  :created_at,
  :ended_at,
  :status,
  :status_details,
  :checksum,
  :s3_bucket_target)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the import file enrichment job.

Returns:

  • (String)


1826
1827
1828
1829
1830
1831
1832
1833
1834
1835
1836
# File 'lib/aws-sdk-mgn/types.rb', line 1826

class ImportFileEnrichment < Struct.new(
  :job_id,
  :created_at,
  :ended_at,
  :status,
  :status_details,
  :checksum,
  :s3_bucket_target)
  SENSITIVE = []
  include Aws::Structure
end

#status_detailsString

Detailed status information about the enrichment job.

Returns:

  • (String)


1826
1827
1828
1829
1830
1831
1832
1833
1834
1835
1836
# File 'lib/aws-sdk-mgn/types.rb', line 1826

class ImportFileEnrichment < Struct.new(
  :job_id,
  :created_at,
  :ended_at,
  :status,
  :status_details,
  :checksum,
  :s3_bucket_target)
  SENSITIVE = []
  include Aws::Structure
end