Class: Aws::Mgn::Types::ImportFileEnrichment
- Inherits:
-
Struct
- Object
- Struct
- Aws::Mgn::Types::ImportFileEnrichment
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mgn/types.rb
Overview
Details about an import file enrichment job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#checksum ⇒ Types::Checksum
The checksum of the enriched file for integrity verification.
-
#created_at ⇒ Time
The timestamp when the enrichment job was created.
-
#ended_at ⇒ Time
The timestamp when the enrichment job completed or failed.
-
#job_id ⇒ String
The unique identifier of the import file enrichment job.
-
#s3_bucket_target ⇒ Types::EnrichmentTargetS3Configuration
The target S3 configuration for the enriched import file.
-
#status ⇒ String
The current status of the import file enrichment job.
-
#status_details ⇒ String
Detailed status information about the enrichment job.
Instance Attribute Details
#checksum ⇒ Types::Checksum
The checksum of the enriched file for integrity verification.
1826 1827 1828 1829 1830 1831 1832 1833 1834 1835 1836 |
# File 'lib/aws-sdk-mgn/types.rb', line 1826 class ImportFileEnrichment < Struct.new( :job_id, :created_at, :ended_at, :status, :status_details, :checksum, :s3_bucket_target) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The timestamp when the enrichment job was created.
1826 1827 1828 1829 1830 1831 1832 1833 1834 1835 1836 |
# File 'lib/aws-sdk-mgn/types.rb', line 1826 class ImportFileEnrichment < Struct.new( :job_id, :created_at, :ended_at, :status, :status_details, :checksum, :s3_bucket_target) SENSITIVE = [] include Aws::Structure end |
#ended_at ⇒ Time
The timestamp when the enrichment job completed or failed.
1826 1827 1828 1829 1830 1831 1832 1833 1834 1835 1836 |
# File 'lib/aws-sdk-mgn/types.rb', line 1826 class ImportFileEnrichment < Struct.new( :job_id, :created_at, :ended_at, :status, :status_details, :checksum, :s3_bucket_target) SENSITIVE = [] include Aws::Structure end |
#job_id ⇒ String
The unique identifier of the import file enrichment job.
1826 1827 1828 1829 1830 1831 1832 1833 1834 1835 1836 |
# File 'lib/aws-sdk-mgn/types.rb', line 1826 class ImportFileEnrichment < Struct.new( :job_id, :created_at, :ended_at, :status, :status_details, :checksum, :s3_bucket_target) SENSITIVE = [] include Aws::Structure end |
#s3_bucket_target ⇒ Types::EnrichmentTargetS3Configuration
The target S3 configuration for the enriched import file.
1826 1827 1828 1829 1830 1831 1832 1833 1834 1835 1836 |
# File 'lib/aws-sdk-mgn/types.rb', line 1826 class ImportFileEnrichment < Struct.new( :job_id, :created_at, :ended_at, :status, :status_details, :checksum, :s3_bucket_target) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the import file enrichment job.
1826 1827 1828 1829 1830 1831 1832 1833 1834 1835 1836 |
# File 'lib/aws-sdk-mgn/types.rb', line 1826 class ImportFileEnrichment < Struct.new( :job_id, :created_at, :ended_at, :status, :status_details, :checksum, :s3_bucket_target) SENSITIVE = [] include Aws::Structure end |
#status_details ⇒ String
Detailed status information about the enrichment job.
1826 1827 1828 1829 1830 1831 1832 1833 1834 1835 1836 |
# File 'lib/aws-sdk-mgn/types.rb', line 1826 class ImportFileEnrichment < Struct.new( :job_id, :created_at, :ended_at, :status, :status_details, :checksum, :s3_bucket_target) SENSITIVE = [] include Aws::Structure end |