Class: Aws::Mgn::Types::ListTemplateActionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Mgn::Types::ListTemplateActionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mgn/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Types::TemplateActionsRequestFilters
Filters to apply when listing template post migration custom actions.
-
#launch_configuration_template_id ⇒ String
Launch configuration template ID.
-
#max_results ⇒ Integer
Maximum amount of items to return when listing template post migration custom actions.
-
#next_token ⇒ String
Next token to use when listing template post migration custom actions.
Instance Attribute Details
#filters ⇒ Types::TemplateActionsRequestFilters
Filters to apply when listing template post migration custom actions.
3863 3864 3865 3866 3867 3868 3869 3870 |
# File 'lib/aws-sdk-mgn/types.rb', line 3863 class ListTemplateActionsRequest < Struct.new( :launch_configuration_template_id, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#launch_configuration_template_id ⇒ String
Launch configuration template ID.
3863 3864 3865 3866 3867 3868 3869 3870 |
# File 'lib/aws-sdk-mgn/types.rb', line 3863 class ListTemplateActionsRequest < Struct.new( :launch_configuration_template_id, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
Maximum amount of items to return when listing template post migration custom actions.
3863 3864 3865 3866 3867 3868 3869 3870 |
# File 'lib/aws-sdk-mgn/types.rb', line 3863 class ListTemplateActionsRequest < Struct.new( :launch_configuration_template_id, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Next token to use when listing template post migration custom actions.
3863 3864 3865 3866 3867 3868 3869 3870 |
# File 'lib/aws-sdk-mgn/types.rb', line 3863 class ListTemplateActionsRequest < Struct.new( :launch_configuration_template_id, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |