Class: Aws::Mgn::Types::MergeOperation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mgn/types.rb

Overview

An operation that merges constructs from different segments into the target construct.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#merge_constructsArray<Types::MergeConstruct>

The list of constructs to merge into the target.

Returns:



4021
4022
4023
4024
4025
# File 'lib/aws-sdk-mgn/types.rb', line 4021

class MergeOperation < Struct.new(
  :merge_constructs)
  SENSITIVE = []
  include Aws::Structure
end