Class: Aws::Mgn::Types::MergeOperation
- Inherits:
-
Struct
- Object
- Struct
- Aws::Mgn::Types::MergeOperation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mgn/types.rb
Overview
An operation that merges constructs from different segments into the target construct.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#merge_constructs ⇒ Array<Types::MergeConstruct>
The list of constructs to merge into the target.
Instance Attribute Details
#merge_constructs ⇒ Array<Types::MergeConstruct>
The list of constructs to merge into the target.
4021 4022 4023 4024 4025 |
# File 'lib/aws-sdk-mgn/types.rb', line 4021 class MergeOperation < Struct.new( :merge_constructs) SENSITIVE = [] include Aws::Structure end |