Class: Aws::Mgn::Types::NetworkMigrationCodeGenerationSegment

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mgn/types.rb

Overview

A segment of generated code representing a logical grouping of infrastructure resources.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#artifactsArray<Types::NetworkMigrationCodeGenerationArtifact>

A list of artifacts generated for this segment.



4324
4325
4326
4327
4328
4329
4330
4331
4332
4333
4334
4335
4336
4337
# File 'lib/aws-sdk-mgn/types.rb', line 4324

class NetworkMigrationCodeGenerationSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :logical_id,
  :mapper_segment_id,
  :artifacts,
  :referenced_segments,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The timestamp when the segment was created.

Returns:

  • (Time)


4324
4325
4326
4327
4328
4329
4330
4331
4332
4333
4334
4335
4336
4337
# File 'lib/aws-sdk-mgn/types.rb', line 4324

class NetworkMigrationCodeGenerationSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :logical_id,
  :mapper_segment_id,
  :artifacts,
  :referenced_segments,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#job_idString

The unique identifier of the code generation job.

Returns:

  • (String)


4324
4325
4326
4327
4328
4329
4330
4331
4332
4333
4334
4335
4336
4337
# File 'lib/aws-sdk-mgn/types.rb', line 4324

class NetworkMigrationCodeGenerationSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :logical_id,
  :mapper_segment_id,
  :artifacts,
  :referenced_segments,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#logical_idString

The logical identifier for the segment.

Returns:

  • (String)


4324
4325
4326
4327
4328
4329
4330
4331
4332
4333
4334
4335
4336
4337
# File 'lib/aws-sdk-mgn/types.rb', line 4324

class NetworkMigrationCodeGenerationSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :logical_id,
  :mapper_segment_id,
  :artifacts,
  :referenced_segments,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#mapper_segment_idString

The ID of the mapper segment that this code generation segment was created from.

Returns:

  • (String)


4324
4325
4326
4327
4328
4329
4330
4331
4332
4333
4334
4335
4336
4337
# File 'lib/aws-sdk-mgn/types.rb', line 4324

class NetworkMigrationCodeGenerationSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :logical_id,
  :mapper_segment_id,
  :artifacts,
  :referenced_segments,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#network_migration_definition_idString

The unique identifier of the network migration definition.

Returns:

  • (String)


4324
4325
4326
4327
4328
4329
4330
4331
4332
4333
4334
4335
4336
4337
# File 'lib/aws-sdk-mgn/types.rb', line 4324

class NetworkMigrationCodeGenerationSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :logical_id,
  :mapper_segment_id,
  :artifacts,
  :referenced_segments,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#network_migration_execution_idString

The unique identifier of the network migration execution.

Returns:

  • (String)


4324
4325
4326
4327
4328
4329
4330
4331
4332
4333
4334
4335
4336
4337
# File 'lib/aws-sdk-mgn/types.rb', line 4324

class NetworkMigrationCodeGenerationSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :logical_id,
  :mapper_segment_id,
  :artifacts,
  :referenced_segments,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#referenced_segmentsArray<String>

A list of other segments that this segment depends on or references.

Returns:

  • (Array<String>)


4324
4325
4326
4327
4328
4329
4330
4331
4332
4333
4334
4335
4336
4337
# File 'lib/aws-sdk-mgn/types.rb', line 4324

class NetworkMigrationCodeGenerationSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :logical_id,
  :mapper_segment_id,
  :artifacts,
  :referenced_segments,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#segment_idString

The unique identifier of the segment.

Returns:

  • (String)


4324
4325
4326
4327
4328
4329
4330
4331
4332
4333
4334
4335
4336
4337
# File 'lib/aws-sdk-mgn/types.rb', line 4324

class NetworkMigrationCodeGenerationSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :logical_id,
  :mapper_segment_id,
  :artifacts,
  :referenced_segments,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#segment_typeString

The type of the segment.

Returns:

  • (String)


4324
4325
4326
4327
4328
4329
4330
4331
4332
4333
4334
4335
4336
4337
# File 'lib/aws-sdk-mgn/types.rb', line 4324

class NetworkMigrationCodeGenerationSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :logical_id,
  :mapper_segment_id,
  :artifacts,
  :referenced_segments,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end