Class: Aws::Mgn::Types::NetworkMigrationCodeGenerationSegment
- Inherits:
-
Struct
- Object
- Struct
- Aws::Mgn::Types::NetworkMigrationCodeGenerationSegment
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mgn/types.rb
Overview
A segment of generated code representing a logical grouping of infrastructure resources.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#artifacts ⇒ Array<Types::NetworkMigrationCodeGenerationArtifact>
A list of artifacts generated for this segment.
-
#created_at ⇒ Time
The timestamp when the segment was created.
-
#job_id ⇒ String
The unique identifier of the code generation job.
-
#logical_id ⇒ String
The logical identifier for the segment.
-
#mapper_segment_id ⇒ String
The ID of the mapper segment that this code generation segment was created from.
-
#network_migration_definition_id ⇒ String
The unique identifier of the network migration definition.
-
#network_migration_execution_id ⇒ String
The unique identifier of the network migration execution.
-
#referenced_segments ⇒ Array<String>
A list of other segments that this segment depends on or references.
-
#segment_id ⇒ String
The unique identifier of the segment.
-
#segment_type ⇒ String
The type of the segment.
Instance Attribute Details
#artifacts ⇒ Array<Types::NetworkMigrationCodeGenerationArtifact>
A list of artifacts generated for this segment.
4324 4325 4326 4327 4328 4329 4330 4331 4332 4333 4334 4335 4336 4337 |
# File 'lib/aws-sdk-mgn/types.rb', line 4324 class NetworkMigrationCodeGenerationSegment < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :segment_id, :segment_type, :logical_id, :mapper_segment_id, :artifacts, :referenced_segments, :created_at) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The timestamp when the segment was created.
4324 4325 4326 4327 4328 4329 4330 4331 4332 4333 4334 4335 4336 4337 |
# File 'lib/aws-sdk-mgn/types.rb', line 4324 class NetworkMigrationCodeGenerationSegment < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :segment_id, :segment_type, :logical_id, :mapper_segment_id, :artifacts, :referenced_segments, :created_at) SENSITIVE = [] include Aws::Structure end |
#job_id ⇒ String
The unique identifier of the code generation job.
4324 4325 4326 4327 4328 4329 4330 4331 4332 4333 4334 4335 4336 4337 |
# File 'lib/aws-sdk-mgn/types.rb', line 4324 class NetworkMigrationCodeGenerationSegment < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :segment_id, :segment_type, :logical_id, :mapper_segment_id, :artifacts, :referenced_segments, :created_at) SENSITIVE = [] include Aws::Structure end |
#logical_id ⇒ String
The logical identifier for the segment.
4324 4325 4326 4327 4328 4329 4330 4331 4332 4333 4334 4335 4336 4337 |
# File 'lib/aws-sdk-mgn/types.rb', line 4324 class NetworkMigrationCodeGenerationSegment < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :segment_id, :segment_type, :logical_id, :mapper_segment_id, :artifacts, :referenced_segments, :created_at) SENSITIVE = [] include Aws::Structure end |
#mapper_segment_id ⇒ String
The ID of the mapper segment that this code generation segment was created from.
4324 4325 4326 4327 4328 4329 4330 4331 4332 4333 4334 4335 4336 4337 |
# File 'lib/aws-sdk-mgn/types.rb', line 4324 class NetworkMigrationCodeGenerationSegment < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :segment_id, :segment_type, :logical_id, :mapper_segment_id, :artifacts, :referenced_segments, :created_at) SENSITIVE = [] include Aws::Structure end |
#network_migration_definition_id ⇒ String
The unique identifier of the network migration definition.
4324 4325 4326 4327 4328 4329 4330 4331 4332 4333 4334 4335 4336 4337 |
# File 'lib/aws-sdk-mgn/types.rb', line 4324 class NetworkMigrationCodeGenerationSegment < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :segment_id, :segment_type, :logical_id, :mapper_segment_id, :artifacts, :referenced_segments, :created_at) SENSITIVE = [] include Aws::Structure end |
#network_migration_execution_id ⇒ String
The unique identifier of the network migration execution.
4324 4325 4326 4327 4328 4329 4330 4331 4332 4333 4334 4335 4336 4337 |
# File 'lib/aws-sdk-mgn/types.rb', line 4324 class NetworkMigrationCodeGenerationSegment < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :segment_id, :segment_type, :logical_id, :mapper_segment_id, :artifacts, :referenced_segments, :created_at) SENSITIVE = [] include Aws::Structure end |
#referenced_segments ⇒ Array<String>
A list of other segments that this segment depends on or references.
4324 4325 4326 4327 4328 4329 4330 4331 4332 4333 4334 4335 4336 4337 |
# File 'lib/aws-sdk-mgn/types.rb', line 4324 class NetworkMigrationCodeGenerationSegment < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :segment_id, :segment_type, :logical_id, :mapper_segment_id, :artifacts, :referenced_segments, :created_at) SENSITIVE = [] include Aws::Structure end |
#segment_id ⇒ String
The unique identifier of the segment.
4324 4325 4326 4327 4328 4329 4330 4331 4332 4333 4334 4335 4336 4337 |
# File 'lib/aws-sdk-mgn/types.rb', line 4324 class NetworkMigrationCodeGenerationSegment < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :segment_id, :segment_type, :logical_id, :mapper_segment_id, :artifacts, :referenced_segments, :created_at) SENSITIVE = [] include Aws::Structure end |
#segment_type ⇒ String
The type of the segment.
4324 4325 4326 4327 4328 4329 4330 4331 4332 4333 4334 4335 4336 4337 |
# File 'lib/aws-sdk-mgn/types.rb', line 4324 class NetworkMigrationCodeGenerationSegment < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :segment_id, :segment_type, :logical_id, :mapper_segment_id, :artifacts, :referenced_segments, :created_at) SENSITIVE = [] include Aws::Structure end |