Class: Aws::Mgn::Types::NetworkMigrationCodeGenerationSegment

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mgn/types.rb

Overview

A segment of generated code representing a logical grouping of infrastructure resources.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#artifactsArray<Types::NetworkMigrationCodeGenerationArtifact>

A list of artifacts generated for this segment.

Returns:



4277
4278
4279
4280
4281
4282
4283
4284
4285
4286
4287
4288
4289
# File 'lib/aws-sdk-mgn/types.rb', line 4277

class NetworkMigrationCodeGenerationSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :logical_id,
  :mapper_segment_id,
  :artifacts,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The timestamp when the segment was created.

Returns:



4277
4278
4279
4280
4281
4282
4283
4284
4285
4286
4287
4288
4289
# File 'lib/aws-sdk-mgn/types.rb', line 4277

class NetworkMigrationCodeGenerationSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :logical_id,
  :mapper_segment_id,
  :artifacts,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#job_idString

The unique identifier of the code generation job.

Returns:



4277
4278
4279
4280
4281
4282
4283
4284
4285
4286
4287
4288
4289
# File 'lib/aws-sdk-mgn/types.rb', line 4277

class NetworkMigrationCodeGenerationSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :logical_id,
  :mapper_segment_id,
  :artifacts,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#logical_idString

The logical identifier for the segment.

Returns:



4277
4278
4279
4280
4281
4282
4283
4284
4285
4286
4287
4288
4289
# File 'lib/aws-sdk-mgn/types.rb', line 4277

class NetworkMigrationCodeGenerationSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :logical_id,
  :mapper_segment_id,
  :artifacts,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#mapper_segment_idString

The ID of the mapper segment that this code generation segment was created from.

Returns:



4277
4278
4279
4280
4281
4282
4283
4284
4285
4286
4287
4288
4289
# File 'lib/aws-sdk-mgn/types.rb', line 4277

class NetworkMigrationCodeGenerationSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :logical_id,
  :mapper_segment_id,
  :artifacts,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#network_migration_definition_idString

The unique identifier of the network migration definition.

Returns:



4277
4278
4279
4280
4281
4282
4283
4284
4285
4286
4287
4288
4289
# File 'lib/aws-sdk-mgn/types.rb', line 4277

class NetworkMigrationCodeGenerationSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :logical_id,
  :mapper_segment_id,
  :artifacts,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#network_migration_execution_idString

The unique identifier of the network migration execution.

Returns:



4277
4278
4279
4280
4281
4282
4283
4284
4285
4286
4287
4288
4289
# File 'lib/aws-sdk-mgn/types.rb', line 4277

class NetworkMigrationCodeGenerationSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :logical_id,
  :mapper_segment_id,
  :artifacts,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#segment_idString

The unique identifier of the segment.

Returns:



4277
4278
4279
4280
4281
4282
4283
4284
4285
4286
4287
4288
4289
# File 'lib/aws-sdk-mgn/types.rb', line 4277

class NetworkMigrationCodeGenerationSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :logical_id,
  :mapper_segment_id,
  :artifacts,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#segment_typeString

The type of the segment.

Returns:



4277
4278
4279
4280
4281
4282
4283
4284
4285
4286
4287
4288
4289
# File 'lib/aws-sdk-mgn/types.rb', line 4277

class NetworkMigrationCodeGenerationSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :logical_id,
  :mapper_segment_id,
  :artifacts,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end