Class: Aws::Mgn::Types::NetworkMigrationCodeGenerationSegment
- Inherits:
-
Struct
- Object
- Struct
- Aws::Mgn::Types::NetworkMigrationCodeGenerationSegment
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mgn/types.rb
Overview
A segment of generated code representing a logical grouping of infrastructure resources.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#artifacts ⇒ Array<Types::NetworkMigrationCodeGenerationArtifact>
A list of artifacts generated for this segment.
-
#created_at ⇒ Time
The timestamp when the segment was created.
-
#job_id ⇒ String
The unique identifier of the code generation job.
-
#logical_id ⇒ String
The logical identifier for the segment.
-
#mapper_segment_id ⇒ String
The ID of the mapper segment that this code generation segment was created from.
-
#network_migration_definition_id ⇒ String
The unique identifier of the network migration definition.
-
#network_migration_execution_id ⇒ String
The unique identifier of the network migration execution.
-
#segment_id ⇒ String
The unique identifier of the segment.
-
#segment_type ⇒ String
The type of the segment.
Instance Attribute Details
#artifacts ⇒ Array<Types::NetworkMigrationCodeGenerationArtifact>
A list of artifacts generated for this segment.
4277 4278 4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 4289 |
# File 'lib/aws-sdk-mgn/types.rb', line 4277 class NetworkMigrationCodeGenerationSegment < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :segment_id, :segment_type, :logical_id, :mapper_segment_id, :artifacts, :created_at) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The timestamp when the segment was created.
4277 4278 4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 4289 |
# File 'lib/aws-sdk-mgn/types.rb', line 4277 class NetworkMigrationCodeGenerationSegment < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :segment_id, :segment_type, :logical_id, :mapper_segment_id, :artifacts, :created_at) SENSITIVE = [] include Aws::Structure end |
#job_id ⇒ String
The unique identifier of the code generation job.
4277 4278 4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 4289 |
# File 'lib/aws-sdk-mgn/types.rb', line 4277 class NetworkMigrationCodeGenerationSegment < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :segment_id, :segment_type, :logical_id, :mapper_segment_id, :artifacts, :created_at) SENSITIVE = [] include Aws::Structure end |
#logical_id ⇒ String
The logical identifier for the segment.
4277 4278 4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 4289 |
# File 'lib/aws-sdk-mgn/types.rb', line 4277 class NetworkMigrationCodeGenerationSegment < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :segment_id, :segment_type, :logical_id, :mapper_segment_id, :artifacts, :created_at) SENSITIVE = [] include Aws::Structure end |
#mapper_segment_id ⇒ String
The ID of the mapper segment that this code generation segment was created from.
4277 4278 4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 4289 |
# File 'lib/aws-sdk-mgn/types.rb', line 4277 class NetworkMigrationCodeGenerationSegment < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :segment_id, :segment_type, :logical_id, :mapper_segment_id, :artifacts, :created_at) SENSITIVE = [] include Aws::Structure end |
#network_migration_definition_id ⇒ String
The unique identifier of the network migration definition.
4277 4278 4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 4289 |
# File 'lib/aws-sdk-mgn/types.rb', line 4277 class NetworkMigrationCodeGenerationSegment < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :segment_id, :segment_type, :logical_id, :mapper_segment_id, :artifacts, :created_at) SENSITIVE = [] include Aws::Structure end |
#network_migration_execution_id ⇒ String
The unique identifier of the network migration execution.
4277 4278 4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 4289 |
# File 'lib/aws-sdk-mgn/types.rb', line 4277 class NetworkMigrationCodeGenerationSegment < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :segment_id, :segment_type, :logical_id, :mapper_segment_id, :artifacts, :created_at) SENSITIVE = [] include Aws::Structure end |
#segment_id ⇒ String
The unique identifier of the segment.
4277 4278 4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 4289 |
# File 'lib/aws-sdk-mgn/types.rb', line 4277 class NetworkMigrationCodeGenerationSegment < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :segment_id, :segment_type, :logical_id, :mapper_segment_id, :artifacts, :created_at) SENSITIVE = [] include Aws::Structure end |
#segment_type ⇒ String
The type of the segment.
4277 4278 4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 4289 |
# File 'lib/aws-sdk-mgn/types.rb', line 4277 class NetworkMigrationCodeGenerationSegment < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :segment_id, :segment_type, :logical_id, :mapper_segment_id, :artifacts, :created_at) SENSITIVE = [] include Aws::Structure end |