Class: Aws::Mgn::Types::NetworkMigrationDefinition

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mgn/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:tags, :scope_tags]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the network migration definition.

Returns:



4342
4343
4344
4345
4346
4347
4348
4349
4350
4351
4352
4353
4354
4355
4356
4357
# File 'lib/aws-sdk-mgn/types.rb', line 4342

class NetworkMigrationDefinition < Struct.new(
  :arn,
  :network_migration_definition_id,
  :name,
  :description,
  :source_configurations,
  :target_s3_configuration,
  :target_network,
  :target_deployment,
  :created_at,
  :updated_at,
  :tags,
  :scope_tags)
  SENSITIVE = [:tags, :scope_tags]
  include Aws::Structure
end

#created_atTime

The timestamp when the network migration definition was created.

Returns:



4342
4343
4344
4345
4346
4347
4348
4349
4350
4351
4352
4353
4354
4355
4356
4357
# File 'lib/aws-sdk-mgn/types.rb', line 4342

class NetworkMigrationDefinition < Struct.new(
  :arn,
  :network_migration_definition_id,
  :name,
  :description,
  :source_configurations,
  :target_s3_configuration,
  :target_network,
  :target_deployment,
  :created_at,
  :updated_at,
  :tags,
  :scope_tags)
  SENSITIVE = [:tags, :scope_tags]
  include Aws::Structure
end

#descriptionString

A description of the network migration definition.

Returns:



4342
4343
4344
4345
4346
4347
4348
4349
4350
4351
4352
4353
4354
4355
4356
4357
# File 'lib/aws-sdk-mgn/types.rb', line 4342

class NetworkMigrationDefinition < Struct.new(
  :arn,
  :network_migration_definition_id,
  :name,
  :description,
  :source_configurations,
  :target_s3_configuration,
  :target_network,
  :target_deployment,
  :created_at,
  :updated_at,
  :tags,
  :scope_tags)
  SENSITIVE = [:tags, :scope_tags]
  include Aws::Structure
end

#nameString

The name of the network migration definition.

Returns:



4342
4343
4344
4345
4346
4347
4348
4349
4350
4351
4352
4353
4354
4355
4356
4357
# File 'lib/aws-sdk-mgn/types.rb', line 4342

class NetworkMigrationDefinition < Struct.new(
  :arn,
  :network_migration_definition_id,
  :name,
  :description,
  :source_configurations,
  :target_s3_configuration,
  :target_network,
  :target_deployment,
  :created_at,
  :updated_at,
  :tags,
  :scope_tags)
  SENSITIVE = [:tags, :scope_tags]
  include Aws::Structure
end

#network_migration_definition_idString

The unique identifier of the network migration definition.

Returns:



4342
4343
4344
4345
4346
4347
4348
4349
4350
4351
4352
4353
4354
4355
4356
4357
# File 'lib/aws-sdk-mgn/types.rb', line 4342

class NetworkMigrationDefinition < Struct.new(
  :arn,
  :network_migration_definition_id,
  :name,
  :description,
  :source_configurations,
  :target_s3_configuration,
  :target_network,
  :target_deployment,
  :created_at,
  :updated_at,
  :tags,
  :scope_tags)
  SENSITIVE = [:tags, :scope_tags]
  include Aws::Structure
end

#scope_tagsHash<String,String>

Scope tags for the network migration definition.

Returns:



4342
4343
4344
4345
4346
4347
4348
4349
4350
4351
4352
4353
4354
4355
4356
4357
# File 'lib/aws-sdk-mgn/types.rb', line 4342

class NetworkMigrationDefinition < Struct.new(
  :arn,
  :network_migration_definition_id,
  :name,
  :description,
  :source_configurations,
  :target_s3_configuration,
  :target_network,
  :target_deployment,
  :created_at,
  :updated_at,
  :tags,
  :scope_tags)
  SENSITIVE = [:tags, :scope_tags]
  include Aws::Structure
end

#source_configurationsArray<Types::SourceConfiguration>

A list of source configurations for the network migration.

Returns:



4342
4343
4344
4345
4346
4347
4348
4349
4350
4351
4352
4353
4354
4355
4356
4357
# File 'lib/aws-sdk-mgn/types.rb', line 4342

class NetworkMigrationDefinition < Struct.new(
  :arn,
  :network_migration_definition_id,
  :name,
  :description,
  :source_configurations,
  :target_s3_configuration,
  :target_network,
  :target_deployment,
  :created_at,
  :updated_at,
  :tags,
  :scope_tags)
  SENSITIVE = [:tags, :scope_tags]
  include Aws::Structure
end

#tagsHash<String,String>

Tags assigned to the network migration definition.

Returns:



4342
4343
4344
4345
4346
4347
4348
4349
4350
4351
4352
4353
4354
4355
4356
4357
# File 'lib/aws-sdk-mgn/types.rb', line 4342

class NetworkMigrationDefinition < Struct.new(
  :arn,
  :network_migration_definition_id,
  :name,
  :description,
  :source_configurations,
  :target_s3_configuration,
  :target_network,
  :target_deployment,
  :created_at,
  :updated_at,
  :tags,
  :scope_tags)
  SENSITIVE = [:tags, :scope_tags]
  include Aws::Structure
end

#target_deploymentString

The target deployment configuration for the migrated network.

Returns:



4342
4343
4344
4345
4346
4347
4348
4349
4350
4351
4352
4353
4354
4355
4356
4357
# File 'lib/aws-sdk-mgn/types.rb', line 4342

class NetworkMigrationDefinition < Struct.new(
  :arn,
  :network_migration_definition_id,
  :name,
  :description,
  :source_configurations,
  :target_s3_configuration,
  :target_network,
  :target_deployment,
  :created_at,
  :updated_at,
  :tags,
  :scope_tags)
  SENSITIVE = [:tags, :scope_tags]
  include Aws::Structure
end

#target_networkTypes::TargetNetwork

The target network configuration including topology and CIDR ranges.

Returns:



4342
4343
4344
4345
4346
4347
4348
4349
4350
4351
4352
4353
4354
4355
4356
4357
# File 'lib/aws-sdk-mgn/types.rb', line 4342

class NetworkMigrationDefinition < Struct.new(
  :arn,
  :network_migration_definition_id,
  :name,
  :description,
  :source_configurations,
  :target_s3_configuration,
  :target_network,
  :target_deployment,
  :created_at,
  :updated_at,
  :tags,
  :scope_tags)
  SENSITIVE = [:tags, :scope_tags]
  include Aws::Structure
end

#target_s3_configurationTypes::TargetS3Configuration

The S3 configuration for storing the target network artifacts.

Returns:



4342
4343
4344
4345
4346
4347
4348
4349
4350
4351
4352
4353
4354
4355
4356
4357
# File 'lib/aws-sdk-mgn/types.rb', line 4342

class NetworkMigrationDefinition < Struct.new(
  :arn,
  :network_migration_definition_id,
  :name,
  :description,
  :source_configurations,
  :target_s3_configuration,
  :target_network,
  :target_deployment,
  :created_at,
  :updated_at,
  :tags,
  :scope_tags)
  SENSITIVE = [:tags, :scope_tags]
  include Aws::Structure
end

#updated_atTime

The timestamp when the network migration definition was last updated.

Returns:



4342
4343
4344
4345
4346
4347
4348
4349
4350
4351
4352
4353
4354
4355
4356
4357
# File 'lib/aws-sdk-mgn/types.rb', line 4342

class NetworkMigrationDefinition < Struct.new(
  :arn,
  :network_migration_definition_id,
  :name,
  :description,
  :source_configurations,
  :target_s3_configuration,
  :target_network,
  :target_deployment,
  :created_at,
  :updated_at,
  :tags,
  :scope_tags)
  SENSITIVE = [:tags, :scope_tags]
  include Aws::Structure
end