Class: Aws::Mgn::Types::NetworkMigrationDefinition
- Inherits:
-
Struct
- Object
- Struct
- Aws::Mgn::Types::NetworkMigrationDefinition
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mgn/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:tags, :scope_tags]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the network migration definition.
-
#created_at ⇒ Time
The timestamp when the network migration definition was created.
-
#description ⇒ String
A description of the network migration definition.
-
#name ⇒ String
The name of the network migration definition.
-
#network_migration_definition_id ⇒ String
The unique identifier of the network migration definition.
-
#scope_tags ⇒ Hash<String,String>
Scope tags for the network migration definition.
-
#source_configurations ⇒ Array<Types::SourceConfiguration>
A list of source configurations for the network migration.
-
#tags ⇒ Hash<String,String>
Tags assigned to the network migration definition.
-
#target_deployment ⇒ String
The target deployment configuration for the migrated network.
-
#target_network ⇒ Types::TargetNetwork
The target network configuration including topology and CIDR ranges.
-
#target_s3_configuration ⇒ Types::TargetS3Configuration
The S3 configuration for storing the target network artifacts.
-
#updated_at ⇒ Time
The timestamp when the network migration definition was last updated.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the network migration definition.
4342 4343 4344 4345 4346 4347 4348 4349 4350 4351 4352 4353 4354 4355 4356 4357 |
# File 'lib/aws-sdk-mgn/types.rb', line 4342 class NetworkMigrationDefinition < Struct.new( :arn, :network_migration_definition_id, :name, :description, :source_configurations, :target_s3_configuration, :target_network, :target_deployment, :created_at, :updated_at, :tags, :scope_tags) SENSITIVE = [:tags, :scope_tags] include Aws::Structure end |
#created_at ⇒ Time
The timestamp when the network migration definition was created.
4342 4343 4344 4345 4346 4347 4348 4349 4350 4351 4352 4353 4354 4355 4356 4357 |
# File 'lib/aws-sdk-mgn/types.rb', line 4342 class NetworkMigrationDefinition < Struct.new( :arn, :network_migration_definition_id, :name, :description, :source_configurations, :target_s3_configuration, :target_network, :target_deployment, :created_at, :updated_at, :tags, :scope_tags) SENSITIVE = [:tags, :scope_tags] include Aws::Structure end |
#description ⇒ String
A description of the network migration definition.
4342 4343 4344 4345 4346 4347 4348 4349 4350 4351 4352 4353 4354 4355 4356 4357 |
# File 'lib/aws-sdk-mgn/types.rb', line 4342 class NetworkMigrationDefinition < Struct.new( :arn, :network_migration_definition_id, :name, :description, :source_configurations, :target_s3_configuration, :target_network, :target_deployment, :created_at, :updated_at, :tags, :scope_tags) SENSITIVE = [:tags, :scope_tags] include Aws::Structure end |
#name ⇒ String
The name of the network migration definition.
4342 4343 4344 4345 4346 4347 4348 4349 4350 4351 4352 4353 4354 4355 4356 4357 |
# File 'lib/aws-sdk-mgn/types.rb', line 4342 class NetworkMigrationDefinition < Struct.new( :arn, :network_migration_definition_id, :name, :description, :source_configurations, :target_s3_configuration, :target_network, :target_deployment, :created_at, :updated_at, :tags, :scope_tags) SENSITIVE = [:tags, :scope_tags] include Aws::Structure end |
#network_migration_definition_id ⇒ String
The unique identifier of the network migration definition.
4342 4343 4344 4345 4346 4347 4348 4349 4350 4351 4352 4353 4354 4355 4356 4357 |
# File 'lib/aws-sdk-mgn/types.rb', line 4342 class NetworkMigrationDefinition < Struct.new( :arn, :network_migration_definition_id, :name, :description, :source_configurations, :target_s3_configuration, :target_network, :target_deployment, :created_at, :updated_at, :tags, :scope_tags) SENSITIVE = [:tags, :scope_tags] include Aws::Structure end |
#scope_tags ⇒ Hash<String,String>
Scope tags for the network migration definition.
4342 4343 4344 4345 4346 4347 4348 4349 4350 4351 4352 4353 4354 4355 4356 4357 |
# File 'lib/aws-sdk-mgn/types.rb', line 4342 class NetworkMigrationDefinition < Struct.new( :arn, :network_migration_definition_id, :name, :description, :source_configurations, :target_s3_configuration, :target_network, :target_deployment, :created_at, :updated_at, :tags, :scope_tags) SENSITIVE = [:tags, :scope_tags] include Aws::Structure end |
#source_configurations ⇒ Array<Types::SourceConfiguration>
A list of source configurations for the network migration.
4342 4343 4344 4345 4346 4347 4348 4349 4350 4351 4352 4353 4354 4355 4356 4357 |
# File 'lib/aws-sdk-mgn/types.rb', line 4342 class NetworkMigrationDefinition < Struct.new( :arn, :network_migration_definition_id, :name, :description, :source_configurations, :target_s3_configuration, :target_network, :target_deployment, :created_at, :updated_at, :tags, :scope_tags) SENSITIVE = [:tags, :scope_tags] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Tags assigned to the network migration definition.
4342 4343 4344 4345 4346 4347 4348 4349 4350 4351 4352 4353 4354 4355 4356 4357 |
# File 'lib/aws-sdk-mgn/types.rb', line 4342 class NetworkMigrationDefinition < Struct.new( :arn, :network_migration_definition_id, :name, :description, :source_configurations, :target_s3_configuration, :target_network, :target_deployment, :created_at, :updated_at, :tags, :scope_tags) SENSITIVE = [:tags, :scope_tags] include Aws::Structure end |
#target_deployment ⇒ String
The target deployment configuration for the migrated network.
4342 4343 4344 4345 4346 4347 4348 4349 4350 4351 4352 4353 4354 4355 4356 4357 |
# File 'lib/aws-sdk-mgn/types.rb', line 4342 class NetworkMigrationDefinition < Struct.new( :arn, :network_migration_definition_id, :name, :description, :source_configurations, :target_s3_configuration, :target_network, :target_deployment, :created_at, :updated_at, :tags, :scope_tags) SENSITIVE = [:tags, :scope_tags] include Aws::Structure end |
#target_network ⇒ Types::TargetNetwork
The target network configuration including topology and CIDR ranges.
4342 4343 4344 4345 4346 4347 4348 4349 4350 4351 4352 4353 4354 4355 4356 4357 |
# File 'lib/aws-sdk-mgn/types.rb', line 4342 class NetworkMigrationDefinition < Struct.new( :arn, :network_migration_definition_id, :name, :description, :source_configurations, :target_s3_configuration, :target_network, :target_deployment, :created_at, :updated_at, :tags, :scope_tags) SENSITIVE = [:tags, :scope_tags] include Aws::Structure end |
#target_s3_configuration ⇒ Types::TargetS3Configuration
The S3 configuration for storing the target network artifacts.
4342 4343 4344 4345 4346 4347 4348 4349 4350 4351 4352 4353 4354 4355 4356 4357 |
# File 'lib/aws-sdk-mgn/types.rb', line 4342 class NetworkMigrationDefinition < Struct.new( :arn, :network_migration_definition_id, :name, :description, :source_configurations, :target_s3_configuration, :target_network, :target_deployment, :created_at, :updated_at, :tags, :scope_tags) SENSITIVE = [:tags, :scope_tags] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp when the network migration definition was last updated.
4342 4343 4344 4345 4346 4347 4348 4349 4350 4351 4352 4353 4354 4355 4356 4357 |
# File 'lib/aws-sdk-mgn/types.rb', line 4342 class NetworkMigrationDefinition < Struct.new( :arn, :network_migration_definition_id, :name, :description, :source_configurations, :target_s3_configuration, :target_network, :target_deployment, :created_at, :updated_at, :tags, :scope_tags) SENSITIVE = [:tags, :scope_tags] include Aws::Structure end |