Class: Aws::Mgn::Types::NetworkMigrationDefinition
- Inherits:
-
Struct
- Object
- Struct
- Aws::Mgn::Types::NetworkMigrationDefinition
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mgn/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:tags, :scope_tags]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the network migration definition.
-
#cidr_mappings ⇒ Array<Types::CidrMapping>
A list of CIDR mappings that map original source CIDR ranges to updated target CIDR ranges.
-
#created_at ⇒ Time
The timestamp when the network migration definition was created.
-
#description ⇒ String
A description of the network migration definition.
-
#name ⇒ String
The name of the network migration definition.
-
#network_migration_definition_id ⇒ String
The unique identifier of the network migration definition.
-
#scope_tags ⇒ Hash<String,String>
Scope tags for the network migration definition.
-
#source_configurations ⇒ Array<Types::SourceConfiguration>
A list of source configurations for the network migration.
-
#tags ⇒ Hash<String,String>
Tags assigned to the network migration definition.
-
#target_deployment ⇒ String
The target deployment configuration for the migrated network.
-
#target_network ⇒ Types::TargetNetwork
The target network configuration including topology and CIDR ranges.
-
#target_s3_configuration ⇒ Types::TargetS3Configuration
The S3 configuration for storing the target network artifacts.
-
#updated_at ⇒ Time
The timestamp when the network migration definition was last updated.
-
#vpc_provisioning_strategy ⇒ String
Indicates whether the migration creates new target VPCs or uses existing ones.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the network migration definition.
4514 4515 4516 4517 4518 4519 4520 4521 4522 4523 4524 4525 4526 4527 4528 4529 4530 4531 |
# File 'lib/aws-sdk-mgn/types.rb', line 4514 class NetworkMigrationDefinition < Struct.new( :arn, :network_migration_definition_id, :name, :description, :source_configurations, :target_s3_configuration, :target_network, :target_deployment, :vpc_provisioning_strategy, :cidr_mappings, :created_at, :updated_at, :tags, :scope_tags) SENSITIVE = [:tags, :scope_tags] include Aws::Structure end |
#cidr_mappings ⇒ Array<Types::CidrMapping>
A list of CIDR mappings that map original source CIDR ranges to
updated target CIDR ranges. CIDR mappings apply only when
vpcProvisioningStrategy is set to USE_EXISTING.
4514 4515 4516 4517 4518 4519 4520 4521 4522 4523 4524 4525 4526 4527 4528 4529 4530 4531 |
# File 'lib/aws-sdk-mgn/types.rb', line 4514 class NetworkMigrationDefinition < Struct.new( :arn, :network_migration_definition_id, :name, :description, :source_configurations, :target_s3_configuration, :target_network, :target_deployment, :vpc_provisioning_strategy, :cidr_mappings, :created_at, :updated_at, :tags, :scope_tags) SENSITIVE = [:tags, :scope_tags] include Aws::Structure end |
#created_at ⇒ Time
The timestamp when the network migration definition was created.
4514 4515 4516 4517 4518 4519 4520 4521 4522 4523 4524 4525 4526 4527 4528 4529 4530 4531 |
# File 'lib/aws-sdk-mgn/types.rb', line 4514 class NetworkMigrationDefinition < Struct.new( :arn, :network_migration_definition_id, :name, :description, :source_configurations, :target_s3_configuration, :target_network, :target_deployment, :vpc_provisioning_strategy, :cidr_mappings, :created_at, :updated_at, :tags, :scope_tags) SENSITIVE = [:tags, :scope_tags] include Aws::Structure end |
#description ⇒ String
A description of the network migration definition.
4514 4515 4516 4517 4518 4519 4520 4521 4522 4523 4524 4525 4526 4527 4528 4529 4530 4531 |
# File 'lib/aws-sdk-mgn/types.rb', line 4514 class NetworkMigrationDefinition < Struct.new( :arn, :network_migration_definition_id, :name, :description, :source_configurations, :target_s3_configuration, :target_network, :target_deployment, :vpc_provisioning_strategy, :cidr_mappings, :created_at, :updated_at, :tags, :scope_tags) SENSITIVE = [:tags, :scope_tags] include Aws::Structure end |
#name ⇒ String
The name of the network migration definition.
4514 4515 4516 4517 4518 4519 4520 4521 4522 4523 4524 4525 4526 4527 4528 4529 4530 4531 |
# File 'lib/aws-sdk-mgn/types.rb', line 4514 class NetworkMigrationDefinition < Struct.new( :arn, :network_migration_definition_id, :name, :description, :source_configurations, :target_s3_configuration, :target_network, :target_deployment, :vpc_provisioning_strategy, :cidr_mappings, :created_at, :updated_at, :tags, :scope_tags) SENSITIVE = [:tags, :scope_tags] include Aws::Structure end |
#network_migration_definition_id ⇒ String
The unique identifier of the network migration definition.
4514 4515 4516 4517 4518 4519 4520 4521 4522 4523 4524 4525 4526 4527 4528 4529 4530 4531 |
# File 'lib/aws-sdk-mgn/types.rb', line 4514 class NetworkMigrationDefinition < Struct.new( :arn, :network_migration_definition_id, :name, :description, :source_configurations, :target_s3_configuration, :target_network, :target_deployment, :vpc_provisioning_strategy, :cidr_mappings, :created_at, :updated_at, :tags, :scope_tags) SENSITIVE = [:tags, :scope_tags] include Aws::Structure end |
#scope_tags ⇒ Hash<String,String>
Scope tags for the network migration definition.
4514 4515 4516 4517 4518 4519 4520 4521 4522 4523 4524 4525 4526 4527 4528 4529 4530 4531 |
# File 'lib/aws-sdk-mgn/types.rb', line 4514 class NetworkMigrationDefinition < Struct.new( :arn, :network_migration_definition_id, :name, :description, :source_configurations, :target_s3_configuration, :target_network, :target_deployment, :vpc_provisioning_strategy, :cidr_mappings, :created_at, :updated_at, :tags, :scope_tags) SENSITIVE = [:tags, :scope_tags] include Aws::Structure end |
#source_configurations ⇒ Array<Types::SourceConfiguration>
A list of source configurations for the network migration.
4514 4515 4516 4517 4518 4519 4520 4521 4522 4523 4524 4525 4526 4527 4528 4529 4530 4531 |
# File 'lib/aws-sdk-mgn/types.rb', line 4514 class NetworkMigrationDefinition < Struct.new( :arn, :network_migration_definition_id, :name, :description, :source_configurations, :target_s3_configuration, :target_network, :target_deployment, :vpc_provisioning_strategy, :cidr_mappings, :created_at, :updated_at, :tags, :scope_tags) SENSITIVE = [:tags, :scope_tags] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Tags assigned to the network migration definition.
4514 4515 4516 4517 4518 4519 4520 4521 4522 4523 4524 4525 4526 4527 4528 4529 4530 4531 |
# File 'lib/aws-sdk-mgn/types.rb', line 4514 class NetworkMigrationDefinition < Struct.new( :arn, :network_migration_definition_id, :name, :description, :source_configurations, :target_s3_configuration, :target_network, :target_deployment, :vpc_provisioning_strategy, :cidr_mappings, :created_at, :updated_at, :tags, :scope_tags) SENSITIVE = [:tags, :scope_tags] include Aws::Structure end |
#target_deployment ⇒ String
The target deployment configuration for the migrated network.
4514 4515 4516 4517 4518 4519 4520 4521 4522 4523 4524 4525 4526 4527 4528 4529 4530 4531 |
# File 'lib/aws-sdk-mgn/types.rb', line 4514 class NetworkMigrationDefinition < Struct.new( :arn, :network_migration_definition_id, :name, :description, :source_configurations, :target_s3_configuration, :target_network, :target_deployment, :vpc_provisioning_strategy, :cidr_mappings, :created_at, :updated_at, :tags, :scope_tags) SENSITIVE = [:tags, :scope_tags] include Aws::Structure end |
#target_network ⇒ Types::TargetNetwork
The target network configuration including topology and CIDR ranges.
4514 4515 4516 4517 4518 4519 4520 4521 4522 4523 4524 4525 4526 4527 4528 4529 4530 4531 |
# File 'lib/aws-sdk-mgn/types.rb', line 4514 class NetworkMigrationDefinition < Struct.new( :arn, :network_migration_definition_id, :name, :description, :source_configurations, :target_s3_configuration, :target_network, :target_deployment, :vpc_provisioning_strategy, :cidr_mappings, :created_at, :updated_at, :tags, :scope_tags) SENSITIVE = [:tags, :scope_tags] include Aws::Structure end |
#target_s3_configuration ⇒ Types::TargetS3Configuration
The S3 configuration for storing the target network artifacts.
4514 4515 4516 4517 4518 4519 4520 4521 4522 4523 4524 4525 4526 4527 4528 4529 4530 4531 |
# File 'lib/aws-sdk-mgn/types.rb', line 4514 class NetworkMigrationDefinition < Struct.new( :arn, :network_migration_definition_id, :name, :description, :source_configurations, :target_s3_configuration, :target_network, :target_deployment, :vpc_provisioning_strategy, :cidr_mappings, :created_at, :updated_at, :tags, :scope_tags) SENSITIVE = [:tags, :scope_tags] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp when the network migration definition was last updated.
4514 4515 4516 4517 4518 4519 4520 4521 4522 4523 4524 4525 4526 4527 4528 4529 4530 4531 |
# File 'lib/aws-sdk-mgn/types.rb', line 4514 class NetworkMigrationDefinition < Struct.new( :arn, :network_migration_definition_id, :name, :description, :source_configurations, :target_s3_configuration, :target_network, :target_deployment, :vpc_provisioning_strategy, :cidr_mappings, :created_at, :updated_at, :tags, :scope_tags) SENSITIVE = [:tags, :scope_tags] include Aws::Structure end |
#vpc_provisioning_strategy ⇒ String
Indicates whether the migration creates new target VPCs or uses
existing ones. CREATE_NEW provisions new target VPCs;
USE_EXISTING migrates into existing VPCs in the target account.
4514 4515 4516 4517 4518 4519 4520 4521 4522 4523 4524 4525 4526 4527 4528 4529 4530 4531 |
# File 'lib/aws-sdk-mgn/types.rb', line 4514 class NetworkMigrationDefinition < Struct.new( :arn, :network_migration_definition_id, :name, :description, :source_configurations, :target_s3_configuration, :target_network, :target_deployment, :vpc_provisioning_strategy, :cidr_mappings, :created_at, :updated_at, :tags, :scope_tags) SENSITIVE = [:tags, :scope_tags] include Aws::Structure end |