Class: Aws::Mgn::Types::NetworkMigrationDeployedStackDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mgn/types.rb

Overview

Details about a CloudFormation stack that has been deployed as part of the network migration.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#failed_resourcesArray<Types::NetworkMigrationFailedResourceDetails>

A list of resources that failed to deploy.

Returns:



4427
4428
4429
4430
4431
4432
4433
4434
4435
4436
# File 'lib/aws-sdk-mgn/types.rb', line 4427

class NetworkMigrationDeployedStackDetails < Struct.new(
  :status,
  :stack_physical_id,
  :stack_logical_id,
  :segment_id,
  :target_account,
  :failed_resources)
  SENSITIVE = []
  include Aws::Structure
end

#segment_idString

The ID of the segment that this stack was deployed for.

Returns:



4427
4428
4429
4430
4431
4432
4433
4434
4435
4436
# File 'lib/aws-sdk-mgn/types.rb', line 4427

class NetworkMigrationDeployedStackDetails < Struct.new(
  :status,
  :stack_physical_id,
  :stack_logical_id,
  :segment_id,
  :target_account,
  :failed_resources)
  SENSITIVE = []
  include Aws::Structure
end

#stack_logical_idString

The logical ID of the stack.

Returns:



4427
4428
4429
4430
4431
4432
4433
4434
4435
4436
# File 'lib/aws-sdk-mgn/types.rb', line 4427

class NetworkMigrationDeployedStackDetails < Struct.new(
  :status,
  :stack_physical_id,
  :stack_logical_id,
  :segment_id,
  :target_account,
  :failed_resources)
  SENSITIVE = []
  include Aws::Structure
end

#stack_physical_idString

The physical ID of the CloudFormation stack.

Returns:



4427
4428
4429
4430
4431
4432
4433
4434
4435
4436
# File 'lib/aws-sdk-mgn/types.rb', line 4427

class NetworkMigrationDeployedStackDetails < Struct.new(
  :status,
  :stack_physical_id,
  :stack_logical_id,
  :segment_id,
  :target_account,
  :failed_resources)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the deployed stack.

Returns:



4427
4428
4429
4430
4431
4432
4433
4434
4435
4436
# File 'lib/aws-sdk-mgn/types.rb', line 4427

class NetworkMigrationDeployedStackDetails < Struct.new(
  :status,
  :stack_physical_id,
  :stack_logical_id,
  :segment_id,
  :target_account,
  :failed_resources)
  SENSITIVE = []
  include Aws::Structure
end

#target_accountString

The target AWS account where the stack was deployed.

Returns:



4427
4428
4429
4430
4431
4432
4433
4434
4435
4436
# File 'lib/aws-sdk-mgn/types.rb', line 4427

class NetworkMigrationDeployedStackDetails < Struct.new(
  :status,
  :stack_physical_id,
  :stack_logical_id,
  :segment_id,
  :target_account,
  :failed_resources)
  SENSITIVE = []
  include Aws::Structure
end