Class: Aws::Mgn::Types::NetworkMigrationDeployedStackDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::Mgn::Types::NetworkMigrationDeployedStackDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mgn/types.rb
Overview
Details about a CloudFormation stack that has been deployed as part of the network migration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#failed_resources ⇒ Array<Types::NetworkMigrationFailedResourceDetails>
A list of resources that failed to deploy.
-
#segment_id ⇒ String
The ID of the segment that this stack was deployed for.
-
#stack_logical_id ⇒ String
The logical ID of the stack.
-
#stack_physical_id ⇒ String
The physical ID of the CloudFormation stack.
-
#status ⇒ String
The current status of the deployed stack.
-
#target_account ⇒ String
The target AWS account where the stack was deployed.
Instance Attribute Details
#failed_resources ⇒ Array<Types::NetworkMigrationFailedResourceDetails>
A list of resources that failed to deploy.
4427 4428 4429 4430 4431 4432 4433 4434 4435 4436 |
# File 'lib/aws-sdk-mgn/types.rb', line 4427 class NetworkMigrationDeployedStackDetails < Struct.new( :status, :stack_physical_id, :stack_logical_id, :segment_id, :target_account, :failed_resources) SENSITIVE = [] include Aws::Structure end |
#segment_id ⇒ String
The ID of the segment that this stack was deployed for.
4427 4428 4429 4430 4431 4432 4433 4434 4435 4436 |
# File 'lib/aws-sdk-mgn/types.rb', line 4427 class NetworkMigrationDeployedStackDetails < Struct.new( :status, :stack_physical_id, :stack_logical_id, :segment_id, :target_account, :failed_resources) SENSITIVE = [] include Aws::Structure end |
#stack_logical_id ⇒ String
The logical ID of the stack.
4427 4428 4429 4430 4431 4432 4433 4434 4435 4436 |
# File 'lib/aws-sdk-mgn/types.rb', line 4427 class NetworkMigrationDeployedStackDetails < Struct.new( :status, :stack_physical_id, :stack_logical_id, :segment_id, :target_account, :failed_resources) SENSITIVE = [] include Aws::Structure end |
#stack_physical_id ⇒ String
The physical ID of the CloudFormation stack.
4427 4428 4429 4430 4431 4432 4433 4434 4435 4436 |
# File 'lib/aws-sdk-mgn/types.rb', line 4427 class NetworkMigrationDeployedStackDetails < Struct.new( :status, :stack_physical_id, :stack_logical_id, :segment_id, :target_account, :failed_resources) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the deployed stack.
4427 4428 4429 4430 4431 4432 4433 4434 4435 4436 |
# File 'lib/aws-sdk-mgn/types.rb', line 4427 class NetworkMigrationDeployedStackDetails < Struct.new( :status, :stack_physical_id, :stack_logical_id, :segment_id, :target_account, :failed_resources) SENSITIVE = [] include Aws::Structure end |
#target_account ⇒ String
The target AWS account where the stack was deployed.
4427 4428 4429 4430 4431 4432 4433 4434 4435 4436 |
# File 'lib/aws-sdk-mgn/types.rb', line 4427 class NetworkMigrationDeployedStackDetails < Struct.new( :status, :stack_physical_id, :stack_logical_id, :segment_id, :target_account, :failed_resources) SENSITIVE = [] include Aws::Structure end |