Class: Aws::Mgn::Types::NetworkMigrationExecution

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mgn/types.rb

Overview

Details about a network migration execution instance.

Constant Summary collapse

SENSITIVE =
[:tags]

Instance Attribute Summary collapse

Instance Attribute Details

#activityString

The current activity being performed in the execution.

Returns:

  • (String)


4519
4520
4521
4522
4523
4524
4525
4526
4527
4528
4529
4530
# File 'lib/aws-sdk-mgn/types.rb', line 4519

class NetworkMigrationExecution < Struct.new(
  :network_migration_definition_id,
  :network_migration_execution_id,
  :status,
  :stage,
  :activity,
  :created_at,
  :updated_at,
  :tags)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#created_atTime

The timestamp when the execution was created.

Returns:

  • (Time)


4519
4520
4521
4522
4523
4524
4525
4526
4527
4528
4529
4530
# File 'lib/aws-sdk-mgn/types.rb', line 4519

class NetworkMigrationExecution < Struct.new(
  :network_migration_definition_id,
  :network_migration_execution_id,
  :status,
  :stage,
  :activity,
  :created_at,
  :updated_at,
  :tags)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#network_migration_definition_idString

The unique identifier of the network migration definition used by this execution.

Returns:

  • (String)


4519
4520
4521
4522
4523
4524
4525
4526
4527
4528
4529
4530
# File 'lib/aws-sdk-mgn/types.rb', line 4519

class NetworkMigrationExecution < Struct.new(
  :network_migration_definition_id,
  :network_migration_execution_id,
  :status,
  :stage,
  :activity,
  :created_at,
  :updated_at,
  :tags)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#network_migration_execution_idString

The unique identifier of the execution.

Returns:

  • (String)


4519
4520
4521
4522
4523
4524
4525
4526
4527
4528
4529
4530
# File 'lib/aws-sdk-mgn/types.rb', line 4519

class NetworkMigrationExecution < Struct.new(
  :network_migration_definition_id,
  :network_migration_execution_id,
  :status,
  :stage,
  :activity,
  :created_at,
  :updated_at,
  :tags)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#stageString

The current stage of the execution in the migration workflow.

Returns:

  • (String)


4519
4520
4521
4522
4523
4524
4525
4526
4527
4528
4529
4530
# File 'lib/aws-sdk-mgn/types.rb', line 4519

class NetworkMigrationExecution < Struct.new(
  :network_migration_definition_id,
  :network_migration_execution_id,
  :status,
  :stage,
  :activity,
  :created_at,
  :updated_at,
  :tags)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#statusString

The current status of the execution.

Returns:

  • (String)


4519
4520
4521
4522
4523
4524
4525
4526
4527
4528
4529
4530
# File 'lib/aws-sdk-mgn/types.rb', line 4519

class NetworkMigrationExecution < Struct.new(
  :network_migration_definition_id,
  :network_migration_execution_id,
  :status,
  :stage,
  :activity,
  :created_at,
  :updated_at,
  :tags)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#tagsHash<String,String>

Tags assigned to the execution.

Returns:

  • (Hash<String,String>)


4519
4520
4521
4522
4523
4524
4525
4526
4527
4528
4529
4530
# File 'lib/aws-sdk-mgn/types.rb', line 4519

class NetworkMigrationExecution < Struct.new(
  :network_migration_definition_id,
  :network_migration_execution_id,
  :status,
  :stage,
  :activity,
  :created_at,
  :updated_at,
  :tags)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#updated_atTime

The timestamp when the execution was last updated.

Returns:

  • (Time)


4519
4520
4521
4522
4523
4524
4525
4526
4527
4528
4529
4530
# File 'lib/aws-sdk-mgn/types.rb', line 4519

class NetworkMigrationExecution < Struct.new(
  :network_migration_definition_id,
  :network_migration_execution_id,
  :status,
  :stage,
  :activity,
  :created_at,
  :updated_at,
  :tags)
  SENSITIVE = [:tags]
  include Aws::Structure
end