Class: Aws::Mgn::Types::NetworkMigrationExecution
- Inherits:
-
Struct
- Object
- Struct
- Aws::Mgn::Types::NetworkMigrationExecution
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mgn/types.rb
Overview
Details about a network migration execution instance.
Constant Summary collapse
- SENSITIVE =
[:tags]
Instance Attribute Summary collapse
-
#activity ⇒ String
The current activity being performed in the execution.
-
#created_at ⇒ Time
The timestamp when the execution was created.
-
#network_migration_definition_id ⇒ String
The unique identifier of the network migration definition used by this execution.
-
#network_migration_execution_id ⇒ String
The unique identifier of the execution.
-
#stage ⇒ String
The current stage of the execution in the migration workflow.
-
#status ⇒ String
The current status of the execution.
-
#tags ⇒ Hash<String,String>
Tags assigned to the execution.
-
#updated_at ⇒ Time
The timestamp when the execution was last updated.
Instance Attribute Details
#activity ⇒ String
The current activity being performed in the execution.
4519 4520 4521 4522 4523 4524 4525 4526 4527 4528 4529 4530 |
# File 'lib/aws-sdk-mgn/types.rb', line 4519 class NetworkMigrationExecution < Struct.new( :network_migration_definition_id, :network_migration_execution_id, :status, :stage, :activity, :created_at, :updated_at, :tags) SENSITIVE = [:tags] include Aws::Structure end |
#created_at ⇒ Time
The timestamp when the execution was created.
4519 4520 4521 4522 4523 4524 4525 4526 4527 4528 4529 4530 |
# File 'lib/aws-sdk-mgn/types.rb', line 4519 class NetworkMigrationExecution < Struct.new( :network_migration_definition_id, :network_migration_execution_id, :status, :stage, :activity, :created_at, :updated_at, :tags) SENSITIVE = [:tags] include Aws::Structure end |
#network_migration_definition_id ⇒ String
The unique identifier of the network migration definition used by this execution.
4519 4520 4521 4522 4523 4524 4525 4526 4527 4528 4529 4530 |
# File 'lib/aws-sdk-mgn/types.rb', line 4519 class NetworkMigrationExecution < Struct.new( :network_migration_definition_id, :network_migration_execution_id, :status, :stage, :activity, :created_at, :updated_at, :tags) SENSITIVE = [:tags] include Aws::Structure end |
#network_migration_execution_id ⇒ String
The unique identifier of the execution.
4519 4520 4521 4522 4523 4524 4525 4526 4527 4528 4529 4530 |
# File 'lib/aws-sdk-mgn/types.rb', line 4519 class NetworkMigrationExecution < Struct.new( :network_migration_definition_id, :network_migration_execution_id, :status, :stage, :activity, :created_at, :updated_at, :tags) SENSITIVE = [:tags] include Aws::Structure end |
#stage ⇒ String
The current stage of the execution in the migration workflow.
4519 4520 4521 4522 4523 4524 4525 4526 4527 4528 4529 4530 |
# File 'lib/aws-sdk-mgn/types.rb', line 4519 class NetworkMigrationExecution < Struct.new( :network_migration_definition_id, :network_migration_execution_id, :status, :stage, :activity, :created_at, :updated_at, :tags) SENSITIVE = [:tags] include Aws::Structure end |
#status ⇒ String
The current status of the execution.
4519 4520 4521 4522 4523 4524 4525 4526 4527 4528 4529 4530 |
# File 'lib/aws-sdk-mgn/types.rb', line 4519 class NetworkMigrationExecution < Struct.new( :network_migration_definition_id, :network_migration_execution_id, :status, :stage, :activity, :created_at, :updated_at, :tags) SENSITIVE = [:tags] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Tags assigned to the execution.
4519 4520 4521 4522 4523 4524 4525 4526 4527 4528 4529 4530 |
# File 'lib/aws-sdk-mgn/types.rb', line 4519 class NetworkMigrationExecution < Struct.new( :network_migration_definition_id, :network_migration_execution_id, :status, :stage, :activity, :created_at, :updated_at, :tags) SENSITIVE = [:tags] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp when the execution was last updated.
4519 4520 4521 4522 4523 4524 4525 4526 4527 4528 4529 4530 |
# File 'lib/aws-sdk-mgn/types.rb', line 4519 class NetworkMigrationExecution < Struct.new( :network_migration_definition_id, :network_migration_execution_id, :status, :stage, :activity, :created_at, :updated_at, :tags) SENSITIVE = [:tags] include Aws::Structure end |