Class: Aws::Mgn::Types::NetworkMigrationMapperSegment
- Inherits:
-
Struct
- Object
- Struct
- Aws::Mgn::Types::NetworkMigrationMapperSegment
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mgn/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:scope_tags]
Instance Attribute Summary collapse
-
#checksum ⇒ Types::Checksum
The checksum of the segment data for integrity verification.
-
#created_at ⇒ Time
The timestamp when the segment was created.
-
#description ⇒ String
A description of the segment.
-
#job_id ⇒ String
The unique identifier of the job that created this segment.
-
#logical_id ⇒ String
The logical identifier for the segment in the infrastructure code.
-
#name ⇒ String
The name of the segment.
-
#network_migration_definition_id ⇒ String
The unique identifier of the network migration definition.
-
#network_migration_execution_id ⇒ String
The unique identifier of the network migration execution.
-
#output_s3_configuration ⇒ Types::S3Configuration
The S3 location where segment artifacts are stored.
-
#referenced_segments ⇒ Array<String>
A list of other segments that this segment depends on or references.
-
#scope_tags ⇒ Hash<String,String>
Scope tags for the segment.
-
#segment_id ⇒ String
The unique identifier of the segment.
-
#segment_type ⇒ String
The type of the segment, such as VPC, subnet, or security group.
-
#target_account ⇒ String
The target AWS account where this segment will be deployed.
-
#updated_at ⇒ Time
The timestamp when the segment was last updated.
Instance Attribute Details
#checksum ⇒ Types::Checksum
The checksum of the segment data for integrity verification.
4735 4736 4737 4738 4739 4740 4741 4742 4743 4744 4745 4746 4747 4748 4749 4750 4751 4752 4753 |
# File 'lib/aws-sdk-mgn/types.rb', line 4735 class NetworkMigrationMapperSegment < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :segment_id, :segment_type, :name, :description, :logical_id, :checksum, :output_s3_configuration, :created_at, :updated_at, :scope_tags, :target_account, :referenced_segments) SENSITIVE = [:scope_tags] include Aws::Structure end |
#created_at ⇒ Time
The timestamp when the segment was created.
4735 4736 4737 4738 4739 4740 4741 4742 4743 4744 4745 4746 4747 4748 4749 4750 4751 4752 4753 |
# File 'lib/aws-sdk-mgn/types.rb', line 4735 class NetworkMigrationMapperSegment < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :segment_id, :segment_type, :name, :description, :logical_id, :checksum, :output_s3_configuration, :created_at, :updated_at, :scope_tags, :target_account, :referenced_segments) SENSITIVE = [:scope_tags] include Aws::Structure end |
#description ⇒ String
A description of the segment.
4735 4736 4737 4738 4739 4740 4741 4742 4743 4744 4745 4746 4747 4748 4749 4750 4751 4752 4753 |
# File 'lib/aws-sdk-mgn/types.rb', line 4735 class NetworkMigrationMapperSegment < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :segment_id, :segment_type, :name, :description, :logical_id, :checksum, :output_s3_configuration, :created_at, :updated_at, :scope_tags, :target_account, :referenced_segments) SENSITIVE = [:scope_tags] include Aws::Structure end |
#job_id ⇒ String
The unique identifier of the job that created this segment.
4735 4736 4737 4738 4739 4740 4741 4742 4743 4744 4745 4746 4747 4748 4749 4750 4751 4752 4753 |
# File 'lib/aws-sdk-mgn/types.rb', line 4735 class NetworkMigrationMapperSegment < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :segment_id, :segment_type, :name, :description, :logical_id, :checksum, :output_s3_configuration, :created_at, :updated_at, :scope_tags, :target_account, :referenced_segments) SENSITIVE = [:scope_tags] include Aws::Structure end |
#logical_id ⇒ String
The logical identifier for the segment in the infrastructure code.
4735 4736 4737 4738 4739 4740 4741 4742 4743 4744 4745 4746 4747 4748 4749 4750 4751 4752 4753 |
# File 'lib/aws-sdk-mgn/types.rb', line 4735 class NetworkMigrationMapperSegment < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :segment_id, :segment_type, :name, :description, :logical_id, :checksum, :output_s3_configuration, :created_at, :updated_at, :scope_tags, :target_account, :referenced_segments) SENSITIVE = [:scope_tags] include Aws::Structure end |
#name ⇒ String
The name of the segment.
4735 4736 4737 4738 4739 4740 4741 4742 4743 4744 4745 4746 4747 4748 4749 4750 4751 4752 4753 |
# File 'lib/aws-sdk-mgn/types.rb', line 4735 class NetworkMigrationMapperSegment < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :segment_id, :segment_type, :name, :description, :logical_id, :checksum, :output_s3_configuration, :created_at, :updated_at, :scope_tags, :target_account, :referenced_segments) SENSITIVE = [:scope_tags] include Aws::Structure end |
#network_migration_definition_id ⇒ String
The unique identifier of the network migration definition.
4735 4736 4737 4738 4739 4740 4741 4742 4743 4744 4745 4746 4747 4748 4749 4750 4751 4752 4753 |
# File 'lib/aws-sdk-mgn/types.rb', line 4735 class NetworkMigrationMapperSegment < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :segment_id, :segment_type, :name, :description, :logical_id, :checksum, :output_s3_configuration, :created_at, :updated_at, :scope_tags, :target_account, :referenced_segments) SENSITIVE = [:scope_tags] include Aws::Structure end |
#network_migration_execution_id ⇒ String
The unique identifier of the network migration execution.
4735 4736 4737 4738 4739 4740 4741 4742 4743 4744 4745 4746 4747 4748 4749 4750 4751 4752 4753 |
# File 'lib/aws-sdk-mgn/types.rb', line 4735 class NetworkMigrationMapperSegment < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :segment_id, :segment_type, :name, :description, :logical_id, :checksum, :output_s3_configuration, :created_at, :updated_at, :scope_tags, :target_account, :referenced_segments) SENSITIVE = [:scope_tags] include Aws::Structure end |
#output_s3_configuration ⇒ Types::S3Configuration
The S3 location where segment artifacts are stored.
4735 4736 4737 4738 4739 4740 4741 4742 4743 4744 4745 4746 4747 4748 4749 4750 4751 4752 4753 |
# File 'lib/aws-sdk-mgn/types.rb', line 4735 class NetworkMigrationMapperSegment < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :segment_id, :segment_type, :name, :description, :logical_id, :checksum, :output_s3_configuration, :created_at, :updated_at, :scope_tags, :target_account, :referenced_segments) SENSITIVE = [:scope_tags] include Aws::Structure end |
#referenced_segments ⇒ Array<String>
A list of other segments that this segment depends on or references.
4735 4736 4737 4738 4739 4740 4741 4742 4743 4744 4745 4746 4747 4748 4749 4750 4751 4752 4753 |
# File 'lib/aws-sdk-mgn/types.rb', line 4735 class NetworkMigrationMapperSegment < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :segment_id, :segment_type, :name, :description, :logical_id, :checksum, :output_s3_configuration, :created_at, :updated_at, :scope_tags, :target_account, :referenced_segments) SENSITIVE = [:scope_tags] include Aws::Structure end |
#scope_tags ⇒ Hash<String,String>
Scope tags for the segment.
4735 4736 4737 4738 4739 4740 4741 4742 4743 4744 4745 4746 4747 4748 4749 4750 4751 4752 4753 |
# File 'lib/aws-sdk-mgn/types.rb', line 4735 class NetworkMigrationMapperSegment < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :segment_id, :segment_type, :name, :description, :logical_id, :checksum, :output_s3_configuration, :created_at, :updated_at, :scope_tags, :target_account, :referenced_segments) SENSITIVE = [:scope_tags] include Aws::Structure end |
#segment_id ⇒ String
The unique identifier of the segment.
4735 4736 4737 4738 4739 4740 4741 4742 4743 4744 4745 4746 4747 4748 4749 4750 4751 4752 4753 |
# File 'lib/aws-sdk-mgn/types.rb', line 4735 class NetworkMigrationMapperSegment < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :segment_id, :segment_type, :name, :description, :logical_id, :checksum, :output_s3_configuration, :created_at, :updated_at, :scope_tags, :target_account, :referenced_segments) SENSITIVE = [:scope_tags] include Aws::Structure end |
#segment_type ⇒ String
The type of the segment, such as VPC, subnet, or security group.
4735 4736 4737 4738 4739 4740 4741 4742 4743 4744 4745 4746 4747 4748 4749 4750 4751 4752 4753 |
# File 'lib/aws-sdk-mgn/types.rb', line 4735 class NetworkMigrationMapperSegment < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :segment_id, :segment_type, :name, :description, :logical_id, :checksum, :output_s3_configuration, :created_at, :updated_at, :scope_tags, :target_account, :referenced_segments) SENSITIVE = [:scope_tags] include Aws::Structure end |
#target_account ⇒ String
The target AWS account where this segment will be deployed.
4735 4736 4737 4738 4739 4740 4741 4742 4743 4744 4745 4746 4747 4748 4749 4750 4751 4752 4753 |
# File 'lib/aws-sdk-mgn/types.rb', line 4735 class NetworkMigrationMapperSegment < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :segment_id, :segment_type, :name, :description, :logical_id, :checksum, :output_s3_configuration, :created_at, :updated_at, :scope_tags, :target_account, :referenced_segments) SENSITIVE = [:scope_tags] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp when the segment was last updated.
4735 4736 4737 4738 4739 4740 4741 4742 4743 4744 4745 4746 4747 4748 4749 4750 4751 4752 4753 |
# File 'lib/aws-sdk-mgn/types.rb', line 4735 class NetworkMigrationMapperSegment < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :segment_id, :segment_type, :name, :description, :logical_id, :checksum, :output_s3_configuration, :created_at, :updated_at, :scope_tags, :target_account, :referenced_segments) SENSITIVE = [:scope_tags] include Aws::Structure end |