Class: Aws::Mgn::Types::NetworkMigrationMapperSegment

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mgn/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:scope_tags]

Instance Attribute Summary collapse

Instance Attribute Details

#checksumTypes::Checksum

The checksum of the segment data for integrity verification.

Returns:



4618
4619
4620
4621
4622
4623
4624
4625
4626
4627
4628
4629
4630
4631
4632
4633
4634
4635
4636
# File 'lib/aws-sdk-mgn/types.rb', line 4618

class NetworkMigrationMapperSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :name,
  :description,
  :logical_id,
  :checksum,
  :output_s3_configuration,
  :created_at,
  :updated_at,
  :scope_tags,
  :target_account,
  :referenced_segments)
  SENSITIVE = [:scope_tags]
  include Aws::Structure
end

#created_atTime

The timestamp when the segment was created.

Returns:

  • (Time)


4618
4619
4620
4621
4622
4623
4624
4625
4626
4627
4628
4629
4630
4631
4632
4633
4634
4635
4636
# File 'lib/aws-sdk-mgn/types.rb', line 4618

class NetworkMigrationMapperSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :name,
  :description,
  :logical_id,
  :checksum,
  :output_s3_configuration,
  :created_at,
  :updated_at,
  :scope_tags,
  :target_account,
  :referenced_segments)
  SENSITIVE = [:scope_tags]
  include Aws::Structure
end

#descriptionString

A description of the segment.

Returns:

  • (String)


4618
4619
4620
4621
4622
4623
4624
4625
4626
4627
4628
4629
4630
4631
4632
4633
4634
4635
4636
# File 'lib/aws-sdk-mgn/types.rb', line 4618

class NetworkMigrationMapperSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :name,
  :description,
  :logical_id,
  :checksum,
  :output_s3_configuration,
  :created_at,
  :updated_at,
  :scope_tags,
  :target_account,
  :referenced_segments)
  SENSITIVE = [:scope_tags]
  include Aws::Structure
end

#job_idString

The unique identifier of the job that created this segment.

Returns:

  • (String)


4618
4619
4620
4621
4622
4623
4624
4625
4626
4627
4628
4629
4630
4631
4632
4633
4634
4635
4636
# File 'lib/aws-sdk-mgn/types.rb', line 4618

class NetworkMigrationMapperSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :name,
  :description,
  :logical_id,
  :checksum,
  :output_s3_configuration,
  :created_at,
  :updated_at,
  :scope_tags,
  :target_account,
  :referenced_segments)
  SENSITIVE = [:scope_tags]
  include Aws::Structure
end

#logical_idString

The logical identifier for the segment in the infrastructure code.

Returns:

  • (String)


4618
4619
4620
4621
4622
4623
4624
4625
4626
4627
4628
4629
4630
4631
4632
4633
4634
4635
4636
# File 'lib/aws-sdk-mgn/types.rb', line 4618

class NetworkMigrationMapperSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :name,
  :description,
  :logical_id,
  :checksum,
  :output_s3_configuration,
  :created_at,
  :updated_at,
  :scope_tags,
  :target_account,
  :referenced_segments)
  SENSITIVE = [:scope_tags]
  include Aws::Structure
end

#nameString

The name of the segment.

Returns:

  • (String)


4618
4619
4620
4621
4622
4623
4624
4625
4626
4627
4628
4629
4630
4631
4632
4633
4634
4635
4636
# File 'lib/aws-sdk-mgn/types.rb', line 4618

class NetworkMigrationMapperSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :name,
  :description,
  :logical_id,
  :checksum,
  :output_s3_configuration,
  :created_at,
  :updated_at,
  :scope_tags,
  :target_account,
  :referenced_segments)
  SENSITIVE = [:scope_tags]
  include Aws::Structure
end

#network_migration_definition_idString

The unique identifier of the network migration definition.

Returns:

  • (String)


4618
4619
4620
4621
4622
4623
4624
4625
4626
4627
4628
4629
4630
4631
4632
4633
4634
4635
4636
# File 'lib/aws-sdk-mgn/types.rb', line 4618

class NetworkMigrationMapperSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :name,
  :description,
  :logical_id,
  :checksum,
  :output_s3_configuration,
  :created_at,
  :updated_at,
  :scope_tags,
  :target_account,
  :referenced_segments)
  SENSITIVE = [:scope_tags]
  include Aws::Structure
end

#network_migration_execution_idString

The unique identifier of the network migration execution.

Returns:

  • (String)


4618
4619
4620
4621
4622
4623
4624
4625
4626
4627
4628
4629
4630
4631
4632
4633
4634
4635
4636
# File 'lib/aws-sdk-mgn/types.rb', line 4618

class NetworkMigrationMapperSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :name,
  :description,
  :logical_id,
  :checksum,
  :output_s3_configuration,
  :created_at,
  :updated_at,
  :scope_tags,
  :target_account,
  :referenced_segments)
  SENSITIVE = [:scope_tags]
  include Aws::Structure
end

#output_s3_configurationTypes::S3Configuration

The S3 location where segment artifacts are stored.



4618
4619
4620
4621
4622
4623
4624
4625
4626
4627
4628
4629
4630
4631
4632
4633
4634
4635
4636
# File 'lib/aws-sdk-mgn/types.rb', line 4618

class NetworkMigrationMapperSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :name,
  :description,
  :logical_id,
  :checksum,
  :output_s3_configuration,
  :created_at,
  :updated_at,
  :scope_tags,
  :target_account,
  :referenced_segments)
  SENSITIVE = [:scope_tags]
  include Aws::Structure
end

#referenced_segmentsArray<String>

A list of other segments that this segment depends on or references.

Returns:

  • (Array<String>)


4618
4619
4620
4621
4622
4623
4624
4625
4626
4627
4628
4629
4630
4631
4632
4633
4634
4635
4636
# File 'lib/aws-sdk-mgn/types.rb', line 4618

class NetworkMigrationMapperSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :name,
  :description,
  :logical_id,
  :checksum,
  :output_s3_configuration,
  :created_at,
  :updated_at,
  :scope_tags,
  :target_account,
  :referenced_segments)
  SENSITIVE = [:scope_tags]
  include Aws::Structure
end

#scope_tagsHash<String,String>

Scope tags for the segment.

Returns:

  • (Hash<String,String>)


4618
4619
4620
4621
4622
4623
4624
4625
4626
4627
4628
4629
4630
4631
4632
4633
4634
4635
4636
# File 'lib/aws-sdk-mgn/types.rb', line 4618

class NetworkMigrationMapperSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :name,
  :description,
  :logical_id,
  :checksum,
  :output_s3_configuration,
  :created_at,
  :updated_at,
  :scope_tags,
  :target_account,
  :referenced_segments)
  SENSITIVE = [:scope_tags]
  include Aws::Structure
end

#segment_idString

The unique identifier of the segment.

Returns:

  • (String)


4618
4619
4620
4621
4622
4623
4624
4625
4626
4627
4628
4629
4630
4631
4632
4633
4634
4635
4636
# File 'lib/aws-sdk-mgn/types.rb', line 4618

class NetworkMigrationMapperSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :name,
  :description,
  :logical_id,
  :checksum,
  :output_s3_configuration,
  :created_at,
  :updated_at,
  :scope_tags,
  :target_account,
  :referenced_segments)
  SENSITIVE = [:scope_tags]
  include Aws::Structure
end

#segment_typeString

The type of the segment, such as VPC, subnet, or security group.

Returns:

  • (String)


4618
4619
4620
4621
4622
4623
4624
4625
4626
4627
4628
4629
4630
4631
4632
4633
4634
4635
4636
# File 'lib/aws-sdk-mgn/types.rb', line 4618

class NetworkMigrationMapperSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :name,
  :description,
  :logical_id,
  :checksum,
  :output_s3_configuration,
  :created_at,
  :updated_at,
  :scope_tags,
  :target_account,
  :referenced_segments)
  SENSITIVE = [:scope_tags]
  include Aws::Structure
end

#target_accountString

The target AWS account where this segment will be deployed.

Returns:

  • (String)


4618
4619
4620
4621
4622
4623
4624
4625
4626
4627
4628
4629
4630
4631
4632
4633
4634
4635
4636
# File 'lib/aws-sdk-mgn/types.rb', line 4618

class NetworkMigrationMapperSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :name,
  :description,
  :logical_id,
  :checksum,
  :output_s3_configuration,
  :created_at,
  :updated_at,
  :scope_tags,
  :target_account,
  :referenced_segments)
  SENSITIVE = [:scope_tags]
  include Aws::Structure
end

#updated_atTime

The timestamp when the segment was last updated.

Returns:

  • (Time)


4618
4619
4620
4621
4622
4623
4624
4625
4626
4627
4628
4629
4630
4631
4632
4633
4634
4635
4636
# File 'lib/aws-sdk-mgn/types.rb', line 4618

class NetworkMigrationMapperSegment < Struct.new(
  :job_id,
  :network_migration_execution_id,
  :network_migration_definition_id,
  :segment_id,
  :segment_type,
  :name,
  :description,
  :logical_id,
  :checksum,
  :output_s3_configuration,
  :created_at,
  :updated_at,
  :scope_tags,
  :target_account,
  :referenced_segments)
  SENSITIVE = [:scope_tags]
  include Aws::Structure
end