Class: Aws::Mgn::Types::NetworkMigrationMapperSegment
- Inherits:
-
Struct
- Object
- Struct
- Aws::Mgn::Types::NetworkMigrationMapperSegment
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mgn/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:scope_tags]
Instance Attribute Summary collapse
-
#checksum ⇒ Types::Checksum
The checksum of the segment data for integrity verification.
-
#created_at ⇒ Time
The timestamp when the segment was created.
-
#description ⇒ String
A description of the segment.
-
#job_id ⇒ String
The unique identifier of the job that created this segment.
-
#logical_id ⇒ String
The logical identifier for the segment in the infrastructure code.
-
#name ⇒ String
The name of the segment.
-
#network_migration_definition_id ⇒ String
The unique identifier of the network migration definition.
-
#network_migration_execution_id ⇒ String
The unique identifier of the network migration execution.
-
#output_s3_configuration ⇒ Types::S3Configuration
The S3 location where segment artifacts are stored.
-
#referenced_segments ⇒ Array<String>
A list of other segments that this segment depends on or references.
-
#scope_tags ⇒ Hash<String,String>
Scope tags for the segment.
-
#segment_id ⇒ String
The unique identifier of the segment.
-
#segment_type ⇒ String
The category of the network migration segment.
-
#target_account ⇒ String
The target AWS account where this segment will be deployed.
-
#updated_at ⇒ Time
The timestamp when the segment was last updated.
Instance Attribute Details
#checksum ⇒ Types::Checksum
The checksum of the segment data for integrity verification.
4794 4795 4796 4797 4798 4799 4800 4801 4802 4803 4804 4805 4806 4807 4808 4809 4810 4811 4812 |
# File 'lib/aws-sdk-mgn/types.rb', line 4794 class NetworkMigrationMapperSegment < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :segment_id, :segment_type, :name, :description, :logical_id, :checksum, :output_s3_configuration, :created_at, :updated_at, :scope_tags, :target_account, :referenced_segments) SENSITIVE = [:scope_tags] include Aws::Structure end |
#created_at ⇒ Time
The timestamp when the segment was created.
4794 4795 4796 4797 4798 4799 4800 4801 4802 4803 4804 4805 4806 4807 4808 4809 4810 4811 4812 |
# File 'lib/aws-sdk-mgn/types.rb', line 4794 class NetworkMigrationMapperSegment < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :segment_id, :segment_type, :name, :description, :logical_id, :checksum, :output_s3_configuration, :created_at, :updated_at, :scope_tags, :target_account, :referenced_segments) SENSITIVE = [:scope_tags] include Aws::Structure end |
#description ⇒ String
A description of the segment.
4794 4795 4796 4797 4798 4799 4800 4801 4802 4803 4804 4805 4806 4807 4808 4809 4810 4811 4812 |
# File 'lib/aws-sdk-mgn/types.rb', line 4794 class NetworkMigrationMapperSegment < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :segment_id, :segment_type, :name, :description, :logical_id, :checksum, :output_s3_configuration, :created_at, :updated_at, :scope_tags, :target_account, :referenced_segments) SENSITIVE = [:scope_tags] include Aws::Structure end |
#job_id ⇒ String
The unique identifier of the job that created this segment.
4794 4795 4796 4797 4798 4799 4800 4801 4802 4803 4804 4805 4806 4807 4808 4809 4810 4811 4812 |
# File 'lib/aws-sdk-mgn/types.rb', line 4794 class NetworkMigrationMapperSegment < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :segment_id, :segment_type, :name, :description, :logical_id, :checksum, :output_s3_configuration, :created_at, :updated_at, :scope_tags, :target_account, :referenced_segments) SENSITIVE = [:scope_tags] include Aws::Structure end |
#logical_id ⇒ String
The logical identifier for the segment in the infrastructure code.
4794 4795 4796 4797 4798 4799 4800 4801 4802 4803 4804 4805 4806 4807 4808 4809 4810 4811 4812 |
# File 'lib/aws-sdk-mgn/types.rb', line 4794 class NetworkMigrationMapperSegment < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :segment_id, :segment_type, :name, :description, :logical_id, :checksum, :output_s3_configuration, :created_at, :updated_at, :scope_tags, :target_account, :referenced_segments) SENSITIVE = [:scope_tags] include Aws::Structure end |
#name ⇒ String
The name of the segment.
4794 4795 4796 4797 4798 4799 4800 4801 4802 4803 4804 4805 4806 4807 4808 4809 4810 4811 4812 |
# File 'lib/aws-sdk-mgn/types.rb', line 4794 class NetworkMigrationMapperSegment < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :segment_id, :segment_type, :name, :description, :logical_id, :checksum, :output_s3_configuration, :created_at, :updated_at, :scope_tags, :target_account, :referenced_segments) SENSITIVE = [:scope_tags] include Aws::Structure end |
#network_migration_definition_id ⇒ String
The unique identifier of the network migration definition.
4794 4795 4796 4797 4798 4799 4800 4801 4802 4803 4804 4805 4806 4807 4808 4809 4810 4811 4812 |
# File 'lib/aws-sdk-mgn/types.rb', line 4794 class NetworkMigrationMapperSegment < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :segment_id, :segment_type, :name, :description, :logical_id, :checksum, :output_s3_configuration, :created_at, :updated_at, :scope_tags, :target_account, :referenced_segments) SENSITIVE = [:scope_tags] include Aws::Structure end |
#network_migration_execution_id ⇒ String
The unique identifier of the network migration execution.
4794 4795 4796 4797 4798 4799 4800 4801 4802 4803 4804 4805 4806 4807 4808 4809 4810 4811 4812 |
# File 'lib/aws-sdk-mgn/types.rb', line 4794 class NetworkMigrationMapperSegment < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :segment_id, :segment_type, :name, :description, :logical_id, :checksum, :output_s3_configuration, :created_at, :updated_at, :scope_tags, :target_account, :referenced_segments) SENSITIVE = [:scope_tags] include Aws::Structure end |
#output_s3_configuration ⇒ Types::S3Configuration
The S3 location where segment artifacts are stored.
4794 4795 4796 4797 4798 4799 4800 4801 4802 4803 4804 4805 4806 4807 4808 4809 4810 4811 4812 |
# File 'lib/aws-sdk-mgn/types.rb', line 4794 class NetworkMigrationMapperSegment < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :segment_id, :segment_type, :name, :description, :logical_id, :checksum, :output_s3_configuration, :created_at, :updated_at, :scope_tags, :target_account, :referenced_segments) SENSITIVE = [:scope_tags] include Aws::Structure end |
#referenced_segments ⇒ Array<String>
A list of other segments that this segment depends on or references.
4794 4795 4796 4797 4798 4799 4800 4801 4802 4803 4804 4805 4806 4807 4808 4809 4810 4811 4812 |
# File 'lib/aws-sdk-mgn/types.rb', line 4794 class NetworkMigrationMapperSegment < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :segment_id, :segment_type, :name, :description, :logical_id, :checksum, :output_s3_configuration, :created_at, :updated_at, :scope_tags, :target_account, :referenced_segments) SENSITIVE = [:scope_tags] include Aws::Structure end |
#scope_tags ⇒ Hash<String,String>
Scope tags for the segment.
4794 4795 4796 4797 4798 4799 4800 4801 4802 4803 4804 4805 4806 4807 4808 4809 4810 4811 4812 |
# File 'lib/aws-sdk-mgn/types.rb', line 4794 class NetworkMigrationMapperSegment < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :segment_id, :segment_type, :name, :description, :logical_id, :checksum, :output_s3_configuration, :created_at, :updated_at, :scope_tags, :target_account, :referenced_segments) SENSITIVE = [:scope_tags] include Aws::Structure end |
#segment_id ⇒ String
The unique identifier of the segment.
4794 4795 4796 4797 4798 4799 4800 4801 4802 4803 4804 4805 4806 4807 4808 4809 4810 4811 4812 |
# File 'lib/aws-sdk-mgn/types.rb', line 4794 class NetworkMigrationMapperSegment < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :segment_id, :segment_type, :name, :description, :logical_id, :checksum, :output_s3_configuration, :created_at, :updated_at, :scope_tags, :target_account, :referenced_segments) SENSITIVE = [:scope_tags] include Aws::Structure end |
#segment_type ⇒ String
The category of the network migration segment. A segment groups the
network constructs (such as VPCs, subnets, and security groups) that
are migrated together. Valid values: WORKLOAD, APPLIANCE.
4794 4795 4796 4797 4798 4799 4800 4801 4802 4803 4804 4805 4806 4807 4808 4809 4810 4811 4812 |
# File 'lib/aws-sdk-mgn/types.rb', line 4794 class NetworkMigrationMapperSegment < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :segment_id, :segment_type, :name, :description, :logical_id, :checksum, :output_s3_configuration, :created_at, :updated_at, :scope_tags, :target_account, :referenced_segments) SENSITIVE = [:scope_tags] include Aws::Structure end |
#target_account ⇒ String
The target AWS account where this segment will be deployed.
4794 4795 4796 4797 4798 4799 4800 4801 4802 4803 4804 4805 4806 4807 4808 4809 4810 4811 4812 |
# File 'lib/aws-sdk-mgn/types.rb', line 4794 class NetworkMigrationMapperSegment < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :segment_id, :segment_type, :name, :description, :logical_id, :checksum, :output_s3_configuration, :created_at, :updated_at, :scope_tags, :target_account, :referenced_segments) SENSITIVE = [:scope_tags] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp when the segment was last updated.
4794 4795 4796 4797 4798 4799 4800 4801 4802 4803 4804 4805 4806 4807 4808 4809 4810 4811 4812 |
# File 'lib/aws-sdk-mgn/types.rb', line 4794 class NetworkMigrationMapperSegment < Struct.new( :job_id, :network_migration_execution_id, :network_migration_definition_id, :segment_id, :segment_type, :name, :description, :logical_id, :checksum, :output_s3_configuration, :created_at, :updated_at, :scope_tags, :target_account, :referenced_segments) SENSITIVE = [:scope_tags] include Aws::Structure end |