Class: Aws::Mgn::Types::NetworkMigrationMapperSegmentConstruct
- Inherits:
-
Struct
- Object
- Struct
- Aws::Mgn::Types::NetworkMigrationMapperSegmentConstruct
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mgn/types.rb
Overview
Represents a construct within a mapper segment. A construct is an individual infrastructure component such as a VPC, subnet, security group, route table, or other network resource that is part of the network migration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#construct_id ⇒ String
The unique identifier of the construct.
-
#construct_type ⇒ String
The type of the construct, such as VPC, subnet, security group, or route table.
-
#created_at ⇒ Time
The timestamp when the construct was created.
-
#description ⇒ String
A description of the construct.
-
#excluded ⇒ Boolean
Whether this construct is excluded from the migration.
-
#logical_id ⇒ String
The logical identifier for the construct in the infrastructure code.
-
#name ⇒ String
The name of the construct.
-
#properties ⇒ Hash<String,String>
The properties and configuration of the construct.
-
#updated_at ⇒ Time
The timestamp when the construct was last updated.
Instance Attribute Details
#construct_id ⇒ String
The unique identifier of the construct.
4725 4726 4727 4728 4729 4730 4731 4732 4733 4734 4735 4736 4737 |
# File 'lib/aws-sdk-mgn/types.rb', line 4725 class NetworkMigrationMapperSegmentConstruct < Struct.new( :construct_id, :construct_type, :name, :description, :logical_id, :excluded, :created_at, :updated_at, :properties) SENSITIVE = [] include Aws::Structure end |
#construct_type ⇒ String
The type of the construct, such as VPC, subnet, security group, or route table.
4725 4726 4727 4728 4729 4730 4731 4732 4733 4734 4735 4736 4737 |
# File 'lib/aws-sdk-mgn/types.rb', line 4725 class NetworkMigrationMapperSegmentConstruct < Struct.new( :construct_id, :construct_type, :name, :description, :logical_id, :excluded, :created_at, :updated_at, :properties) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The timestamp when the construct was created.
4725 4726 4727 4728 4729 4730 4731 4732 4733 4734 4735 4736 4737 |
# File 'lib/aws-sdk-mgn/types.rb', line 4725 class NetworkMigrationMapperSegmentConstruct < Struct.new( :construct_id, :construct_type, :name, :description, :logical_id, :excluded, :created_at, :updated_at, :properties) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the construct.
4725 4726 4727 4728 4729 4730 4731 4732 4733 4734 4735 4736 4737 |
# File 'lib/aws-sdk-mgn/types.rb', line 4725 class NetworkMigrationMapperSegmentConstruct < Struct.new( :construct_id, :construct_type, :name, :description, :logical_id, :excluded, :created_at, :updated_at, :properties) SENSITIVE = [] include Aws::Structure end |
#excluded ⇒ Boolean
Whether this construct is excluded from the migration.
4725 4726 4727 4728 4729 4730 4731 4732 4733 4734 4735 4736 4737 |
# File 'lib/aws-sdk-mgn/types.rb', line 4725 class NetworkMigrationMapperSegmentConstruct < Struct.new( :construct_id, :construct_type, :name, :description, :logical_id, :excluded, :created_at, :updated_at, :properties) SENSITIVE = [] include Aws::Structure end |
#logical_id ⇒ String
The logical identifier for the construct in the infrastructure code.
4725 4726 4727 4728 4729 4730 4731 4732 4733 4734 4735 4736 4737 |
# File 'lib/aws-sdk-mgn/types.rb', line 4725 class NetworkMigrationMapperSegmentConstruct < Struct.new( :construct_id, :construct_type, :name, :description, :logical_id, :excluded, :created_at, :updated_at, :properties) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the construct.
4725 4726 4727 4728 4729 4730 4731 4732 4733 4734 4735 4736 4737 |
# File 'lib/aws-sdk-mgn/types.rb', line 4725 class NetworkMigrationMapperSegmentConstruct < Struct.new( :construct_id, :construct_type, :name, :description, :logical_id, :excluded, :created_at, :updated_at, :properties) SENSITIVE = [] include Aws::Structure end |
#properties ⇒ Hash<String,String>
The properties and configuration of the construct.
4725 4726 4727 4728 4729 4730 4731 4732 4733 4734 4735 4736 4737 |
# File 'lib/aws-sdk-mgn/types.rb', line 4725 class NetworkMigrationMapperSegmentConstruct < Struct.new( :construct_id, :construct_type, :name, :description, :logical_id, :excluded, :created_at, :updated_at, :properties) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp when the construct was last updated.
4725 4726 4727 4728 4729 4730 4731 4732 4733 4734 4735 4736 4737 |
# File 'lib/aws-sdk-mgn/types.rb', line 4725 class NetworkMigrationMapperSegmentConstruct < Struct.new( :construct_id, :construct_type, :name, :description, :logical_id, :excluded, :created_at, :updated_at, :properties) SENSITIVE = [] include Aws::Structure end |