Class: Aws::Mgn::Types::OperationUnion

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-mgn/types.rb

Overview

Note:

OperationUnion is a union - when making an API calls you must set exactly one of the members.

A union type representing the operation to perform on a construct during a mapping update.

Direct Known Subclasses

Delete, Merge, Split, Unknown, Update

Defined Under Namespace

Classes: Delete, Merge, Split, Unknown, Update

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#deleteTypes::DeleteOperation

A delete operation to remove a construct from the mapping.



4865
4866
4867
4868
4869
4870
4871
4872
4873
4874
4875
4876
4877
4878
4879
4880
# File 'lib/aws-sdk-mgn/types.rb', line 4865

class OperationUnion < Struct.new(
  :merge,
  :split,
  :delete,
  :update,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Merge < OperationUnion; end
  class Split < OperationUnion; end
  class Delete < OperationUnion; end
  class Update < OperationUnion; end
  class Unknown < OperationUnion; end
end

#mergeTypes::MergeOperation

A merge operation to combine constructs from different segments.



4865
4866
4867
4868
4869
4870
4871
4872
4873
4874
4875
4876
4877
4878
4879
4880
# File 'lib/aws-sdk-mgn/types.rb', line 4865

class OperationUnion < Struct.new(
  :merge,
  :split,
  :delete,
  :update,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Merge < OperationUnion; end
  class Split < OperationUnion; end
  class Delete < OperationUnion; end
  class Update < OperationUnion; end
  class Unknown < OperationUnion; end
end

#splitTypes::SplitOperation

A split operation to divide a construct into multiple constructs with specified CIDR blocks.



4865
4866
4867
4868
4869
4870
4871
4872
4873
4874
4875
4876
4877
4878
4879
4880
# File 'lib/aws-sdk-mgn/types.rb', line 4865

class OperationUnion < Struct.new(
  :merge,
  :split,
  :delete,
  :update,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Merge < OperationUnion; end
  class Split < OperationUnion; end
  class Delete < OperationUnion; end
  class Update < OperationUnion; end
  class Unknown < OperationUnion; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



4865
4866
4867
# File 'lib/aws-sdk-mgn/types.rb', line 4865

def unknown
  @unknown
end

#updateTypes::UpdateOperation

An update operation to modify construct properties.



4865
4866
4867
4868
4869
4870
4871
4872
4873
4874
4875
4876
4877
4878
4879
4880
# File 'lib/aws-sdk-mgn/types.rb', line 4865

class OperationUnion < Struct.new(
  :merge,
  :split,
  :delete,
  :update,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Merge < OperationUnion; end
  class Split < OperationUnion; end
  class Delete < OperationUnion; end
  class Update < OperationUnion; end
  class Unknown < OperationUnion; end
end