Class: Aws::Mgn::Types::OperationUnion
- Inherits:
-
Struct
- Object
- Struct
- Aws::Mgn::Types::OperationUnion
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-mgn/types.rb
Overview
OperationUnion is a union - when making an API calls you must set exactly one of the members.
A union type representing the operation to perform on a construct during a mapping update.
Defined Under Namespace
Classes: Delete, Merge, Split, Unknown, Update
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#delete ⇒ Types::DeleteOperation
A delete operation to remove a construct from the mapping.
-
#merge ⇒ Types::MergeOperation
A merge operation to combine constructs from different segments.
-
#split ⇒ Types::SplitOperation
A split operation to divide a construct into multiple constructs with specified CIDR blocks.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
-
#update ⇒ Types::UpdateOperation
An update operation to modify construct properties.
Instance Attribute Details
#delete ⇒ Types::DeleteOperation
A delete operation to remove a construct from the mapping.
4865 4866 4867 4868 4869 4870 4871 4872 4873 4874 4875 4876 4877 4878 4879 4880 |
# File 'lib/aws-sdk-mgn/types.rb', line 4865 class OperationUnion < Struct.new( :merge, :split, :delete, :update, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Merge < OperationUnion; end class Split < OperationUnion; end class Delete < OperationUnion; end class Update < OperationUnion; end class Unknown < OperationUnion; end end |
#merge ⇒ Types::MergeOperation
A merge operation to combine constructs from different segments.
4865 4866 4867 4868 4869 4870 4871 4872 4873 4874 4875 4876 4877 4878 4879 4880 |
# File 'lib/aws-sdk-mgn/types.rb', line 4865 class OperationUnion < Struct.new( :merge, :split, :delete, :update, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Merge < OperationUnion; end class Split < OperationUnion; end class Delete < OperationUnion; end class Update < OperationUnion; end class Unknown < OperationUnion; end end |
#split ⇒ Types::SplitOperation
A split operation to divide a construct into multiple constructs with specified CIDR blocks.
4865 4866 4867 4868 4869 4870 4871 4872 4873 4874 4875 4876 4877 4878 4879 4880 |
# File 'lib/aws-sdk-mgn/types.rb', line 4865 class OperationUnion < Struct.new( :merge, :split, :delete, :update, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Merge < OperationUnion; end class Split < OperationUnion; end class Delete < OperationUnion; end class Update < OperationUnion; end class Unknown < OperationUnion; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
4865 4866 4867 |
# File 'lib/aws-sdk-mgn/types.rb', line 4865 def unknown @unknown end |
#update ⇒ Types::UpdateOperation
An update operation to modify construct properties.
4865 4866 4867 4868 4869 4870 4871 4872 4873 4874 4875 4876 4877 4878 4879 4880 |
# File 'lib/aws-sdk-mgn/types.rb', line 4865 class OperationUnion < Struct.new( :merge, :split, :delete, :update, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Merge < OperationUnion; end class Split < OperationUnion; end class Delete < OperationUnion; end class Update < OperationUnion; end class Unknown < OperationUnion; end end |