Class: Aws::Mgn::Types::OperationUnion
- Inherits:
-
Struct
- Object
- Struct
- Aws::Mgn::Types::OperationUnion
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-mgn/types.rb
Overview
Note:
OperationUnion is a union - when making an API calls you must set exactly one of the members.
A union type representing the operation to perform on a construct during a mapping update.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#unknown ⇒ Object
Returns the value of attribute unknown.
-
#update ⇒ Types::UpdateOperation
An update operation to modify construct properties.
Instance Attribute Details
#unknown ⇒ Object
Returns the value of attribute unknown
4804 4805 4806 |
# File 'lib/aws-sdk-mgn/types.rb', line 4804 def unknown @unknown end |
#update ⇒ Types::UpdateOperation
An update operation to modify construct properties.
4804 4805 4806 4807 4808 4809 4810 4811 4812 4813 |
# File 'lib/aws-sdk-mgn/types.rb', line 4804 class OperationUnion < Struct.new( :update, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Update < OperationUnion; end class Unknown < OperationUnion; end end |