Class: Aws::Mgn::Types::PostLaunchActionsStatus
- Inherits:
-
Struct
- Object
- Struct
- Aws::Mgn::Types::PostLaunchActionsStatus
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mgn/types.rb
Overview
Status of the Post Launch Actions running on the Test or Cutover instance.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#post_launch_actions_launch_status_list ⇒ Array<Types::JobPostLaunchActionsLaunchStatus>
List of Post Launch Action status.
-
#ssm_agent_discovery_datetime ⇒ String
Time where the AWS Systems Manager was detected as running on the Test or Cutover instance.
Instance Attribute Details
#post_launch_actions_launch_status_list ⇒ Array<Types::JobPostLaunchActionsLaunchStatus>
List of Post Launch Action status.
4977 4978 4979 4980 4981 4982 |
# File 'lib/aws-sdk-mgn/types.rb', line 4977 class PostLaunchActionsStatus < Struct.new( :ssm_agent_discovery_datetime, :post_launch_actions_launch_status_list) SENSITIVE = [] include Aws::Structure end |
#ssm_agent_discovery_datetime ⇒ String
Time where the AWS Systems Manager was detected as running on the Test or Cutover instance.
4977 4978 4979 4980 4981 4982 |
# File 'lib/aws-sdk-mgn/types.rb', line 4977 class PostLaunchActionsStatus < Struct.new( :ssm_agent_discovery_datetime, :post_launch_actions_launch_status_list) SENSITIVE = [] include Aws::Structure end |