Class: Aws::Mgn::Types::TargetNetwork

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mgn/types.rb

Overview

Configuration for the target network topology and addressing.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#inbound_cidrString

The CIDR block for inbound traffic in the target network.

Returns:

  • (String)


6342
6343
6344
6345
6346
6347
6348
6349
# File 'lib/aws-sdk-mgn/types.rb', line 6342

class TargetNetwork < Struct.new(
  :topology,
  :inbound_cidr,
  :outbound_cidr,
  :inspection_cidr)
  SENSITIVE = []
  include Aws::Structure
end

#inspection_cidrString

The CIDR block for inspection traffic in the target network.

Returns:

  • (String)


6342
6343
6344
6345
6346
6347
6348
6349
# File 'lib/aws-sdk-mgn/types.rb', line 6342

class TargetNetwork < Struct.new(
  :topology,
  :inbound_cidr,
  :outbound_cidr,
  :inspection_cidr)
  SENSITIVE = []
  include Aws::Structure
end

#outbound_cidrString

The CIDR block for outbound traffic in the target network.

Returns:

  • (String)


6342
6343
6344
6345
6346
6347
6348
6349
# File 'lib/aws-sdk-mgn/types.rb', line 6342

class TargetNetwork < Struct.new(
  :topology,
  :inbound_cidr,
  :outbound_cidr,
  :inspection_cidr)
  SENSITIVE = []
  include Aws::Structure
end

#topologyString

The network topology type for the target environment.

Returns:

  • (String)


6342
6343
6344
6345
6346
6347
6348
6349
# File 'lib/aws-sdk-mgn/types.rb', line 6342

class TargetNetwork < Struct.new(
  :topology,
  :inbound_cidr,
  :outbound_cidr,
  :inspection_cidr)
  SENSITIVE = []
  include Aws::Structure
end