Class: Aws::Mgn::Types::UpdateNetworkMigrationDefinitionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mgn/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:scope_tags]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

The updated description of the network migration definition.

Returns:

  • (String)


7072
7073
7074
7075
7076
7077
7078
7079
7080
7081
7082
7083
# File 'lib/aws-sdk-mgn/types.rb', line 7072

class UpdateNetworkMigrationDefinitionRequest < Struct.new(
  :network_migration_definition_id,
  :name,
  :description,
  :source_configurations,
  :target_s3_configuration,
  :target_network,
  :target_deployment,
  :scope_tags)
  SENSITIVE = [:scope_tags]
  include Aws::Structure
end

#nameString

The updated name of the network migration definition.

Returns:

  • (String)


7072
7073
7074
7075
7076
7077
7078
7079
7080
7081
7082
7083
# File 'lib/aws-sdk-mgn/types.rb', line 7072

class UpdateNetworkMigrationDefinitionRequest < Struct.new(
  :network_migration_definition_id,
  :name,
  :description,
  :source_configurations,
  :target_s3_configuration,
  :target_network,
  :target_deployment,
  :scope_tags)
  SENSITIVE = [:scope_tags]
  include Aws::Structure
end

#network_migration_definition_idString

The unique identifier of the network migration definition to update.

Returns:

  • (String)


7072
7073
7074
7075
7076
7077
7078
7079
7080
7081
7082
7083
# File 'lib/aws-sdk-mgn/types.rb', line 7072

class UpdateNetworkMigrationDefinitionRequest < Struct.new(
  :network_migration_definition_id,
  :name,
  :description,
  :source_configurations,
  :target_s3_configuration,
  :target_network,
  :target_deployment,
  :scope_tags)
  SENSITIVE = [:scope_tags]
  include Aws::Structure
end

#scope_tagsHash<String,String>

The updated scope tags for the network migration definition.

Returns:

  • (Hash<String,String>)


7072
7073
7074
7075
7076
7077
7078
7079
7080
7081
7082
7083
# File 'lib/aws-sdk-mgn/types.rb', line 7072

class UpdateNetworkMigrationDefinitionRequest < Struct.new(
  :network_migration_definition_id,
  :name,
  :description,
  :source_configurations,
  :target_s3_configuration,
  :target_network,
  :target_deployment,
  :scope_tags)
  SENSITIVE = [:scope_tags]
  include Aws::Structure
end

#source_configurationsArray<Types::SourceConfiguration>

The updated list of source configurations.

Returns:



7072
7073
7074
7075
7076
7077
7078
7079
7080
7081
7082
7083
# File 'lib/aws-sdk-mgn/types.rb', line 7072

class UpdateNetworkMigrationDefinitionRequest < Struct.new(
  :network_migration_definition_id,
  :name,
  :description,
  :source_configurations,
  :target_s3_configuration,
  :target_network,
  :target_deployment,
  :scope_tags)
  SENSITIVE = [:scope_tags]
  include Aws::Structure
end

#target_deploymentString

The updated target deployment configuration.

Returns:

  • (String)


7072
7073
7074
7075
7076
7077
7078
7079
7080
7081
7082
7083
# File 'lib/aws-sdk-mgn/types.rb', line 7072

class UpdateNetworkMigrationDefinitionRequest < Struct.new(
  :network_migration_definition_id,
  :name,
  :description,
  :source_configurations,
  :target_s3_configuration,
  :target_network,
  :target_deployment,
  :scope_tags)
  SENSITIVE = [:scope_tags]
  include Aws::Structure
end

#target_networkTypes::TargetNetworkUpdate

The updated target network configuration.



7072
7073
7074
7075
7076
7077
7078
7079
7080
7081
7082
7083
# File 'lib/aws-sdk-mgn/types.rb', line 7072

class UpdateNetworkMigrationDefinitionRequest < Struct.new(
  :network_migration_definition_id,
  :name,
  :description,
  :source_configurations,
  :target_s3_configuration,
  :target_network,
  :target_deployment,
  :scope_tags)
  SENSITIVE = [:scope_tags]
  include Aws::Structure
end

#target_s3_configurationTypes::TargetS3ConfigurationUpdate

The updated S3 configuration for storing the target network artifacts.



7072
7073
7074
7075
7076
7077
7078
7079
7080
7081
7082
7083
# File 'lib/aws-sdk-mgn/types.rb', line 7072

class UpdateNetworkMigrationDefinitionRequest < Struct.new(
  :network_migration_definition_id,
  :name,
  :description,
  :source_configurations,
  :target_s3_configuration,
  :target_network,
  :target_deployment,
  :scope_tags)
  SENSITIVE = [:scope_tags]
  include Aws::Structure
end