Class: Aws::Mgn::Types::UpdateNetworkMigrationDefinitionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Mgn::Types::UpdateNetworkMigrationDefinitionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mgn/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:scope_tags]
Instance Attribute Summary collapse
-
#description ⇒ String
The updated description of the network migration definition.
-
#name ⇒ String
The updated name of the network migration definition.
-
#network_migration_definition_id ⇒ String
The unique identifier of the network migration definition to update.
-
#scope_tags ⇒ Hash<String,String>
The updated scope tags for the network migration definition.
-
#source_configurations ⇒ Array<Types::SourceConfiguration>
The updated list of source configurations.
-
#target_deployment ⇒ String
The updated target deployment configuration.
-
#target_network ⇒ Types::TargetNetworkUpdate
The updated target network configuration.
-
#target_s3_configuration ⇒ Types::TargetS3ConfigurationUpdate
The updated S3 configuration for storing the target network artifacts.
Instance Attribute Details
#description ⇒ String
The updated description of the network migration definition.
6873 6874 6875 6876 6877 6878 6879 6880 6881 6882 6883 6884 |
# File 'lib/aws-sdk-mgn/types.rb', line 6873 class UpdateNetworkMigrationDefinitionRequest < Struct.new( :network_migration_definition_id, :name, :description, :source_configurations, :target_s3_configuration, :target_network, :target_deployment, :scope_tags) SENSITIVE = [:scope_tags] include Aws::Structure end |
#name ⇒ String
The updated name of the network migration definition.
6873 6874 6875 6876 6877 6878 6879 6880 6881 6882 6883 6884 |
# File 'lib/aws-sdk-mgn/types.rb', line 6873 class UpdateNetworkMigrationDefinitionRequest < Struct.new( :network_migration_definition_id, :name, :description, :source_configurations, :target_s3_configuration, :target_network, :target_deployment, :scope_tags) SENSITIVE = [:scope_tags] include Aws::Structure end |
#network_migration_definition_id ⇒ String
The unique identifier of the network migration definition to update.
6873 6874 6875 6876 6877 6878 6879 6880 6881 6882 6883 6884 |
# File 'lib/aws-sdk-mgn/types.rb', line 6873 class UpdateNetworkMigrationDefinitionRequest < Struct.new( :network_migration_definition_id, :name, :description, :source_configurations, :target_s3_configuration, :target_network, :target_deployment, :scope_tags) SENSITIVE = [:scope_tags] include Aws::Structure end |
#scope_tags ⇒ Hash<String,String>
The updated scope tags for the network migration definition.
6873 6874 6875 6876 6877 6878 6879 6880 6881 6882 6883 6884 |
# File 'lib/aws-sdk-mgn/types.rb', line 6873 class UpdateNetworkMigrationDefinitionRequest < Struct.new( :network_migration_definition_id, :name, :description, :source_configurations, :target_s3_configuration, :target_network, :target_deployment, :scope_tags) SENSITIVE = [:scope_tags] include Aws::Structure end |
#source_configurations ⇒ Array<Types::SourceConfiguration>
The updated list of source configurations.
6873 6874 6875 6876 6877 6878 6879 6880 6881 6882 6883 6884 |
# File 'lib/aws-sdk-mgn/types.rb', line 6873 class UpdateNetworkMigrationDefinitionRequest < Struct.new( :network_migration_definition_id, :name, :description, :source_configurations, :target_s3_configuration, :target_network, :target_deployment, :scope_tags) SENSITIVE = [:scope_tags] include Aws::Structure end |
#target_deployment ⇒ String
The updated target deployment configuration.
6873 6874 6875 6876 6877 6878 6879 6880 6881 6882 6883 6884 |
# File 'lib/aws-sdk-mgn/types.rb', line 6873 class UpdateNetworkMigrationDefinitionRequest < Struct.new( :network_migration_definition_id, :name, :description, :source_configurations, :target_s3_configuration, :target_network, :target_deployment, :scope_tags) SENSITIVE = [:scope_tags] include Aws::Structure end |
#target_network ⇒ Types::TargetNetworkUpdate
The updated target network configuration.
6873 6874 6875 6876 6877 6878 6879 6880 6881 6882 6883 6884 |
# File 'lib/aws-sdk-mgn/types.rb', line 6873 class UpdateNetworkMigrationDefinitionRequest < Struct.new( :network_migration_definition_id, :name, :description, :source_configurations, :target_s3_configuration, :target_network, :target_deployment, :scope_tags) SENSITIVE = [:scope_tags] include Aws::Structure end |
#target_s3_configuration ⇒ Types::TargetS3ConfigurationUpdate
The updated S3 configuration for storing the target network artifacts.
6873 6874 6875 6876 6877 6878 6879 6880 6881 6882 6883 6884 |
# File 'lib/aws-sdk-mgn/types.rb', line 6873 class UpdateNetworkMigrationDefinitionRequest < Struct.new( :network_migration_definition_id, :name, :description, :source_configurations, :target_s3_configuration, :target_network, :target_deployment, :scope_tags) SENSITIVE = [:scope_tags] include Aws::Structure end |